@@ -1,22 +1,16 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2005 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2005 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2005 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2005 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef APPLICATION_H
 #define APPLICATION_H
 
-#include <QUrl>
 #include <QNetworkConfigurationManager>
 
 #include "preferences.h"
@@ -62,6 +56,7 @@ namespace KWallet
 class Application : public QApplication
 {
     Q_OBJECT
+    friend class ConnectionManager;
 
     public:
         /** This function in general shouldn't be called, because in the future there
@@ -72,18 +67,18 @@ class Application : public QApplication
          *  Note to any MDI developer - get this to return any of the windows, or some
          *  'main' one.
          */
-        MainWindow* getMainWindow() { return mainWindow; }
+        MainWindow* getMainWindow() const { return mainWindow; }
 
-        ConnectionManager* getConnectionManager() { return m_connectionManager; }
-        AwayManager* getAwayManager() { return m_awayManager; }
-        ScriptLauncher* getScriptLauncher() { return m_scriptLauncher; }
-        Konversation::DCC::TransferManager* getDccTransferManager() { return m_dccTransferManager; }
+        ConnectionManager* getConnectionManager() const { return m_connectionManager; }
+        AwayManager* getAwayManager() const { return m_awayManager; }
+        ScriptLauncher* getScriptLauncher() const { return m_scriptLauncher; }
+        Konversation::DCC::TransferManager* getDccTransferManager() const { return m_dccTransferManager; }
 
         // HACK
         void showQueueTuner(bool);
 
         // URL-Catcher
-        QStandardItemModel* getUrlModel() { return m_urlModel; }
+        QStandardItemModel* getUrlModel() const { return m_urlModel; }
 
         Application(int &argc, char **argv);
         ~Application() override;
@@ -110,21 +105,21 @@ class Application : public QApplication
          */
         NickInfoPtr getNickInfo(const QString &ircnick, const QString &serverOrGroup);
 
-        OSDWidget* osd;
+        Konversation::Sound* sound() const;
 
-        Konversation::Sound* sound();
+        OSDWidget* osd() const;
 
         IRCQueue::EmptyingRate staticrates[Server::_QueueListSize];
 
-        Images* images() { return m_images; }
+        Images* images() const { return m_images; }
 
         Konversation::NotificationHandler* notificationHandler() const { return m_notificationHandler; }
 
         // auto replacement for input or output lines
-        QPair<QString, int> doAutoreplace(const QString& text, bool output, int cursorPos = -1);
+        QPair<QString, int> doAutoreplace(const QString& text, bool output, int cursorPos = -1) const;
 
         // inline auto replacement for input lines
-        void doInlineAutoreplace(KTextEdit* textEdit);
+        void doInlineAutoreplace(KTextEdit* textEdit) const;
 
         void newInstance(QCommandLineParser *args);
 
@@ -160,7 +155,10 @@ class Application : public QApplication
 
         void handleActivate(const QStringList& arguments);
 
-    protected Q_SLOTS:
+    protected:
+        bool event(QEvent* event) override;
+
+    private Q_SLOTS:
         void openQuickConnectDialog();
 
         void dbusMultiServerRaw(const QString &command);
@@ -173,12 +171,10 @@ class Application : public QApplication
 
         void closeWallet();
 
-    protected:
-        bool event(QEvent* event) override;
-
     private:
         void implementRestart();
 
+    private:
         ConnectionManager* m_connectionManager;
         AwayManager* m_awayManager;
         Konversation::DCC::TransferManager* m_dccTransferManager;
@@ -187,7 +183,8 @@ class Application : public QApplication
         Konversation::DBus* dbusObject;
         Konversation::IdentDBus* identDBus;
         QPointer<MainWindow> mainWindow;
-        Konversation::Sound* m_sound;
+        OSDWidget* m_osd;
+        mutable Konversation::Sound* m_sound;
         QuickConnectDialog* quickConnectDialog;
         Images* m_images;
         bool m_restartScheduled;
@@ -196,10 +193,17 @@ class Application : public QApplication
 
         KWallet::Wallet* m_wallet;
 
+// Silence deprecation warnings as long as there is no known substitute for QNetworkConfigurationManager
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
         QNetworkConfigurationManager* m_networkConfigurationManager;
+QT_WARNING_POP
 
         QCommandLineParser *m_commandLineParser;
         QStringList m_restartArguments;
+
+        Q_DISABLE_COPY(Application)
 };
 
 #endif
