@@ -1,14 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 1999 Martin R. Jones <mjones@kde.org>
-  Copyright (C) 2008 Eike Hein <hein@kde.org>
-  Copyright (C) 2010 Martin Blumenstingl <darklight.xdarklight@googlemail.com>
+    SPDX-FileCopyrightText: 1999 Martin R. Jones <mjones@kde.org>
+    SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2010 Martin Blumenstingl <darklight.xdarklight@googlemail.com>
 */
 
 #include "awaymanager.h"
@@ -27,8 +22,8 @@ AwayManager::AwayManager(QObject* parent) : QObject(parent)
 {
     m_connectionManager = Application::instance()->getConnectionManager();
 
-    connect(KIdleTime::instance(), SIGNAL(resumingFromIdle()), this, SLOT(resumeFromIdle()));
-    connect(KIdleTime::instance(), SIGNAL(timeoutReached(int)), this, SLOT(idleTimeoutReached(int)));
+    connect(KIdleTime::instance(), &KIdleTime::resumingFromIdle, this, &AwayManager::resumeFromIdle);
+    connect(KIdleTime::instance(), QOverload<int, int>::of(&KIdleTime::timeoutReached), this, &AwayManager::idleTimeoutReached);
 
     // Catch the first "resume event" (= user input) so we correctly catch the first
     // resume event in case the user is already idle on startup).
@@ -50,8 +45,7 @@ void AwayManager::identitiesChanged()
 
     const QList<Server*> serverList = m_connectionManager->getServerList();
 
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         IdentityPtr identity = server->getIdentity();
         int identityId = identity->id();
 
@@ -92,8 +86,7 @@ void AwayManager::implementManagedAway(int identityId)
 {
     const QList<Server*> serverList = m_connectionManager->getServerList();
 
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         if (server->getIdentity()->id() == identityId && server->isConnected() && !server->isAway())
             server->requestAway();
     }
@@ -111,8 +104,7 @@ void AwayManager::implementManagedUnaway(const QList<int>& identityList)
 {
     const QList<Server*> serverList = m_connectionManager->getServerList();
 
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         IdentityPtr identity = server->getIdentity();
 
         if (identityList.contains(identity->id()) && identity->getAutomaticUnaway()
@@ -134,7 +126,7 @@ void AwayManager::requestAllAway(const QString& reason)
 {
     const QList<Server*> serverList = m_connectionManager->getServerList();
 
-    foreach (Server* server, serverList)
+    for (Server* server : serverList)
         if (server->isConnected())
             server->requestAway(reason);
 }
@@ -143,7 +135,7 @@ void AwayManager::requestAllUnaway()
 {
     const QList<Server*> serverList = m_connectionManager->getServerList();
 
-    foreach (Server* server, serverList)
+    for (Server* server : serverList)
         if (server->isConnected() && server->isAway())
             server->requestUnaway();
 }
@@ -176,8 +168,7 @@ void AwayManager::updateGlobalAwayAction(bool away)
         const QList<Server*> serverList = m_connectionManager->getServerList();
         int awayCount = 0;
 
-        foreach (Server* server, serverList)
-        {
+        for (Server* server : serverList) {
             if (server->isAway())
                 awayCount++;
         }
@@ -322,8 +313,7 @@ void AwayManager::identitiesOnAutoAwayChanged()
     // Also clear the list of identity <-> timer mappings.
     m_timerForIdentity.clear();
 
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         IdentityPtr identity = server->getIdentity();
         int identityId = identity->id();
 
