@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2008 Eike Hein <hein@kde.org>
-  Copyright (C) 2010 Martin Blumenstingl <darklight.xdarklight@googlemail.com>
+    SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2010 Martin Blumenstingl <darklight.xdarklight@googlemail.com>
 */
 
 #ifndef AWAYMANAGER_H
@@ -23,8 +18,8 @@ class AwayManager : public QObject
     Q_OBJECT
 
     public:
-        explicit AwayManager(QObject* parent = 0);
-        ~AwayManager() override;
+        explicit AwayManager(QObject* parent = nullptr);
+        ~AwayManager();
 
 
     public Q_SLOTS:
@@ -39,12 +34,12 @@ class AwayManager : public QObject
         /**
           * Marks all identities which have auto-away enabled as away.
           */
-        virtual void setManagedIdentitiesAway();
+        void setManagedIdentitiesAway();
 
         /**
           * Marks all identities which have auto-away and automatic un-away enabled as "not away".
           */
-        virtual void setManagedIdentitiesUnaway();
+        void setManagedIdentitiesUnaway();
 
         /**
           * Simulates user activity. This means the implementation should ensure
@@ -95,7 +90,7 @@ class AwayManager : public QObject
           * This first drops all active idle timers. Then it triggers recalculation
           * of all idle timers for all identities which have auto-away enabled.
           */
-        virtual void identitiesOnAutoAwayChanged();
+        void identitiesOnAutoAwayChanged();
 
         /**
           * An identity which has auto-away enabled went offline.
@@ -103,7 +98,7 @@ class AwayManager : public QObject
           *
           * @param identityId the ID of the identity which just went offline
           */
-        virtual void identityOnAutoAwayWentOnline(int identityId);
+        void identityOnAutoAwayWentOnline(int identityId);
 
         /**
           * An identity which has auto-away enabled went offline.
@@ -111,7 +106,7 @@ class AwayManager : public QObject
           *
           * @param identityId the ID of the identity which just went offline
           */
-        virtual void identityOnAutoAwayWentOffline(int identityId);
+        void identityOnAutoAwayWentOffline(int identityId);
 
         /**
           * Creates a new idle timer for the given identity with the given
@@ -164,6 +159,7 @@ class AwayManager : public QObject
           */
         static int minutesToMilliseconds(int minutes);
 
+    private:
         /**
           * A list of identity IDs and their corresponding auto-away times (in
           * milliseconds).
@@ -176,6 +172,8 @@ class AwayManager : public QObject
         QHash<int, int> m_timerForIdentity;
 
         ConnectionManager* m_connectionManager;
+
+        Q_DISABLE_COPY(AwayManager)
 };
 
 #endif
