@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #include "alias_config.h"
@@ -71,7 +66,10 @@ void Alias_Config::setAliasListView(const QStringList& aliasList)
     for(int index=aliasList.count(); index!=0; index--)
     {
         QString item=aliasList[index-1];
-        QTreeWidgetItem *treeWidgetItem = new QTreeWidgetItem(aliasListView, QStringList() << item.section(' ',0,0) << item.section(' ',1));
+        QTreeWidgetItem *treeWidgetItem = new QTreeWidgetItem(aliasListView, QStringList {
+            item.section(QLatin1Char(' '), 0, 0),
+            item.section(QLatin1Char(' '), 1)
+        });
         treeWidgetItem->setFlags(treeWidgetItem->flags() &~ Qt::ItemIsDropEnabled);
     }
 
@@ -80,14 +78,14 @@ void Alias_Config::setAliasListView(const QStringList& aliasList)
     m_oldAliasList=aliasList;
 }
 
-QStringList Alias_Config::currentAliasList()
+QStringList Alias_Config::currentAliasList() const
 {
     QStringList newList;
 
     QTreeWidgetItem* item=aliasListView->topLevelItem(0);
     while(item)
         {
-        newList.append(item->text(0)+' '+item->text(1));
+        newList.append(item->text(0) + QLatin1Char(' ') + item->text(1));
         item=aliasListView->itemBelow(item);
         }
     return newList;
@@ -200,7 +198,7 @@ void Alias_Config::removeEntry()
         else
         {
             // no next item found, this means the list is empty
-            entrySelected(0);
+            entrySelected(nullptr);
         }
         // tell the config system that somethig has changed
         emit modified();
