@@ -1,24 +1,18 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #include "autoreplace_config.h"
 #include "preferences.h"
 
-#include <kparts/componentfactory.h>
-#include <kregexpeditorinterface.h>
+#include <KSharedConfig>
 
-#define DIRECTION_OUTPUT 0
-#define DIRECTION_INPUT  1
-#define DIRECTION_BOTH   2
+constexpr int DIRECTION_OUTPUT = 0;
+constexpr int DIRECTION_INPUT  = 1;
+constexpr int DIRECTION_BOTH   = 2;
 
 
 Autoreplace_Config::Autoreplace_Config(QWidget* parent, const char* name)
@@ -29,23 +23,7 @@ Autoreplace_Config::Autoreplace_Config(QWidget* parent, const char* name)
 
   // reset flag to defined state (used to block signals when just selecting a new item)
   m_newItemSelected=false;
-  //Check if the regexp editor is installed
-// it does not make sense to port / enable this since KRegExpEditor is in a very bad shape. just keep this
-// code here because it will probably help at a later point to port it when KRegExpEditor is again usable.
-// 2009-02-06, uwolfer
-  bool installed = false;//( KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor", QString(), this )!= 0 );
-  regExpEditorButton->setVisible(false);
 
-  if(installed)
-  {
-      regExpEditorButton->setEnabled(true);
-      regExpEditorButton->setStatusTip(i18n("Click to run Regular Expression Editor (KRegExpEditor)"));
-  }
-  else
-  {
-      regExpEditorButton->setEnabled(false);
-      regExpEditorButton->setStatusTip(i18n("The Regular Expression Editor (KRegExpEditor) is not installed"));
-  }
   // populate combobox
   directionCombo->insertItem(DIRECTION_OUTPUT, i18n("Outgoing"));
   directionCombo->insertItem(DIRECTION_INPUT, i18n("Incoming"));
@@ -54,16 +32,15 @@ Autoreplace_Config::Autoreplace_Config(QWidget* parent, const char* name)
   // populate listview
   loadSettings();
 
-  connect(patternListView, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(entrySelected(QTreeWidgetItem*)));
+  connect(patternListView, &QTreeWidget::currentItemChanged, this, &Autoreplace_Config::entrySelected);
 
-  connect(directionCombo, SIGNAL(activated(int)), this, SLOT(directionChanged(int)));
+  connect(directionCombo, QOverload<int>::of(&KComboBox::activated), this, &Autoreplace_Config::directionChanged);
 
-  connect(patternInput, SIGNAL(textChanged(QString)), this, SLOT(patternChanged(QString)));
-  connect(regExpEditorButton, SIGNAL(clicked()), this, SLOT(showRegExpEditor()));
-  connect(replacementInput, SIGNAL(textChanged(QString)), this, SLOT(replacementChanged(QString)));
+  connect(patternInput, &KLineEdit::textChanged, this, &Autoreplace_Config::patternChanged);
+  connect(replacementInput, &KLineEdit::textChanged, this, &Autoreplace_Config::replacementChanged);
 
-  connect(newButton, SIGNAL(clicked()), this, SLOT(addEntry()));
-  connect(removeButton, SIGNAL(clicked()), this, SLOT(removeEntry()));
+  connect(newButton, &QPushButton::clicked, this, &Autoreplace_Config::addEntry);
+  connect(removeButton, &QPushButton::clicked, this, &Autoreplace_Config::removeEntry);
 }
 
 Autoreplace_Config::~Autoreplace_Config()
@@ -84,26 +61,23 @@ void Autoreplace_Config::setAutoreplaceListView(const QList<QStringList> &autore
   // clear listView
   patternListView->clear();
   // go through the list
-  for (int index=0;index<autoreplaceList.count();index++)
-  {
-    // get autoreplace definition
-    QStringList definition=autoreplaceList[index];
+  for (const QStringList &definition : autoreplaceList) {
     // cut definition apart in name and action, and create a new listview item
     QTreeWidgetItem* newItem=new QTreeWidgetItem(patternListView);
     newItem->setFlags(newItem->flags() &~ Qt::ItemIsDropEnabled);
     newItem->setCheckState(0, Qt::Unchecked);
     // Regular expression?
-    if (definition.at(0)=="1") newItem->setCheckState(0, Qt::Checked);
+    if (definition.at(0)== QLatin1Char('1')) newItem->setCheckState(0, Qt::Checked);
     // direction input/output/both
-    if (definition.at(1)=="i")
+    if (definition.at(1)== QLatin1Char('i'))
     {
         newItem->setText(1,directionCombo->itemText(DIRECTION_INPUT));
     }
-    else if (definition.at(1)=="o")
+    else if (definition.at(1)== QLatin1Char('o'))
     {
         newItem->setText(1,directionCombo->itemText(DIRECTION_OUTPUT));
     }
-    else if (definition.at(1)=="io")
+    else if (definition.at(1)==QLatin1String("io"))
     {
         newItem->setText(1,directionCombo->itemText(DIRECTION_BOTH));
     }
@@ -121,7 +95,7 @@ void Autoreplace_Config::setAutoreplaceListView(const QList<QStringList> &autore
 void Autoreplace_Config::saveSettings()
 {
   // get configuration object
-  KSharedConfigPtr config=KGlobal::config();
+  KSharedConfigPtr config=KSharedConfig::openConfig();
 
   // delete all patterns
   config->deleteGroup("Autoreplace List");
@@ -133,13 +107,12 @@ void Autoreplace_Config::saveSettings()
   QList<QStringList> newList=currentAutoreplaceList();
 
   // check if there are any patterns in the list view
-  if(newList.count())
-  {
+  if (!newList.isEmpty()) {
     // go through all patterns and save them into the configuration
-    QString regexString("Regex");
-    QString directString("Direction");
-    QString patternString("Pattern");
-    QString replaceString("Replace");
+    QString regexString(QStringLiteral("Regex"));
+    QString directString(QStringLiteral("Direction"));
+    QString patternString(QStringLiteral("Pattern"));
+    QString replaceString(QStringLiteral("Replace"));
     for(int index=0;index<newList.count();index++)
     {
         // write the current entry's pattern and replacement (adds a "#" to preserve blanks at the end of the line)
@@ -147,8 +120,8 @@ void Autoreplace_Config::saveSettings()
         QStringList definition = newList[index];
         grp.writeEntry(regexString + indexString,definition.at(0)); //regex status
         grp.writeEntry(directString + indexString,definition.at(1)); //direction
-        grp.writeEntry(patternString + indexString,QString(definition.at(2)+'#')); //pattern
-        grp.writeEntry(replaceString + indexString,QString(definition.at(3)+'#')); //replace
+        grp.writeEntry(patternString + indexString, QString(definition.at(2) + QLatin1Char('#'))); //pattern
+        grp.writeEntry(replaceString + indexString, QString(definition.at(3) + QLatin1Char('#'))); //replace
 
     } // for
   }
@@ -169,7 +142,7 @@ void Autoreplace_Config::restorePageToDefaults()
   setAutoreplaceListView(Preferences::defaultAutoreplaceList());
 }
 
-QList<QStringList> Autoreplace_Config::currentAutoreplaceList()
+QList<QStringList> Autoreplace_Config::currentAutoreplaceList() const
 {
   // get first item of the autoreplace listview
   QTreeWidgetItem* item=patternListView->topLevelItem(0);
@@ -179,9 +152,9 @@ QList<QStringList> Autoreplace_Config::currentAutoreplaceList()
   // go through all items and save them into the configuration
   while(item)
   {
-    regex = (item->checkState(0) == Qt::Checked) ? '1' : '0';
+    regex = (item->checkState(0) == Qt::Checked) ? QLatin1Char('1') : QLatin1Char('0');
     // remember entry in internal list (col 4 is hidden for input/output)
-    newList.append(QStringList() << regex << item->text(4) << item->text(2) << item->text(3));
+    newList.append(QStringList { regex, item->text(4), item->text(2), item->text(3) });
     // get next item in the listview
     item=patternListView->itemBelow(item);
   } // while
@@ -218,9 +191,9 @@ void Autoreplace_Config::entrySelected(QTreeWidgetItem* autoreplaceEntry)
     // set combobox to selected item
     int itemIndex=0;
     QString direction=autoreplaceEntry->text(4);
-    if(direction=="i") itemIndex=DIRECTION_INPUT;
-    else if(direction=="o") itemIndex=DIRECTION_OUTPUT;
-    else if(direction=="io") itemIndex=DIRECTION_BOTH;
+    if(direction== QLatin1Char('i')) itemIndex=DIRECTION_INPUT;
+    else if(direction== QLatin1Char('o')) itemIndex=DIRECTION_OUTPUT;
+    else if(direction==QLatin1String("io")) itemIndex=DIRECTION_BOTH;
     directionCombo->setCurrentIndex(itemIndex);
     // re-enable modified() signal on text changes in edit widgets
     m_newItemSelected=false;
@@ -234,13 +207,6 @@ void Autoreplace_Config::entrySelected(QTreeWidgetItem* autoreplaceEntry)
   replacementLabel->setEnabled(enabled);
   replacementInput->setEnabled(enabled);
 
-// see note above about KRegExpEditor
-#if 0
-  if(!KTrader::self()->query("KRegExpEditor/KRegExpEditor").isEmpty())
-  {
-    regExpEditorButton->setEnabled(enabled);
-  }
-#endif
   // make checkboxes work
   emit modified();
 }
@@ -257,9 +223,9 @@ void Autoreplace_Config::directionChanged(int newDirection)
     // prepare hidden identifier string
     QString id;
     // find the direction strings to set up in the item
-    if(newDirection==DIRECTION_INPUT)       id='i';
-    else if(newDirection==DIRECTION_OUTPUT) id='o';
-    else if(newDirection==DIRECTION_BOTH)   id="io";
+    if (newDirection==DIRECTION_INPUT)       id = QStringLiteral("i");
+    else if (newDirection==DIRECTION_OUTPUT) id = QStringLiteral("o");
+    else if(newDirection==DIRECTION_BOTH)   id=QStringLiteral("io");
     // rename direction
     item->setText(1,directionCombo->itemText(newDirection));
     item->setText(4,id);
@@ -278,8 +244,7 @@ void Autoreplace_Config::patternChanged(const QString& newPattern)
   if(item)
   {
     // rename pattern
-    if (newPattern.length()>0)
-    {
+    if (!newPattern.isEmpty()) {
         item->setText(2,newPattern);
     }
     else
@@ -317,13 +282,13 @@ void Autoreplace_Config::addEntry()
   {
     newItem->setFlags(newItem->flags() &~ Qt::ItemIsDropEnabled);
     newItem->setCheckState(0, Qt::Unchecked);
-  
+
     // set default direction
     newItem->setText(1,directionCombo->itemText(DIRECTION_OUTPUT));
     // set default pattern name
     newItem->setText(2,i18nc("Default content of the \"Find:\" field of a newly-added auto-replace rule.", "New"));
     // set default direction
-    newItem->setText(4,"o");
+    newItem->setText(4,QStringLiteral("o"));
     // select new item and make it the current one
     patternListView->setCurrentItem(newItem);
     // set input focus on item pattern edit
@@ -361,33 +326,11 @@ void Autoreplace_Config::removeEntry()
     else
     {
       // no next item found, this means the list is empty
-      entrySelected(0);
+      entrySelected(nullptr);
     }
     // tell the config system that somethig has changed
     emit modified();
   }
 }
 
-void Autoreplace_Config::showRegExpEditor()
-{
-    QDialog *editorDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor", QString(), this );
 
-    if(editorDialog)
-    {
-        // kdeutils was installed, so the dialog was found.  Fetch the editor interface.
-         KRegExpEditorInterface *iface = qobject_cast<KRegExpEditorInterface*>( editorDialog );
-        Q_ASSERT(iface); // This should not fail!
-        iface->setRegExp(patternInput->text());
-        int dlgResult = editorDialog->exec();
-
-        if(dlgResult == QDialog::Accepted)
-        {
-            QString re = iface->regExp();
-            patternInput->setText(re);
-        }
-
-        delete editorDialog;
-    }
-}
-
-#include "autoreplace_config.moc"
