@@ -1,32 +1,20 @@
 /*
-Copyright 2009  Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2009 Peter Simonsson <peter.simonsson@gmail.com>
 */
 
 #include "connectionbehavior_config.h"
+
 #include "application.h"
 #include "preferences.h"
+#include "konversation_log.h"
+#include <config-konversation.h>
 
 #include <KLineEdit>
-#include <kwallet.h>
+#include <KWallet>
 #include <KLocalizedString>
 
-#include <config-konversation.h>
 
 ConnectionBehavior_Config::ConnectionBehavior_Config(QWidget* parent)
     : QWidget(parent), m_passwordChanged(false)
@@ -39,7 +27,7 @@ ConnectionBehavior_Config::ConnectionBehavior_Config(QWidget* parent)
 
     kcfg_ReconnectDelay->setSuffix(ki18np(" second", " seconds"));
 
-    connect(m_ProxyPassword, SIGNAL(textChanged(QString)), this, SLOT(setPasswordChanged()));
+    connect(m_ProxyPassword, &KLineEdit::textChanged, this, [this]() { setPasswordChanged(); });
 }
 
 void ConnectionBehavior_Config::restorePageToDefaults()
@@ -53,11 +41,11 @@ void ConnectionBehavior_Config::saveSettings()
     {
         if(Application::instance()->wallet())
         {
-            int ret = Application::instance()->wallet()->writePassword("ProxyPassword", m_ProxyPassword->text());
+            int ret = Application::instance()->wallet()->writePassword(QStringLiteral("ProxyPassword"), m_ProxyPassword->text());
 
             if(ret != 0)
             {
-                qCritical() << "Failed to write the proxy password to the wallet, error code:" << ret;
+                qCCritical(KONVERSATION_LOG) << "Failed to write the proxy password to the wallet, error code:" << ret;
             }
         }
     }
@@ -73,11 +61,11 @@ void ConnectionBehavior_Config::loadSettings()
     {
         if(Application::instance()->wallet())
         {
-            int ret = Application::instance()->wallet()->readPassword("ProxyPassword", password);
+            int ret = Application::instance()->wallet()->readPassword(QStringLiteral("ProxyPassword"), password);
 
             if(ret != 0)
             {
-                qCritical() << "Failed to read the proxy password from the wallet, error code:" << ret;
+                qCCritical(KONVERSATION_LOG) << "Failed to read the proxy password from the wallet, error code:" << ret;
             }
         }
     }
