@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #include "highlight_config.h"
@@ -21,7 +16,7 @@
 #include <QStandardPaths>
 
 
-Highlight_Config::Highlight_Config(QWidget* parent, const char* name)
+Highlight_Config::Highlight_Config(QWidget* parent, const QString& name)
 : QWidget(parent)
 {
     setObjectName(name);
@@ -32,28 +27,25 @@ Highlight_Config::Highlight_Config(QWidget* parent, const char* name)
 
     loadSettings();
 
-    soundPlayBtn->setIcon(QIcon::fromTheme("media-playback-start"));
+    soundPlayBtn->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
     soundURL->setWhatsThis(i18n("Select Sound File"));
 
     // This code was copied from KNotifyWidget::openSoundDialog() (knotifydialog.cpp) [it's under LGPL v2]
     // find the first "sound"-resource that contains files
-    QStringList soundDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konversation/sounds");
-    soundDirs += QStandardPaths::locate(QStandardPaths::GenericDataLocation, "sounds", QStandardPaths::LocateDirectory);
+    QStringList soundDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konversation/sounds"));
+    soundDirs += QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds"), QStandardPaths::LocateDirectory);
 
     if (!soundDirs.isEmpty())
     {
         QDir dir;
         dir.setFilter( QDir::Files | QDir::Readable );
-        QStringList::ConstIterator it = soundDirs.constBegin();
-        while ( it != soundDirs.constEnd() )
-        {
-            dir = *it;
+        for (const QString& soundDir : qAsConst(soundDirs)) {
+            dir.setPath(soundDir);
             if ( dir.isReadable() && dir.count() > 2 )
             {
-                soundURL->setStartDir(QUrl::fromLocalFile(*it));
+                soundURL->setStartDir(QUrl::fromLocalFile(soundDir));
                 break;
             }
-            ++it;
         }
     }
     // End copy
@@ -90,8 +82,8 @@ void Highlight_Config::restorePageToDefaults()
 void Highlight_Config::loadSettings()
 {
     highlightListView->clear();
-    foreach (Highlight* currentHighlight, Preferences::highlightList())
-    {
+    const auto highlightList = Preferences::highlightList();
+    for (Highlight* currentHighlight : highlightList) {
         HighlightViewItem *item = new HighlightViewItem(highlightListView,currentHighlight);
         item->setFlags(item->flags() &~ Qt::ItemIsDropEnabled);
     }
@@ -115,7 +107,7 @@ void Highlight_Config::highlightSelected(QTreeWidgetItem* item)
     if (item)
     {
         // make a highlight item out of the generic qlistviewitem
-        HighlightViewItem* highlightItem = static_cast<HighlightViewItem*>(item);
+        HighlightViewItem* highlightItem = dynamic_cast<HighlightViewItem*>(item);
 
         // tell all now emitted signals that we just clicked on a new item, so they should
         // not emit the modified() signal.
@@ -135,7 +127,7 @@ void Highlight_Config::highlightSelected(QTreeWidgetItem* item)
 
 void Highlight_Config::updateButtons()
 {
-    bool enabled = highlightListView->currentItem() != NULL;
+    bool enabled = highlightListView->currentItem() != nullptr;
     // enable or disable edit widgets
     patternLabel->setEnabled(enabled);
     patternInput->setEnabled(enabled);
@@ -154,7 +146,7 @@ void Highlight_Config::updateButtons()
 
 void Highlight_Config::patternChanged(const QString& newPattern)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -165,7 +157,7 @@ void Highlight_Config::patternChanged(const QString& newPattern)
 
 void Highlight_Config::notifyModeChanged(bool enabled)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -176,7 +168,7 @@ void Highlight_Config::notifyModeChanged(bool enabled)
 
 void Highlight_Config::colorChanged(const QColor& newColor)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -187,7 +179,7 @@ void Highlight_Config::colorChanged(const QColor& newColor)
 
 void Highlight_Config::soundURLChanged(const QString& newURL)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -198,7 +190,7 @@ void Highlight_Config::soundURLChanged(const QString& newURL)
 
 void Highlight_Config::autoTextChanged(const QString& newText)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -209,7 +201,7 @@ void Highlight_Config::autoTextChanged(const QString& newText)
 
 void Highlight_Config::chatWindowsChanged(const QString& newChatWindows)
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (!newItemSelected && item)
     {
@@ -232,13 +224,13 @@ void Highlight_Config::addHighlight()
 
 void Highlight_Config::removeHighlight()
 {
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
     if (item)
     {
         delete item;
 
-        item = static_cast<HighlightViewItem*>(highlightListView->currentItem());
+        item = dynamic_cast<HighlightViewItem*>(highlightListView->currentItem());
 
         if (item)
         {
@@ -250,31 +242,31 @@ void Highlight_Config::removeHighlight()
     updateButtons();
 }
 
-QList<Highlight*> Highlight_Config::getHighlightList()
+QList<Highlight*> Highlight_Config::getHighlightList() const
 {
     QList<Highlight*> newList;
 
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->topLevelItem(0));
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->topLevelItem(0));
     while (item)
     {
         newList.append(new Highlight(item->getPattern(), item->getRegExp(), item->getColor(),
             item->getSoundURL(), item->getAutoText(), item->getChatWindows(), item->getNotify()));
-        item = static_cast<HighlightViewItem*>(highlightListView->itemBelow(item));
+        item = dynamic_cast<HighlightViewItem*>(highlightListView->itemBelow(item));
     }
 
     return newList;
 }
 
-QStringList Highlight_Config::currentHighlightList()
+QStringList Highlight_Config::currentHighlightList() const
 {
     QStringList newList;
 
-    HighlightViewItem* item = static_cast<HighlightViewItem*>(highlightListView->topLevelItem(0));
+    HighlightViewItem* item = dynamic_cast<HighlightViewItem*>(highlightListView->topLevelItem(0));
     while (item)
     {
         newList.append(item->getPattern() + QString(item->getRegExp()) + item->getColor().name() +
             item->getSoundURL().url() + item->getAutoText() + item->getChatWindows() + QString::number(item->getNotify()));
-        item = static_cast<HighlightViewItem*>(highlightListView->itemBelow(item));
+        item = dynamic_cast<HighlightViewItem*>(highlightListView->itemBelow(item));
     }
 
     return newList;
@@ -291,11 +283,10 @@ void Highlight_Config::saveSettings()
     KSharedConfigPtr config = KSharedConfig::openConfig();
 
     // Write all highlight entries
-    QList<Highlight*> hiList = getHighlightList();
+    const QList<Highlight*> hiList = getHighlightList();
     int i = 0;
-    foreach (Highlight* hl, hiList)
-    {
-        KConfigGroup grp = config->group(QString("Highlight%1").arg(i));
+    for (Highlight* hl : hiList) {
+        KConfigGroup grp = config->group(QStringLiteral("Highlight%1").arg(i));
         grp.writeEntry("Pattern", hl->getPattern());
         grp.writeEntry("RegExp", hl->getRegExp());
         grp.writeEntry("Color", hl->getColor());
@@ -309,9 +300,9 @@ void Highlight_Config::saveSettings()
     Preferences::setHighlightList(hiList);
 
     // Remove unused entries...
-    while (config->hasGroup(QString("Highlight%1").arg(i)))
+    while (config->hasGroup(QStringLiteral("Highlight%1").arg(i)))
     {
-        config->deleteGroup(QString("Highlight%1").arg(i));
+        config->deleteGroup(QStringLiteral("Highlight%1").arg(i));
         i++;
     }
 
