@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #include "ignore_config.h"
@@ -49,7 +44,7 @@ Ignore_Config::~Ignore_Config()
 void Ignore_Config::newIgnore()
 {
     QTreeWidgetItem *item = new IgnoreListViewItem(ignoreListView,
-        "new!new@new.new",
+        QStringLiteral("new!new@new.new"),
         Ignore::Channel |
         Ignore::Query |
         Ignore::Notice |
@@ -76,14 +71,15 @@ void Ignore_Config::removeIgnore()
     emit modified();
 }
 
-QList<Ignore*> Ignore_Config::getIgnoreList()
+QList<Ignore*> Ignore_Config::getIgnoreList() const
 {
     QList<Ignore*> newList;
 
     QTreeWidgetItem *root = ignoreListView->invisibleRootItem();
-    for (int i = 0; i < root->childCount(); ++i)
-    {
-        IgnoreListViewItem* item = static_cast<IgnoreListViewItem *>(root->child(i));
+    const int childCount = root->childCount();
+    newList.reserve(childCount);
+    for (int i = 0; i < childCount; ++i) {
+        IgnoreListViewItem* item = dynamic_cast<IgnoreListViewItem *>(root->child(i));
         Ignore* newItem=new Ignore(item->text(0),item->getFlags());
         newList.append(newItem);
     }
@@ -92,14 +88,15 @@ QList<Ignore*> Ignore_Config::getIgnoreList()
 }
 
 // returns the currently visible ignore list as QStringList to make comparing easy
-QStringList Ignore_Config::currentIgnoreList()
+QStringList Ignore_Config::currentIgnoreList() const
 {
     QStringList newList;
 
     QTreeWidgetItem *root = ignoreListView->invisibleRootItem();
-    for (int i = 0; i < root->childCount(); ++i)
-    {
-        IgnoreListViewItem* item = static_cast<IgnoreListViewItem *>(root->child(i));
+    const int childCount = root->childCount();
+    newList.reserve(childCount);
+    for (int i = 0; i < childCount; ++i) {
+        IgnoreListViewItem* item = dynamic_cast<IgnoreListViewItem *>(root->child(i));
         newList.append(item->text(0)+QLatin1Char(' ')+QString(item->getFlags()));
     }
 
@@ -130,8 +127,8 @@ void Ignore_Config::saveSettings()
 void Ignore_Config::loadSettings()
 {
     ignoreListView->clear();
-    foreach (Ignore* item, Preferences::ignoreList())
-    {
+    const auto ignoreItems = Preferences::ignoreList();
+    for (Ignore* item : ignoreItems) {
         new IgnoreListViewItem(ignoreListView, item->getName(), item->getFlags());
     }
     ignoreListView->sortItems(0, Qt::AscendingOrder);
@@ -142,17 +139,17 @@ void Ignore_Config::loadSettings()
 
 void Ignore_Config::updateEnabledness()
 {
-    IgnoreListViewItem* selectedItem=static_cast<IgnoreListViewItem*>(ignoreListView->currentItem());
+    IgnoreListViewItem* selectedItem=dynamic_cast<IgnoreListViewItem*>(ignoreListView->currentItem());
 
-    chkChannel->setEnabled(selectedItem != NULL);
-    chkQuery->setEnabled(selectedItem != NULL);
-    chkNotice->setEnabled(selectedItem != NULL);
-    chkCTCP->setEnabled(selectedItem != NULL);
-    chkDCC->setEnabled(selectedItem != NULL);
-    chkInvite->setEnabled(selectedItem != NULL);
+    chkChannel->setEnabled(selectedItem != nullptr);
+    chkQuery->setEnabled(selectedItem != nullptr);
+    chkNotice->setEnabled(selectedItem != nullptr);
+    chkCTCP->setEnabled(selectedItem != nullptr);
+    chkDCC->setEnabled(selectedItem != nullptr);
+    chkInvite->setEnabled(selectedItem != nullptr);
 //	chkExceptions->setEnabled(selectedItem != NULL);
-    txtPattern->setEnabled(selectedItem != NULL);
-    removeButton->setEnabled(selectedItem != NULL);
+    txtPattern->setEnabled(selectedItem != nullptr);
+    removeButton->setEnabled(selectedItem != nullptr);
     removeAllButton->setEnabled(ignoreListView->topLevelItemCount() > 0);
 
 }
@@ -160,7 +157,7 @@ void Ignore_Config::updateEnabledness()
 void Ignore_Config::select(QTreeWidgetItem* item)
 {
     updateEnabledness();
-    IgnoreListViewItem* selectedItem=static_cast<IgnoreListViewItem*>(item);
+    IgnoreListViewItem* selectedItem=dynamic_cast<IgnoreListViewItem*>(item);
 
     if(selectedItem)
     {
@@ -190,7 +187,7 @@ void Ignore_Config::flagCheckboxChanged()
     if(chkInvite->isChecked()) flags |= Ignore::Invite;
 
 //    if(chkExceptions->isChecked()) flags |= Ignore::Exceptions;
-    IgnoreListViewItem* selectedItem=static_cast<IgnoreListViewItem*>(ignoreListView->currentItem());
+    IgnoreListViewItem* selectedItem=dynamic_cast<IgnoreListViewItem*>(ignoreListView->currentItem());
     if(selectedItem) {
         selectedItem->setFlags(flags);
 	selectedItem->setName(txtPattern->text());
