@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #ifndef NICKLISTBEHAVIOR_CONFIG_H
@@ -22,8 +17,8 @@ class NicklistBehavior_Config : public QWidget, public KonviSettingsPage, privat
     Q_OBJECT
 
     public:
-        explicit NicklistBehavior_Config(QWidget *parent = 0, const char *name = 0);
-        ~NicklistBehavior_Config() override;
+        explicit NicklistBehavior_Config(QWidget *parent = nullptr, const char *name = nullptr);
+        ~NicklistBehavior_Config();
 
         void saveSettings() override;
         void loadSettings() override;
@@ -31,14 +26,17 @@ class NicklistBehavior_Config : public QWidget, public KonviSettingsPage, privat
 
         bool hasChanged() override;
 
-    private:
-        void setNickList(const QString &sortingOrder);
-        QString currentSortingOrder();
-
-        QString m_oldSortingOrder;
-
     Q_SIGNALS:
         void modified();
+
+    private:
+        void setNickList(const QString &sortingOrder);
+        QString currentSortingOrder() const;
+
+    private:
+        QString m_oldSortingOrder;
+
+        Q_DISABLE_COPY(NicklistBehavior_Config)
 };
 
 #endif
