@@ -1,16 +1,11 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Ivor Hewitt <ivor@ivor.org>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2006 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2005 Ivor Hewitt <ivor@ivor.org>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Peter Simonsson <psn@linux.se>
 */
 
 #include "osd_config.h"
@@ -18,12 +13,11 @@
 #include "osd.h"
 #include "application.h"
 
-#include <kcombobox.h>
-#include <kcolorbutton.h>
+#include <KComboBox>
+#include <KColorButton>
 #include <QCheckBox>
-#include <kfontrequester.h>
-#include <QDesktopWidget>
-#include <kconfigdialog.h>
+#include <QScreen>
+#include <KFontRequester>
 
 
 OSD_Config::OSD_Config( QWidget* parent, const char* name, Qt::WindowFlags fl )
@@ -35,9 +29,9 @@ OSD_Config::OSD_Config( QWidget* parent, const char* name, Qt::WindowFlags fl )
     bool enableScreenChooser = false;
     QRect screenRect;
 
-    for(int i = 0; i < QApplication::desktop()->numScreens(); ++i) {
+    for(int i = 0; i < QApplication::screens().count(); ++i) {
         kcfg_OSDScreen->addItem(QString::number(i));
-        screenRect = QApplication::desktop()->screenGeometry(i);
+        screenRect = QApplication::screens()[i]->geometry();
 
         //Check if we're using xinerama or not
         if(screenRect.left() != 0 || screenRect.top() != 0) {
@@ -47,7 +41,7 @@ OSD_Config::OSD_Config( QWidget* parent, const char* name, Qt::WindowFlags fl )
 
     kcfg_OSDScreen->setEnabled(enableScreenChooser);
 
-    m_pOSDPreview = new OSDPreviewWidget("Konversation");
+    m_pOSDPreview = new OSDPreviewWidget(QStringLiteral("Konversation"));
     connect(m_pOSDPreview, &OSDPreviewWidget::positionChanged, this, &OSD_Config::slotPositionChanged);
 
     connect(kcfg_OSDFont, &KFontRequester::fontSelected, this, &OSD_Config::slotUpdateFont);
@@ -67,7 +61,7 @@ OSD_Config::OSD_Config( QWidget* parent, const char* name, Qt::WindowFlags fl )
     connect(kcfg_OSDUseCustomColors, &QGroupBox::toggled, this, &OSD_Config::slotCustomColorsChanged);
     connect(kcfg_OSDTextColor, &KColorButton::changed, this, &OSD_Config::slotTextColorChanged);
     connect(kcfg_OSDBackgroundColor, &KColorButton::changed, this, &OSD_Config::slotBackgroundColorChanged);
-    connect(kcfg_OSDScreen, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &OSD_Config::slotScreenChanged);
+    connect(kcfg_OSDScreen, QOverload<int>::of(&KComboBox::activated), this, &OSD_Config::slotScreenChanged);
     connect(kcfg_OSDDrawShadow, &QCheckBox::toggled, this, &OSD_Config::slotDrawShadowChanged);
 }
 
@@ -87,31 +81,31 @@ void OSD_Config::restorePageToDefaults()
 void OSD_Config::saveSettings()
 {
     //Update the current OSD.
-    Application *konvApp=Application::instance();
+    OSDWidget *osd = Application::instance()->osd();
 
-    konvApp->osd->setEnabled(kcfg_UseOSD->isChecked());
+    osd->setEnabled(kcfg_UseOSD->isChecked());
     if (kcfg_UseOSD->isChecked())
     {
-        konvApp->osd->setFont(Preferences::self()->oSDFont());
+        osd->setFont(Preferences::self()->oSDFont());
         if(kcfg_OSDUseCustomColors->isChecked())
         {
-            konvApp->osd->setTextColor(kcfg_OSDTextColor->color());
-            QPalette p = konvApp->osd->palette();
-            p.setColor(konvApp->osd->backgroundRole(), kcfg_OSDBackgroundColor->color());
-            konvApp->osd->setPalette(p);
+            osd->setTextColor(kcfg_OSDTextColor->color());
+            QPalette p = osd->palette();
+            p.setColor(osd->backgroundRole(), kcfg_OSDBackgroundColor->color());
+            osd->setPalette(p);
         }
         else
         {
-            konvApp->osd->unsetColors();
+            osd->unsetColors();
         }
 
-        konvApp->osd->setDuration(kcfg_OSDDuration->value());
-        konvApp->osd->setScreen(kcfg_OSDScreen->currentIndex());
-        konvApp->osd->setShadow(kcfg_OSDDrawShadow->isChecked());
+        osd->setDuration(kcfg_OSDDuration->value());
+        osd->setScreen(kcfg_OSDScreen->currentIndex());
+        osd->setShadow(kcfg_OSDDrawShadow->isChecked());
 
         //x is ignored anyway, but leave incase we use in future
-        konvApp->osd->setOffset(kcfg_OSDOffsetX->value(), kcfg_OSDOffsetY->value());
-        konvApp->osd->setAlignment((OSDWidget::Alignment)kcfg_OSDAlignment->value());
+        osd->setOffset(kcfg_OSDOffsetX->value(), kcfg_OSDOffsetY->value());
+        osd->setAlignment((OSDWidget::Alignment)kcfg_OSDAlignment->value());
     }
 
 }
