@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #include "tabs_config.h"
@@ -18,7 +13,7 @@ Tabs_Config::Tabs_Config(QWidget *parent, const char *name)
     setObjectName(QString::fromLatin1(name));
     setupUi(this);
 
-    connect(kcfg_TabPlacement, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &Tabs_Config::toggleCheckBoxes);
+    connect(kcfg_TabPlacement, QOverload<int>::of(&KComboBox::activated), this, &Tabs_Config::toggleCheckBoxes);
 }
 
 Tabs_Config::~Tabs_Config()
