@@ -1,45 +1,36 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2007 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2007 Eike Hein <hein@kde.org>
 */
 
 #include "theme_config.h"
+
 #include "preferences_base.h"
 #include "images.h"
 #include "nickiconset.h"
 #include "common.h"
 #include "application.h"
 
-#include <QStringList>
-
-#include <QUrl>
 #include <KMessageBox>
-#include <QFileDialog>
 #include <KTar>
 #include <KZip>
 #include <KDesktopFile>
 #include <KIO/DeleteJob>
 #include <KIO/CopyJob>
-
 #include <KSharedConfig>
+#include <KNSCore/DownloadManager>
+
+#include <QStringList>
+#include <QUrl>
+#include <QFileDialog>
 #include <QStandardPaths>
-#include <QDebug>
 #include <QTemporaryFile>
 #include <QMimeDatabase>
 
-#ifndef Q_OS_WIN
-#include <unistd.h> // unlink()
-#endif
-
 using namespace Konversation;
 
 Theme_Config::Theme_Config(QWidget* parent, const char* name)
@@ -53,9 +44,12 @@ Theme_Config::Theme_Config(QWidget* parent, const char* name)
     // load the current settings
     loadSettings();
 
+    getButton->setConfigFile(QStringLiteral("konversation_nicklist_theme.knsrc"));
+
     connect(iconThemeIndex, &QListWidget::currentRowChanged, this, &Theme_Config::updatePreview);
     connect(iconThemeIndex, &QListWidget::itemSelectionChanged, this, &Theme_Config::updateButtons);
     connect(iconThemeIndex, &QListWidget::itemSelectionChanged, this, &Theme_Config::modified);
+    connect(getButton, &KNS3::Button::dialogFinished, this, &Theme_Config::gotNewSchemes);
     connect(installButton, &QPushButton::clicked, this, &Theme_Config::installTheme);
     connect(removeButton, &QPushButton::clicked, this, &Theme_Config::removeTheme);
 }
@@ -67,16 +61,15 @@ Theme_Config::~Theme_Config()
 void Theme_Config::loadSettings()
 {
     // get list of theme dirs
-    QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konversation/themes/", QStandardPaths::LocateDirectory);
+    const QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konversation/themes/"), QStandardPaths::LocateDirectory);
     m_dirs.clear();
 
-    foreach(const QString& path, paths)
-    {
+    for (const QString& path : paths) {
         QDir dir(path);
 
-        foreach(const QString& themedir, dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot))
-        {
-            QFileInfo file(path + themedir + "/index.desktop");
+        const auto themeDirs = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
+        for (const QString& themedir : themeDirs) {
+            QFileInfo file(path + themedir + QLatin1String("/index.desktop"));
 
             if(file.exists())
             {
@@ -86,8 +79,7 @@ void Theme_Config::loadSettings()
     }
 
     // if we have any themes
-    if (m_dirs.count() > 0)
-    {
+    if (!m_dirs.isEmpty()) {
         m_dirs.sort();
 
         QString themeName, themeComment, themeDir;
@@ -99,15 +91,14 @@ void Theme_Config::loadSettings()
         // initialize index counter
         int i = 0;
         // iterate through all found theme directories
-        for(QStringList::ConstIterator it = m_dirs.constBegin(); it != m_dirs.constEnd(); ++it)
-        {
-            KDesktopFile themeRC(*it);
+        for (const QString& dir : qAsConst(m_dirs)) {
+            KDesktopFile themeRC(dir);
             // get the name and comment from the theme
             themeName = themeRC.readName();
             themeComment = themeRC.readComment();
 
             // extract folder name
-            themeDir=(*it).section('/',-2,-2);
+            themeDir = dir.section(QLatin1Char('/'),-2,-2);
             // is this our currently used theme?
             if (themeDir==currentTheme)
             {
@@ -117,12 +108,12 @@ void Theme_Config::loadSettings()
                 currentThemeIndex = i;
             }
 
-            if (themeDir=="oxygen")
+            if (themeDir==QLatin1String("oxygen"))
                 m_defaultThemeIndex= i;
 
             // if there was a comment to the theme, add it to the listview entry string
             if(!themeComment.isEmpty())
-                themeName = themeName+" ("+themeComment+')';
+                themeName = themeName + QLatin1String(" (") + themeComment + QLatin1Char(')');
 
             // insert entry into the listview
             iconThemeIndex->addItem(themeName);
@@ -137,7 +128,7 @@ void Theme_Config::loadSettings()
     // if there was no currently used theme found, use the default theme
     // If anyone knows how to get the default value from this, please change this!
     if(m_oldTheme.isEmpty())
-        m_oldTheme = "oxygen";
+        m_oldTheme = QStringLiteral("oxygen");
 
     // update enabled/disabled state of buttons
     updateButtons();
@@ -178,6 +169,11 @@ void Theme_Config::restorePageToDefaults()
         iconThemeIndex->setCurrentRow(m_defaultThemeIndex);
 }
 
+void Theme_Config::gotNewSchemes()
+{
+    loadSettings();
+}
+
 void Theme_Config::installTheme()
 {
     QUrl themeURL = QFileDialog::getOpenFileUrl(this,
@@ -188,7 +184,7 @@ void Theme_Config::installTheme()
     if(themeURL.isEmpty())
         return;
 
-    QString themesDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "konversation/themes/");
+    QString themesDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/konversation/themes/"));
     QString tmpThemeFile;
 
     QTemporaryFile tmpFile; // file automatically deleted when object is destroyed
@@ -210,7 +206,7 @@ void Theme_Config::installTheme()
             else
                 errorString = i18n("Unknown error (0)");
 
-            KMessageBox::error(0L,
+            KMessageBox::error(nullptr,
                 errorString,
                 i18n("Failed to Download Theme"),
                 KMessageBox::Notify
@@ -229,14 +225,14 @@ void Theme_Config::installTheme()
 
     if(themeInstallDir.exists()) // We got a directory not a file
     {
-        if(themeInstallDir.exists("index.desktop"))
+        if(themeInstallDir.exists(QStringLiteral("index.desktop")))
         {
             KIO::CopyJob* job = KIO::copy(QUrl(tmpThemeFile), QUrl(themesDir));
             job->exec(); //FIXME error handling
         }
         else
         {
-            KMessageBox::error(0L,
+            KMessageBox::error(nullptr,
                 i18n("Theme archive is invalid."),
                 i18n("Cannot Install Theme"),
                 KMessageBox::Notify
@@ -262,13 +258,11 @@ void Theme_Config::installTheme()
         qApp->processEvents();
 
         const KArchiveDirectory* themeDir = themeArchive->directory();
-        QStringList allEntries = themeDir->entries();
+        const QStringList allEntries = themeDir->entries();
 
-        for(QStringList::ConstIterator it=allEntries.constBegin(); it != allEntries.constEnd(); ++it)
-        {
-            if(themeDir->entry(*it+"/index.desktop") == NULL)
-            {
-                KMessageBox::error(0L,
+        for (const QString& entry : allEntries) {
+            if (themeDir->entry(entry + QLatin1String("/index.desktop")) == nullptr) {
+                KMessageBox::error(nullptr,
                     i18n("Theme archive is invalid."),
                     i18n("Cannot Install Theme"),
                     KMessageBox::Notify
@@ -293,20 +287,53 @@ void Theme_Config::removeTheme()
 
     dir = m_dirs[iconThemeIndex->currentRow()];
 
-    int remove = KMessageBox::warningContinueCancel(0L,
+    int remove = KMessageBox::warningContinueCancel(nullptr,
         i18n("Do you want to remove %1?", themeName),
         i18n("Remove Theme"),
         KStandardGuiItem::del(),KStandardGuiItem::cancel(),
-        "warningRemoveTheme"
+        QStringLiteral("warningRemoveTheme")
         );
 
-    if(remove == KMessageBox::Continue)
-    {
-        QByteArray encoded = QFile::encodeName(dir);
-        unlink(encoded.data());
-        KIO::DeleteJob* job = KIO::del(QUrl::fromLocalFile(dir.remove("index.desktop")));
-        connect(job, &KIO::DeleteJob::result, this, &Theme_Config::postRemoveTheme);
+    if (remove != KMessageBox::Continue) {
+        return;
     }
+
+    dir.chop(QLatin1String("index.desktop").size());
+
+    // Check if theme was installed by KNS, if so uninstall via KNS, otherwise manually
+    auto *manager = new KNSCore::DownloadManager(QStringLiteral("konversation_nicklist_theme.knsrc"), this);
+    connect(manager, &KNSCore::DownloadManager::searchResult,
+            this, [=](const KNSCore::EntryInternal::List &entries) {
+        bool isUninstalledByKNS = false;
+
+        for (auto &entry : entries) {
+            const QStringList installedFiles = entry.installedFiles();
+            for (const QString &file : installedFiles) {
+                // file strings are of pattern "[...]/konversation/themes/simpleminded/*"
+                if (file.startsWith(dir)) {
+                    // uninstall via KNS and be done
+                    manager->uninstallEntry(entry);
+                    isUninstalledByKNS = true;
+                    break;
+                }
+            }
+            if (isUninstalledByKNS) {
+                break;
+            }
+        }
+
+        if (isUninstalledByKNS) {
+            loadSettings();
+        } else {
+            // manually installed, so delete manually
+            KIO::DeleteJob* job = KIO::del(QUrl::fromLocalFile(dir));
+            connect(job, &KIO::DeleteJob::result, this, &Theme_Config::postRemoveTheme);
+        }
+
+        manager->deleteLater();
+    });
+
+    manager->checkForInstalled();
 }
 
 void Theme_Config::postRemoveTheme(KJob* /* delete_job */)
@@ -320,7 +347,7 @@ void Theme_Config::updatePreview(int id)
         return;
     QString dir;
     dir = m_dirs[id];
-    dir.remove("/index.desktop");
+    dir.remove(QStringLiteral("/index.desktop"));
     NickIconSet nickIconSet;
     nickIconSet.load(dir);
 
@@ -347,7 +374,7 @@ void Theme_Config::updateButtons()
     QString dir = m_dirs[iconThemeIndex->currentRow()];
     QFile themeRC(dir);
     // get name for directory
-    m_currentTheme = dir.section('/',-2,-2);
+    m_currentTheme = dir.section(QLatin1Char('/'),-2,-2);
 
     // allow delete action only for themes that have been installed by the user
     if(!themeRC.open(QIODevice::ReadOnly | QIODevice::WriteOnly))
