@@ -1,15 +1,10 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
-  Copyright (C) 2010 Eli Mackenzie <argonel@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2010 Eli Mackenzie <argonel@gmail.com>
 */
 
 
@@ -73,7 +68,7 @@ void Warnings_Config::saveSettings()
         const QString warningName = item->data(0, WarningNameRole).toString();
 
         // save state of this item in hasChanged() list
-        warningsChecked += checked ? "1" : "0";
+        warningsChecked += checked ? QLatin1Char('1') : QLatin1Char('0');
 
         if (warningName == QLatin1String("LargePaste"))
         {
@@ -109,7 +104,7 @@ void Warnings_Config::saveSettings()
                 // else newly unchecked, always join "1"
                 QString state = grp.readEntry(warningName, QString());
 
-                if (state == "2")
+                if (state == QLatin1Char('2'))
                     grp.writeEntry(warningName, state);
                 else
                     grp.writeEntry(warningName, "1");
@@ -129,7 +124,7 @@ void Warnings_Config::loadSettings()
 {
     // This table is very wide, on purpose, so that the nauseatingly constant context string is
     // out of the way. The problem is this:
-    // The context string in I18N_NOOP2_NOSTRIP must always be first, and now that it has
+    // The context string in I18NC_NOOP must always be first, and now that it has
     // semantic markers it is always very long. So, if you want to understand a string
     // definition, you must repeatedly look at the context string. A macro replacement for it
     // is not possible as such recent and complicated inventions are not supported by the tools
@@ -141,79 +136,77 @@ void Warnings_Config::loadSettings()
         const char *context;
         const char *message;
     } warningDialogDefinitions[] = {
-        { "Invitation",                                                                                 I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "Invitation",                                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... a channel invitation is received"
         )},
-        { "SaveLogfileNote",                                                                            I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "SaveLogfileNote",                                                                            I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... saving a log file would save only the visible portion"
         )},
-        { "ClearLogfileQuestion",                                                                       I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "ClearLogfileQuestion",                                                                       I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... a log file is about to be deleted"
         )},
-        { "CloseQueryAfterIgnore",                                                                      I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "CloseQueryAfterIgnore",                                                                      I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... an open query exists for a nickname that has just been marked as ignored"
         )},
-        { "ReconnectWithDifferentServer",                                                               I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "ReconnectWithDifferentServer",                                                               I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... switching a connection to a different server in the same network"
         )},
-        { "ReuseExistingConnection",                                                                    I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "ReuseExistingConnection",                                                                    I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... creating a new connection to an already connected network"
         )},
-        { "QuitServerTab",                                                                              I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "QuitServerTab",                                                                              I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... closing a server tab"
         )},
-        { "QuitChannelTab",                                                                             I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "QuitChannelTab",                                                                             I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... closing a channel tab"
         )},
-        { "QuitQueryTab",                                                                               I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "QuitQueryTab",                                                                               I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... closing a query tab"
         )},
-        { "QuitDCCChatTab",                                                                             I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "QuitDCCChatTab",                                                                             I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... closing a DCC Chat tab"
         )},
-        { "ChannelListNoServerSelected",                                                                I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "ChannelListNoServerSelected",                                                                I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... a source for the channel list cannot be determined from the current tab"
         )},
-        { "HideMenuBarWarning",                                                                         I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "HideMenuBarWarning",                                                                         I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... you have chosen to hide the menu bar"
         )},
-        { "ChannelListWarning",                                                                         I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "ChannelListWarning",                                                                         I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... a channel listing may cause disconnection due to the download size"
         )},
-        { "LargePaste",                                                                                 I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "LargePaste",                                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... pasting large portions of text"
         )},
-        { "systemtrayquitKonversation",                                                                 I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "systemtrayquitKonversation",                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... quitting Konversation via the tray icon"
         )},
-        { "IgnoreNick",                                                                                 I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "IgnoreNick",                                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... you have chosen to ignore a nickname"
         )},
-        { "UnignoreNick",                                                                               I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "UnignoreNick",                                                                               I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... you have chosen to stop ignoring a nickname"
         )},
-        { "QuitWithActiveDccTransfers",                                                                 I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "QuitWithActiveDccTransfers",                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... quitting Konversation while DCC file transfers are active"
         )},
-        { "WarnEncodingConflict",                                                                       I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "WarnEncodingConflict",                                                                       I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... some characters in a message are incompatible with the active encoding"
         )},
-        { "HideOnCloseInfo",                                                                            I18N_NOOP2_NOSTRIP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
+        { "HideOnCloseInfo",                                                                            I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... closing the window will minimize to the system tray"
         )}
     };
-    static const int definitionsCount = sizeof(warningDialogDefinitions) / sizeof(warningDialogDefinitions[0]);
 
     dialogListView->clear();
 
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup grp =  config->group("Notification Messages");
 
-    for (int i = 0; i < definitionsCount; ++i)
-    {
-        const QLatin1String flagName(warningDialogDefinitions[i].flagName);
-        const char * const message(warningDialogDefinitions[i].message);
-        const char * const ctx(warningDialogDefinitions[i].context);
+    for (const auto& warningDialogDefinition : warningDialogDefinitions) {
+        const QLatin1String flagName(warningDialogDefinition.flagName);
+        const char * const message(warningDialogDefinition.message);
+        const char * const ctx(warningDialogDefinition.context);
 
         QTreeWidgetItem *item = new QTreeWidgetItem(dialogListView);
         item->setText(0, i18nc(ctx, message));
@@ -226,7 +219,7 @@ void Warnings_Config::loadSettings()
         }
         else if (flagName == QLatin1String("Invitation"))
         {
-            item->setCheckState(0, grp.readEntry(flagName, QString("0")) == "0" ? Qt::Checked : Qt::Unchecked);
+            item->setCheckState(0, grp.readEntry(flagName, QStringLiteral("0")) == QLatin1Char('0') ? Qt::Checked : Qt::Unchecked);
         }
         else
         {
@@ -241,7 +234,7 @@ void Warnings_Config::loadSettings()
 }
 
 // get a list of checked/unchecked items for hasChanged()
-QString Warnings_Config::currentWarningsChecked()
+QString Warnings_Config::currentWarningsChecked() const
 {
     // prepare list
     QString newList;
@@ -249,7 +242,7 @@ QString Warnings_Config::currentWarningsChecked()
     // get first checklist item
     for (int i = 0; i < dialogListView->topLevelItemCount(); ++i)
     {
-        newList += dialogListView->topLevelItem(i)->checkState(0) == Qt::Checked ? "1" : "0";
+        newList += (dialogListView->topLevelItem(i)->checkState(0) == Qt::Checked) ? QLatin1Char('1') : QLatin1Char('0');
     }
     // return list
     return newList;
