@@ -1,19 +1,15 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
-  Copyright (C) 2004,2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004, 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "chat.h"
+
 #include "dcccommon.h"
 #include "application.h"
 #include "irccharsets.h"
@@ -21,10 +17,10 @@
 #include "upnprouter.h"
 #include "transfermanager.h"
 #include "connectionmanager.h"
+#include "konversation_log.h"
 
 #include <QHostAddress>
 #include <QTextCodec>
-#include <QTextStream>
 #include <QTcpSocket>
 #include <QTcpServer>
 
@@ -40,12 +36,12 @@ namespace Konversation
         Chat::Chat(QObject *parent)
             : QObject(parent),
               m_selfOpened(true),
-              m_dccSocket(0),
-              m_dccServer(0),
+              m_dccSocket(nullptr),
+              m_dccServer(nullptr),
               m_chatStatus(Configuring),
               m_chatExtension(Unknown)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             // set default values
             m_reverse = Preferences::self()->dccPassiveSend();
 
@@ -66,11 +62,11 @@ namespace Konversation
 
             emit aboutToClose();
 
-            m_textStream.setDevice(0);
+            m_textStream.setDevice(nullptr);
 
             if (m_dccServer)
             {
-                disconnect(m_dccServer, 0, 0, 0);
+                disconnect(m_dccServer, nullptr, nullptr, nullptr);
                 m_dccServer->close();
 
                 if (Preferences::self()->dccUPnP())
@@ -81,14 +77,14 @@ namespace Konversation
                         router->undoForward(m_ownPort, QAbstractSocket::TcpSocket);
                     }
                 }
-                m_dccServer = 0;
+                m_dccServer = nullptr;
             }
 
             if (m_dccSocket)
             {
-                disconnect(m_dccSocket, 0, 0, 0);
+                disconnect(m_dccSocket, nullptr, nullptr, nullptr);
                 m_dccSocket->close();
-                m_dccSocket = 0;
+                m_dccSocket = nullptr;
             }
         }
 
@@ -97,7 +93,7 @@ namespace Konversation
             Server *server = serverByConnectionId();
             if (!server)
             {
-                qDebug() << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
+                qCDebug(KONVERSATION_LOG) << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
                 failed(i18nc("%1=dcc extension like Chat or Whiteboard",
                              "Could not send a DCC %1 request to the partner via the IRC server.",
                              localizedExtensionString()));
@@ -108,17 +104,17 @@ namespace Konversation
             {
                 m_ownIp = DccCommon::getOwnIp(server);
             }
-            qDebug() << "ownip: " << m_ownIp;
+            qCDebug(KONVERSATION_LOG) << "ownip: " << m_ownIp;
 
             if (m_selfOpened)
             {
                 //we started the dcc chat
                 if (m_reverse)
                 {
-                    qDebug() << "passive dcc chat";
+                    qCDebug(KONVERSATION_LOG) << "passive dcc chat";
                     int token = Application::instance()->getDccTransferManager()->generateReverseTokenNumber();
                     m_token = QString::number(token);
-                    qDebug() << "token:" << m_token;
+                    qCDebug(KONVERSATION_LOG) << "token:" << m_token;
                     server->dccPassiveChatRequest(m_partnerNick, extensionString(), DccCommon::textIpToNumericalIp(m_ownIp), m_token);
                     setStatus(WaitingRemote, i18n("Awaiting acceptance by remote user..."));
                 }
@@ -148,7 +144,7 @@ namespace Konversation
             {
                 if (!Preferences::self()->dccChatAutoAccept())
                 {
-                    int ret = KMessageBox::questionYesNo(0,
+                    int ret = KMessageBox::questionYesNo(nullptr,
                                                          i18nc("%1=partnerNick, %2=Servername, %3=dcc extension as chat or wboard", "%1 (on %2) offers to DCC %3 with you", m_partnerNick, server->getServerName(), localizedExtensionString()),
                                                          i18nc("%1=dcc extension as Chat or Whiteboard, %2=partnerNick", "DCC %1 offer from %2", localizedExtensionString(), m_partnerNick),
                                                          KGuiItem(i18n("Accept")),
@@ -167,7 +163,7 @@ namespace Konversation
 
                 if (m_reverse)
                 {
-                    qDebug() << "partner1: passive:1";
+                    qCDebug(KONVERSATION_LOG) << "partner1: passive:1";
                     listenForPartner();
                     if (Preferences::self()->dccUPnP())
                     {
@@ -269,7 +265,7 @@ namespace Konversation
 
         void Chat::setStatus(Chat::Status status, const QString &detailMessage)
         {
-            qDebug() << "old: " << m_chatStatus << " != " << status << " :new";
+            qCDebug(KONVERSATION_LOG) << "old: " << m_chatStatus << " != " << status << " :new";
             if (m_chatStatus != status)
             {
                 m_chatDetailedStatus = detailMessage;
@@ -297,7 +293,8 @@ namespace Konversation
                     return;
                 }
 
-                disconnect(this->sender(), SIGNAL(forwardComplete(bool,quint16)), this, SLOT(sendRequest(bool,quint16)));
+                auto* router = qobject_cast<UPnPRouter*>(this->sender());
+                disconnect(router, &UPnPRouter::forwardComplete, this, &Chat::sendRequest);
 
                 if (error)
                 {
@@ -328,7 +325,8 @@ namespace Konversation
                     return;
                 }
 
-                disconnect(this->sender(), SIGNAL(forwardComplete(bool,quint16)), this, SLOT(sendReverseAck(bool,quint16)));
+                auto* router = qobject_cast<UPnPRouter*>(this->sender());
+                disconnect(router, &UPnPRouter::forwardComplete, this, &Chat::sendReverseAck);
 
                 if (error)
                 {
@@ -341,7 +339,7 @@ namespace Konversation
 
         void Chat::listenForPartner()
         {
-            qDebug() << "[BEGIN]";
+            qCDebug(KONVERSATION_LOG) << "[BEGIN]";
 
             // Set up server socket
             QString failedReason;
@@ -364,13 +362,13 @@ namespace Konversation
 
             // Get our own port number
             m_ownPort = m_dccServer->serverPort();
-            qDebug() << "using port: " << m_ownPort ;
+            qCDebug(KONVERSATION_LOG) << "using port: " << m_ownPort ;
 
             setStatus(Chat::WaitingRemote, i18nc("%1=dcc extension like Chat or Whiteboard,%2=partnerNick, %3=port",
                                                  "Offering DCC %1 connection to %2 on port %3...",
                                                  localizedExtensionString(), m_partnerNick, QString::number(m_ownPort)));
 
-            qDebug() << "[END]";
+            qCDebug(KONVERSATION_LOG) << "[END]";
         }
 
         Chat::Status Chat::status() const
@@ -386,17 +384,17 @@ namespace Konversation
         void Chat::setExtension(const QString& extension)
         {
             QString ext = extension.toLower();
-            if (ext == "chat")
+            if (ext == QLatin1String("chat"))
             {
                 m_chatExtension = SimpleChat;
                 return;
             }
-            else if (ext == "wboard")
+            else if (ext == QLatin1String("wboard"))
             {
                 m_chatExtension = Whiteboard;
                 return;
             }
-            qDebug() << "unknown chat extension:" << extension;
+            qCDebug(KONVERSATION_LOG) << "unknown chat extension:" << extension;
             m_chatExtension = Unknown;
             return;
         }
@@ -416,10 +414,10 @@ namespace Konversation
             switch (extension())
             {
                 case Whiteboard:
-                    return "wboard";
+                    return QStringLiteral("wboard");
                 case SimpleChat:
                 default:
-                    return "chat";
+                    return QStringLiteral("chat");
             }
         }
 
@@ -457,9 +455,9 @@ namespace Konversation
 
         void Chat::connectToPartner()
         {
-            //qDebug() << "num: " << m_partnerIp;
+            //qCDebug(KONVERSATION_LOG) << "num: " << m_partnerIp;
             //m_partnerIp = DccCommon::numericalIpToTextIp(m_partnerIp);
-            qDebug() << "partnerIP: " << m_partnerIp << " partnerport: " << m_partnerPort  << " nick: " << m_partnerNick;
+            qCDebug(KONVERSATION_LOG) << "partnerIP: " << m_partnerIp << " partnerport: " << m_partnerPort  << " nick: " << m_partnerNick;
 
             setStatus(Chat::Connecting, i18nc("%1=extension like Chat or Whiteboard ,%2 = nickname, %3 = IP, %4 = port",
                                               "Establishing DCC %1 connection to %2 (%3:%4)...", localizedExtensionString(),
@@ -469,7 +467,11 @@ namespace Konversation
 
             //connect(m_dccSocket, SIGNAL(hostFound()), this, SLOT(lookupFinished()));
             connect(m_dccSocket, &QTcpSocket::connected, this, &Chat::connectionEstablished);
-            connect(m_dccSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &Chat::connectionFailed);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_dccSocket, &QTcpSocket::errorOccurred, this, &Chat::connectionFailed);
+#else
+            connect(m_dccSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &Chat::connectionFailed);
+#endif
             connect(m_dccSocket, &QTcpSocket::readyRead, this, &Chat::readData);
             connect(m_dccSocket, &QTcpSocket::disconnected, this, &Chat::socketClosed);
 
@@ -493,7 +495,7 @@ namespace Konversation
 
         void Chat::readData()
         {
-            char *buffer = 0;
+            char *buffer = nullptr;
             QString line;
             QTextCodec *codec = m_textStream.codec();
             qint64 available = m_dccSocket->bytesAvailable();
@@ -511,9 +513,12 @@ namespace Konversation
                 line = codec->toUnicode(buffer);
                 delete[] buffer;
 
-                const QStringList &lines = line.split('\n', QString::SkipEmptyParts);
-                foreach (const QString &lin, lines)
-                {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                const QStringList &lines = line.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+                const QStringList &lines = line.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
+                for (const QString &lin : lines) {
                     emit receivedRawLine(lin);
                 }
                 available = m_dccSocket->bytesAvailable();
@@ -525,7 +530,7 @@ namespace Konversation
             QString line(action);
             OutputFilter::replaceAliases(line);
 
-            static const QString actionText("\x01""ACTION %2\x01");
+            const QString actionText = QStringLiteral("\x01""ACTION %2\x01");
             sendRawLine(actionText.arg(line));
         }
 
@@ -533,7 +538,11 @@ namespace Konversation
         {
             if (m_dccSocket && m_textStream.device())
             {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+                m_textStream << text << Qt::endl;
+#else
                 m_textStream << text << endl;
+#endif
             }
         }
 
@@ -556,12 +565,15 @@ namespace Konversation
 
             connect(m_dccSocket, &QTcpSocket::readyRead, this, &Chat::readData);
             connect(m_dccSocket, &QTcpSocket::disconnected, this, &Chat::socketClosed);
-            connect(m_dccSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &Chat::connectionFailed);
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_dccSocket, &QTcpSocket::errorOccurred, this, &Chat::connectionFailed);
+#else
+            connect(m_dccSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &Chat::connectionFailed);
+#endif
             // the listen socket isn't needed anymore
-            disconnect(m_dccServer, 0, 0, 0);
+            disconnect(m_dccServer, nullptr, nullptr, nullptr);
             m_dccServer->close();
-            m_dccServer = 0;
+            m_dccServer = nullptr;
 
             if (Preferences::self()->dccUPnP())
             {
