@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "chatcontainer.h"
@@ -18,15 +13,16 @@
 #include <ircviewbox.h>
 #include <topiclabel.h>
 #include <ircview.h>
+#include <notificationhandler.h>
 #include "whiteboard.h"
-
-#include <QSplitter>
+#include "konversation_log.h"
 
 #include <KLocalizedString>
-#include <KActionCollection>
 #include <KMessageBox>
 #include <KStandardGuiItem>
 
+#include <QSplitter>
+
 namespace Konversation
 {
     namespace DCC
@@ -34,11 +30,11 @@ namespace Konversation
         ChatContainer::ChatContainer(QWidget *parent, Chat *chat)
             : ChatWindow(parent),
               m_chat(chat),
-              m_whiteBoard(0)
+              m_whiteBoard(nullptr)
         {
             setType(ChatWindow::DccChat);
             //dcc chat, not used here
-            setServer(0);
+            setServer(nullptr);
             setChannelEncodingSupported(true);
             setPartnerNick(m_chat->partnerNick());
 
@@ -80,9 +76,9 @@ namespace Konversation
             connect(m_inputBar, &IRCInput::submit, this, &ChatContainer::textEntered);
             connect(m_inputBar, &IRCInput::textPasted, this, &ChatContainer::textPasted);
 
-            connect(getTextView(), SIGNAL(textPasted(bool)), m_inputBar, SLOT(paste(bool)));
-            connect(getTextView(), SIGNAL(gotFocus()), m_inputBar, SLOT(setFocus()));
-            connect(getTextView(), SIGNAL(autoText(QString)), this, SLOT(textPasted(QString)));
+            connect(getTextView(), &IRCView::textPasted, m_inputBar, &IRCInput::paste);
+            connect(getTextView(), &IRCView::gotFocus, m_inputBar, QOverload<>::of(&IRCInput::setFocus));
+            connect(getTextView(), &IRCView::autoText, this, &ChatContainer::textPasted);
 
             updateAppearance();
         }
@@ -92,17 +88,17 @@ namespace Konversation
             if (m_chat)
             {
                 //Do not delete the chat, its the transfermanagers job
-                disconnect(m_chat, 0, 0, 0);
+                disconnect(m_chat, nullptr, nullptr, nullptr);
                 m_chat->close();
                 m_chat->removedFromView();
-                m_chat = 0;
+                m_chat = nullptr;
             }
         }
 
         void ChatContainer::chatStatusChanged(Chat *chat, Konversation::DCC::Chat::Status newstatus, Konversation::DCC::Chat::Status oldstatus)
         {
-            Q_UNUSED(oldstatus);
-            Q_UNUSED(chat);
+            Q_UNUSED(oldstatus)
+            Q_UNUSED(chat)
 
             Q_ASSERT(newstatus != oldstatus);
             Q_ASSERT(m_chat == chat);
@@ -145,8 +141,8 @@ namespace Konversation
 
         void ChatContainer::setPartnerNick (const QString &nick)
         {
-            ChatWindow::setName('-' + nick + '-');
-            ChatWindow::setLogfileName('-' + nick + '-');
+            ChatWindow::setName(QLatin1Char('-') + nick + QLatin1Char('-'));
+            ChatWindow::setLogfileName(QLatin1Char('-') + nick + QLatin1Char('-'));
             m_chat->setPartnerNick(nick);
         }
 
@@ -155,7 +151,7 @@ namespace Konversation
             return m_chat->ownNick();
         }
 
-        bool ChatContainer::canBeFrontView()
+        bool ChatContainer::canBeFrontView() const
         {
             return true;
         }
@@ -185,7 +181,7 @@ namespace Konversation
                                                                   "Close DCC %1", m_chat->localizedExtensionString()),
                                                             KStandardGuiItem::close(),
                                                             KStandardGuiItem::cancel(),
-                                                            "QuitDCCChatTab");
+                                                            QStringLiteral("QuitDCCChatTab"));
 
                 if (result == KMessageBox::Continue)
                 {
@@ -198,7 +194,7 @@ namespace Konversation
 
         void ChatContainer::emitUpdateInfo()
         {
-            //qDebug();
+            //qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             QString info;
             if (m_chat && m_chat->partnerNick() == m_chat->ownNick())
                 info = i18n("Talking to yourself");
@@ -210,17 +206,17 @@ namespace Konversation
             emit updateInfo(info);
         }
 
-        QString ChatContainer::getChannelEncoding()
+        QString ChatContainer::getChannelEncoding() const
         {
             return m_chat->getEncoding();
         }
 
-        QString ChatContainer::getChannelEncodingDefaultDesc()
+        QString ChatContainer::getChannelEncodingDefaultDesc() const
         {
             return i18nc("%1=Encoding","Default ( %1 )", Konversation::IRCCharsets::self()->encodingForLocale());
         }
 
-        bool ChatContainer::searchView()
+        bool ChatContainer::searchView() const
         {
             return true;
         }
@@ -242,16 +238,14 @@ namespace Konversation
             const QString &cc = Preferences::self()->commandChar();
             if (line.startsWith(cc))
             {
-                QString cmd = line.section(' ', 0, 0).toLower();
-                qDebug() << "cmd" << cmd;
-                if (cmd == cc + "clear")
-                {
+                const QString cmd = line.section(QLatin1Char(' '), 0, 0).toLower();
+                qCDebug(KONVERSATION_LOG) << "cmd" << cmd;
+                if (cmd == cc + QLatin1String("clear")) {
                     textView->clear();
                 }
-                else if (cmd == cc + "me")
-                {
-                    QString toSend = line.section(' ', 1);
-                    //qDebug() << "toSend" << toSend;
+                else if (cmd == cc + QLatin1String("me")) {
+                    const QString toSend = line.section(QLatin1Char(' '), 1);
+                    //qCDebug(KONVERSATION_LOG) << "toSend" << toSend;
                     if (toSend.isEmpty())
                     {
                         getTextView()->appendServerMessage(i18n("Usage"), i18n("Usage: %1ME text", Preferences::self()->commandChar()));
@@ -262,8 +256,7 @@ namespace Konversation
                         appendAction(m_chat->ownNick(), toSend);
                     }
                 }
-                else if (cmd == cc + "close")
-                {
+                else if (cmd == cc + QLatin1String("close")) {
                     closeYourself(false);
                 }
                 else
@@ -285,10 +278,13 @@ namespace Konversation
                 return;
             }
 
-            const QStringList lines = sterilizeUnicode(text.split('\n', QString::SkipEmptyParts));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            const QStringList lines = sterilizeUnicode(text.split(QLatin1Char('\n'), QString::SkipEmptyParts));
+#else
+            const QStringList lines = sterilizeUnicode(text.split(QLatin1Char('\n'), Qt::SkipEmptyParts));
+#endif
 
-            foreach (const QString &line, lines)
-            {
+            for (const QString &line : lines) {
                 m_chat->sendText(line);
                 getTextView()->append(m_chat->ownNick(), line);
             }
@@ -297,16 +293,15 @@ namespace Konversation
         void ChatContainer::receivedLine(const QString &_line)
         {
             const QString line(sterilizeUnicode(_line));
-            if (line.startsWith('\x01'))
-            {
+            if (line.startsWith(QLatin1Char('\x01'))) {
                 // cut out the CTCP command
                 const QString ctcp = line.mid(1, line.indexOf(1, 1) - 1);
 
-                const QString ctcpCommand = ctcp.section(' ', 0, 0);
-                QString ctcpArgument(ctcp.section(' ', 1));
+                const QString ctcpCommand = ctcp.section(QLatin1Char(' '), 0, 0);
+                QString ctcpArgument = ctcp.section(QLatin1Char(' '), 1);
                 OutputFilter::replaceAliases(ctcpArgument);
 
-                if (ctcpCommand.toLower() == "action")
+                if (ctcpCommand.toLower() == QLatin1String("action"))
                 {
                     appendAction(m_chat->partnerNick(), ctcpArgument);
                 }
@@ -322,6 +317,22 @@ namespace Konversation
             else
             {
                 getTextView()->append(m_chat->partnerNick(), line);
+
+                QRegExp regexp(QStringLiteral("(^|[^\\d\\w])") +
+                        QRegExp::escape(m_chat->ownNick()) +
+                        QStringLiteral("([^\\d\\w]|$)"));
+                regexp.setCaseSensitivity(Qt::CaseInsensitive);
+
+                if(line.contains(regexp))
+                {
+                    Application::instance()->notificationHandler()->nick(this,
+                            m_chat->partnerNick(), line);
+                }
+                else
+                {
+                    Application::instance()->notificationHandler()->message(this,
+                            m_chat->partnerNick(), line);
+                }
             }
         }
     }
