@@ -1,18 +1,15 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "dcccommon.h"
+
 #include "preferences.h"
 #include "server.h"
+#include "konversation_log.h"
 
 #include <config-konversation.h>
 
@@ -52,7 +49,7 @@ namespace Konversation
                 return ip.toString();
 
             default:
-                qDebug() << "unspported protocol: " << ipString;
+                qCDebug(KONVERSATION_LOG) << "unsupported protocol: " << ipString;
                 return QString();
             }
         }
@@ -62,8 +59,7 @@ namespace Konversation
             QHostAddress ip;
 
             //Only IPV6 can contain ':'
-            if (numericalIp.contains(':'))
-            {
+            if (numericalIp.contains(QLatin1Char(':'))) {
                 return numericalIp;
             }
             //ipv4 comes as numericalip
@@ -101,7 +97,7 @@ namespace Konversation
                 ownIp = server->getOwnIpByNetworkInterface();
             }
 
-            qDebug() << ownIp;
+            qCDebug(KONVERSATION_LOG) << ownIp;
             return ownIp;
         }
 
@@ -117,18 +113,19 @@ namespace Konversation
                 const QByteArray addressBa = Preferences::self()->dccIPv4FallbackIface().toLatin1();
                 const char* address = addressBa.constData();
                 int sock = socket(AF_INET, SOCK_DGRAM, 0);
-                strncpy(ifr.ifr_name, address, IF_NAMESIZE);
+                strncpy(ifr.ifr_name, address, IF_NAMESIZE - 1);
+                ifr.ifr_name[IF_NAMESIZE - 1] = '\0';
                 ifr.ifr_addr.sa_family = AF_INET;
 
                 if (ioctl( sock, SIOCGIFADDR, &ifr ) >= 0)
                 {
                     struct sockaddr_in sock;
                     memcpy(&sock, &ifr.ifr_addr, sizeof(ifr.ifr_addr));
-                    fallbackIp = inet_ntoa(sock.sin_addr);
+                    fallbackIp = QString::fromLatin1(inet_ntoa(sock.sin_addr));
                 }
-                qDebug() << "Falling back to IPv4 address " << fallbackIp;
+                qCDebug(KONVERSATION_LOG) << "Falling back to IPv4 address " << fallbackIp;
 #else
-                qDebug() << "TODO: implement ipv6 fallback";
+                qCDebug(KONVERSATION_LOG) << "TODO: implement ipv6 fallback";
 #endif
             }
             return fallbackIp;
@@ -154,7 +151,7 @@ namespace Konversation
                     if ( failedReason )
                         *failedReason = i18n( "No vacant port" );
                     delete socket;
-                    return 0;
+                    return nullptr;
                 }
             }
             else
@@ -165,7 +162,7 @@ namespace Konversation
                     if ( failedReason )
                         *failedReason = i18n( "Could not open a socket" );
                     delete socket;
-                    return 0;
+                    return nullptr;
                 }
             }
 
