@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2011 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2011 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef DCCFILEDIALOG_H
@@ -20,13 +15,14 @@ class KFileWidget;
 
 class DccFileDialog : public QDialog
 {
+    Q_OBJECT
 
 public:
     DccFileDialog(QWidget* parent);
 
     QList<QUrl> getOpenUrls(const QUrl &startDir = QUrl(), const QString& filter = QString(), const QString& caption = QString());
 
-    bool passiveSend();
+    bool passiveSend() const;
 
     QSize sizeHint() const override;
 
