@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef TRANSFERDETAILEDINFOPANEL_H
@@ -31,8 +26,8 @@ namespace Konversation
             Q_OBJECT
 
             public:
-                explicit TransferDetailedInfoPanel(QWidget *parent = 0);
-                ~TransferDetailedInfoPanel() override;
+                explicit TransferDetailedInfoPanel(QWidget *parent = nullptr);
+                virtual ~TransferDetailedInfoPanel();
 
                 void setTransfer(Transfer *item);
                 Transfer *transfer() const;
@@ -51,6 +46,8 @@ namespace Konversation
 
                 Transfer *m_transfer;
                 QTimer *m_autoViewUpdateTimer;
+
+                Q_DISABLE_COPY(TransferDetailedInfoPanel)
         };
     }
 }
