@@ -1,19 +1,13 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
-#include <QDir>
-
 #include "transfermanager.h"
+
 #include "transferrecv.h"
 #include "transfersend.h"
 #include "application.h"
@@ -22,6 +16,9 @@
 #include "upnprouter.h"
 #include "transfer.h"
 #include "chat.h"
+#include "konversation_log.h"
+
+#include <QDir>
 
 using namespace Konversation::UPnP;
 
@@ -37,11 +34,11 @@ namespace Konversation
 
             m_defaultIncomingFolder = Preferences::self()->dccPath();
 
-            connect( Application::instance(), SIGNAL(appearanceChanged()),
-                     this, SLOT(slotSettingsChanged()) );
+            connect( Application::instance(), &Application::appearanceChanged,
+                     this, &TransferManager::slotSettingsChanged );
 
-            m_upnpRouter = 0;
-            m_upnpSocket = 0;
+            m_upnpRouter = nullptr;
+            m_upnpSocket = nullptr;
 
             if (Preferences::self()->dccUPnP())
                 startupUPnP();
@@ -49,17 +46,17 @@ namespace Konversation
 
         TransferManager::~TransferManager()
         {
-            qDebug();
-            foreach (TransferSend* sendItem, m_sendItems)
-            {
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
+            const auto currentSendItems = m_sendItems;
+            for (TransferSend* sendItem : currentSendItems) {
                 sendItem->abort();
             }
-            foreach (TransferRecv* recvItem, m_recvItems)
-            {
+            const auto currentRecvItems = m_recvItems;
+            for (TransferRecv* recvItem : currentRecvItems) {
                 recvItem->abort();
             }
-            foreach (Chat* chatItem, m_chatItems)
-            {
+            const auto currentChatItems = m_chatItems;
+            for (Chat* chatItem : currentChatItems) {
                 chatItem->close();
             }
 
@@ -81,7 +78,7 @@ namespace Konversation
             shutdownUPnP();
         }
 
-        void TransferManager::startupUPnP(void)
+        void TransferManager::startupUPnP()
         {
             m_upnpSocket = new UPnPMCastSocket();
 
@@ -90,12 +87,12 @@ namespace Konversation
             m_upnpSocket->discover();
         }
 
-        void TransferManager::shutdownUPnP(void)
+        void TransferManager::shutdownUPnP()
         {
             // This deletes the router too.
             delete m_upnpSocket;
-            m_upnpSocket = 0;
-            m_upnpRouter = 0;
+            m_upnpSocket = nullptr;
+            m_upnpRouter = nullptr;
         }
 
         TransferRecv* TransferManager::newDownload()
@@ -126,18 +123,17 @@ namespace Konversation
 
         TransferSend* TransferManager::rejectSend(int connectionId, const QString& partnerNick, const QString& fileName)
         {
-            TransferSend* transfer = 0;
+            TransferSend* transfer = nullptr;
 
             // find applicable one
-            foreach (TransferSend* it, m_sendItems )
-            {
+            for (TransferSend* it : qAsConst(m_sendItems)) {
                 if ( ( it->getStatus() == Transfer::Queued || it->getStatus() == Transfer::WaitingRemote ) &&
                     it->getConnectionId() == connectionId &&
                     it->getPartnerNick() == partnerNick &&
                     it->getFileName() == fileName )
                 {
                     transfer = it;
-                    qDebug() << "Filename match: " << fileName;
+                    qCDebug(KONVERSATION_LOG) << "Filename match: " << fileName;
                     break;
                 }
             }
@@ -150,11 +146,10 @@ namespace Konversation
 
         Chat* TransferManager::rejectChat(int connectionId, const QString& partnerNick)
         {
-            Chat* chat = 0;
+            Chat* chat = nullptr;
 
             // find applicable one
-            foreach (Chat* it, m_chatItems)
-            {
+            for (Chat* it : qAsConst(m_chatItems)) {
                 if (it->status() == Chat::WaitingRemote &&
                     it->connectionId() == connectionId &&
                     it->partnerNick() == partnerNick)
@@ -172,11 +167,10 @@ namespace Konversation
 
         TransferRecv* TransferManager::resumeDownload( int connectionId, const QString& partnerNick, const QString& fileName, quint16 ownPort, quint64 position )
         {
-            TransferRecv* transfer = 0;
+            TransferRecv* transfer = nullptr;
 
             // find applicable one
-            foreach (TransferRecv* it, m_recvItems )
-            {
+            for (TransferRecv* it : qAsConst(m_recvItems)) {
                 if ( ( it->getStatus() == Transfer::Queued || it->getStatus() == Transfer::WaitingRemote ) &&
                     it->getConnectionId() == connectionId &&
                     it->getPartnerNick() == partnerNick &&
@@ -184,7 +178,7 @@ namespace Konversation
                     it->isResumed() )
                 {
                     transfer = it;
-                    qDebug() << "Filename match: " << fileName << ", claimed port: " << ownPort << ", item port: " << transfer->getOwnPort();
+                    qCDebug(KONVERSATION_LOG) << "Filename match: " << fileName << ", claimed port: " << ownPort << ", item port: " << transfer->getOwnPort();
                     // the port number can be changed behind NAT, so we pick an item which only the filename is correspondent in that case.
                     if ( transfer->getOwnPort() == ownPort )
                     {
@@ -201,11 +195,10 @@ namespace Konversation
 
         TransferSend* TransferManager::resumeUpload( int connectionId, const QString& partnerNick, const QString& fileName, quint16 ownPort, quint64 position )
         {
-            TransferSend* transfer = 0;
+            TransferSend* transfer = nullptr;
 
             // find applicable one
-            foreach ( TransferSend* it, m_sendItems )
-            {
+            for (TransferSend* it : qAsConst(m_sendItems)) {
                 if ( ( it->getStatus() == Transfer::Queued || it->getStatus() == Transfer::WaitingRemote ) &&
                     it->getConnectionId() == connectionId &&
                     it->getPartnerNick() == partnerNick &&
@@ -213,7 +206,7 @@ namespace Konversation
                     !it->isResumed() )
                 {
                     transfer = it;
-                    qDebug() << "Filename match: " << fileName << ", claimed port: " << ownPort << ", item port: " << transfer->getOwnPort();
+                    qCDebug(KONVERSATION_LOG) << "Filename match: " << fileName << ", claimed port: " << ownPort << ", item port: " << transfer->getOwnPort();
                     // the port number can be changed behind NAT, so we pick an item which only the filename is correspondent in that case.
                     if ( transfer->getOwnPort() == ownPort )
                     {
@@ -230,12 +223,11 @@ namespace Konversation
 
         TransferSend* TransferManager::startReverseSending( int connectionId, const QString& partnerNick, const QString& fileName, const QString& partnerHost, quint16 partnerPort, quint64 fileSize, const QString& token )
         {
-            qDebug() << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", filename: " << fileName << ", partner IP: " << partnerHost << ", parnter port: " << partnerPort << ", filesize: " << fileSize << ", token: " << token;
-            TransferSend* transfer = 0;
+            qCDebug(KONVERSATION_LOG) << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", filename: " << fileName << ", partner IP: " << partnerHost << ", parnter port: " << partnerPort << ", filesize: " << fileSize << ", token: " << token;
+            TransferSend* transfer = nullptr;
 
             // find applicable one
-            foreach ( TransferSend* it, m_sendItems )
-            {
+            for (TransferSend* it : qAsConst(m_sendItems)) {
                 if (
                     it->getStatus() == Transfer::WaitingRemote &&
                     it->getConnectionId() == connectionId &&
@@ -259,12 +251,11 @@ namespace Konversation
 
         Chat* TransferManager::startReverseChat(int connectionId, const QString& partnerNick, const QString& partnerHost, quint16 partnerPort, const QString& token)
         {
-            qDebug() << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", partner IP: " << partnerHost << ", parnter port: " << partnerPort << ", token: " << token;
-            Chat* chat = 0;
+            qCDebug(KONVERSATION_LOG) << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", partner IP: " << partnerHost << ", parnter port: " << partnerPort << ", token: " << token;
+            Chat* chat = nullptr;
 
             // find applicable one
-            foreach (Chat* it, m_chatItems)
-            {
+            for (Chat* it :qAsConst(m_chatItems)) {
                 if (
                     it->status() == Chat::WaitingRemote &&
                     it->connectionId() == connectionId &&
@@ -289,13 +280,13 @@ namespace Konversation
 
         void TransferManager::acceptDccGet(int connectionId, const QString& partnerNick, const QString& fileName)
         {
-            qDebug() << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", filename: " << fileName;
+            qCDebug(KONVERSATION_LOG) << "Server group ID: " << connectionId << ", partner: " << partnerNick << ", filename: " << fileName;
 
             bool nickEmpty = partnerNick.isEmpty();
             bool fileEmpty = fileName.isEmpty();
 
-            foreach ( TransferRecv* it, m_recvItems )
-            {
+            const auto currentRecvItems = m_recvItems;
+            for (TransferRecv* it : currentRecvItems) {
                 if (
                     it->getStatus() == Transfer::Queued &&
                     it->getConnectionId() == connectionId &&
@@ -317,8 +308,7 @@ namespace Konversation
 
         bool TransferManager::isLocalFileInWritingProcess( const QUrl &url ) const
         {
-            foreach ( TransferRecv* it, m_recvItems )
-            {
+            for (TransferRecv* it : m_recvItems) {
                 if ( ( it->getStatus() == Transfer::Connecting ||
                        it->getStatus() == Transfer::Transferring ) &&
                     it->getFileURL() == url )
@@ -334,16 +324,14 @@ namespace Konversation
             return m_nextReverseTokenNumber++;
         }
 
-        bool TransferManager::hasActiveTransfers()
+        bool TransferManager::hasActiveTransfers() const
         {
-            foreach ( TransferSend* it, m_sendItems )
-            {
+            for (TransferSend* it : m_sendItems) {
                 if (it->getStatus() == Transfer::Transferring)
                     return true;
             }
 
-            foreach ( TransferRecv* it, m_recvItems )
-            {
+            for (TransferRecv* it : m_recvItems) {
                 if (it->getStatus() == Transfer::Transferring)
                     return true;
             }
@@ -351,10 +339,9 @@ namespace Konversation
             return false;
         }
 
-        bool TransferManager::hasActiveChats()
+        bool TransferManager::hasActiveChats() const
         {
-            foreach (Chat* chat, m_chatItems)
-            {
+            for (Chat* chat : m_chatItems) {
                 if (chat->status() == Chat::Chatting)
                     return true;
             }
@@ -363,7 +350,7 @@ namespace Konversation
 
         void TransferManager::slotTransferStatusChanged( Transfer* item, int newStatus, int oldStatus )
         {
-            qDebug() << oldStatus << " -> " << newStatus << " " << item->getFileName() << " (" << item->getType() << ")";
+            qCDebug(KONVERSATION_LOG) << oldStatus << " -> " << newStatus << " " << item->getFileName() << " (" << item->getType() << ")";
 
             if ( newStatus == Transfer::Queued )
                 emit newDccTransferQueued( item );
@@ -374,8 +361,7 @@ namespace Konversation
             // update the default incoming directory for already existed DCCRECV items
             if ( Preferences::self()->dccPath() != m_defaultIncomingFolder )
             {
-                foreach ( TransferRecv* it, m_recvItems )
-                {
+                for (TransferRecv* it : qAsConst(m_recvItems)) {
                     if ( it->getStatus() == Transfer::Queued &&
                          it->getFileURL().adjusted(QUrl::RemoveFilename) == m_defaultIncomingFolder.adjusted(QUrl::RemoveFilename))
                     {
@@ -392,14 +378,14 @@ namespace Konversation
 
         void TransferManager::removeSendItem( Transfer* item )
         {
-            TransferSend* transfer = static_cast< TransferSend* > ( item );
+            TransferSend* transfer = qobject_cast< TransferSend* > ( item );
             m_sendItems.removeOne( transfer );
             item->deleteLater();
         }
 
         void TransferManager::removeRecvItem( Transfer* item )
         {
-            TransferRecv* transfer = static_cast< TransferRecv* > ( item );
+            TransferRecv* transfer = qobject_cast< TransferRecv* > ( item );
             m_recvItems.removeOne( transfer );
             item->deleteLater();
         }
@@ -412,13 +398,13 @@ namespace Konversation
 
         void TransferManager::upnpRouterDiscovered(UPnPRouter *router)
         {
-            qDebug() << "Router discovered!";
+            qCDebug(KONVERSATION_LOG) << "Router discovered!";
 
             // Assuming only 1 router for now
             m_upnpRouter = router;
         }
 
-        UPnPRouter* TransferManager::getUPnPRouter()
+        UPnPRouter* TransferManager::getUPnPRouter() const
         {
             return m_upnpRouter;
         }
