@@ -1,18 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Mit Aug 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
-*/
-/*
-  Copyright (C) 2004-2008 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009,2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004-2008 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009, 2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "transferpanel.h"
@@ -26,9 +17,9 @@
 
 #include <QSplitter>
 
+#include <KIO/OpenFileManagerWindowJob>
 #include <KMessageBox>
 #include <QMenu>
-#include <KRun>
 #include <KAuthorized>
 #include <KToolBar>
 #include <KSharedConfig>
@@ -45,30 +36,30 @@ namespace Konversation
 
             initGUI();
 
-            connect(Application::instance()->getDccTransferManager(), SIGNAL(newTransferAdded(Konversation::DCC::Transfer*)),
-                    this, SLOT(slotNewTransferAdded(Konversation::DCC::Transfer*)));
+            connect(Application::instance()->getDccTransferManager(), &TransferManager::newTransferAdded,
+                    this, &TransferPanel::slotNewTransferAdded);
         }
 
         TransferPanel::~TransferPanel()
         {
             KConfigGroup config(KSharedConfig::openConfig(), "DCC Settings");
             const QByteArray state = m_splitter->saveState();
-            config.writeEntry(QString("PanelSplitter"), state.toBase64());
+            config.writeEntry(QStringLiteral("PanelSplitter"), state.toBase64());
         }
 
         void TransferPanel::initGUI()
         {
             setSpacing(0);
             m_toolBar = new KToolBar(this, true, true);
-            m_toolBar->setObjectName("dccstatus_toolbar");
+            m_toolBar->setObjectName(QStringLiteral("dccstatus_toolbar"));
 
             m_splitter = new QSplitter(this);
             m_splitter->setOrientation(Qt::Vertical);
 
             m_transferView = new TransferView(m_splitter);
 
-            connect(m_transferView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                    this, SLOT(updateButton()));
+            connect(m_transferView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                    this, &TransferPanel::updateButton);
             connect(m_transferView, &TransferView::runSelectedTransfers, this, &TransferPanel::runDcc);
 
             // detailed info panel
@@ -78,23 +69,23 @@ namespace Konversation
 
             // popup menu
             m_popup = new QMenu(this);
-            m_selectAll =  m_popup->addAction(i18n("&Select All Items"), this, SLOT(selectAll()));
-            m_selectAllCompleted = m_popup->addAction(i18n("S&elect All Completed Items"), this, SLOT(selectAllCompleted()));
+            m_selectAll =  m_popup->addAction(i18n("&Select All Items"), this, &TransferPanel::selectAll);
+            m_selectAllCompleted = m_popup->addAction(i18n("S&elect All Completed Items"), this, &TransferPanel::selectAllCompleted);
             m_popup->addSeparator();                           // -----
-            m_accept =  m_popup->addAction(QIcon::fromTheme("media-playback-start"), i18n("&Accept"), this, SLOT(acceptDcc()));
+            m_accept =  m_popup->addAction(QIcon::fromTheme(QStringLiteral("media-playback-start")), i18n("&Accept"), this, &TransferPanel::acceptDcc);
             m_accept->setStatusTip(i18n("Start receiving"));
-            m_abort = m_popup->addAction(QIcon::fromTheme("process-stop"),i18n("A&bort"), this, SLOT(abortDcc()));
+            m_abort = m_popup->addAction(QIcon::fromTheme(QStringLiteral("process-stop")),i18n("A&bort"), this, &TransferPanel::abortDcc);
             m_abort->setStatusTip(i18n("Abort the transfer(s)"));
             m_popup->addSeparator();                           // -----
-            m_resend = m_popup->addAction(QIcon::fromTheme("edit-redo"),i18n("Resend"), this, SLOT(resendFile()));
-            m_clear = m_popup->addAction(QIcon::fromTheme("edit-delete"),i18nc("clear selected dcctransfer","&Clear"), this, SLOT(clearDcc()));
+            m_resend = m_popup->addAction(QIcon::fromTheme(QStringLiteral("edit-redo")),i18n("Resend"), this, &TransferPanel::resendFile);
+            m_clear = m_popup->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),i18nc("clear selected dcctransfer","&Clear"), this, &TransferPanel::clearDcc);
             m_clear->setStatusTip(i18n("Clear all selected Items"));
-            m_clearCompleted = m_popup->addAction(QIcon::fromTheme("edit-clear-list"),i18n("Clear Completed"), this, SLOT(clearCompletedDcc()));
+            m_clearCompleted = m_popup->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-list")),i18n("Clear Completed"), this, &TransferPanel::clearCompletedDcc);
             m_clearCompleted->setStatusTip(i18n("Clear Completed Items"));
             m_popup->addSeparator();                           // -----
-            m_open = m_popup->addAction(QIcon::fromTheme("system-run"), i18n("&Open File"), this, SLOT(runDcc()));
+            m_open = m_popup->addAction(QIcon::fromTheme(QStringLiteral("system-run")), i18n("&Open File"), this, &TransferPanel::runDcc);
             m_open->setStatusTip(i18n("Run the file"));
-            m_openLocation = m_popup->addAction(QIcon::fromTheme("document-open-folder"), i18n("Open Location"), this, SLOT(openLocation()));
+            m_openLocation = m_popup->addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Location"), this, QOverload<>::of(&TransferPanel::openLocation));
             m_openLocation->setStatusTip(i18n("Open the file location"));
 
             m_transferView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -102,8 +93,8 @@ namespace Konversation
 
             // misc.
             connect(m_transferView, &TransferView::doubleClicked, this, &TransferPanel::doubleClicked);
-            connect(m_transferView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                    this, SLOT(setDetailPanelItem(QItemSelection,QItemSelection)));
+            connect(m_transferView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                    this, &TransferPanel::setDetailPanelItem);
 
             m_toolBar->addAction(m_accept);
             m_toolBar->addAction(m_abort);
@@ -126,7 +117,7 @@ namespace Konversation
 
         void TransferPanel::slotNewTransferAdded(Transfer *transfer)
         {
-            connect(transfer, SIGNAL(statusChanged(Konversation::DCC::Transfer*,int,int)), this, SLOT(slotTransferStatusChanged()));
+            connect(transfer, &Transfer::statusChanged, this, &TransferPanel::slotTransferStatusChanged);
             m_transferView->addTransfer(transfer);
             if (m_transferView->itemCount() == 1)
             {
@@ -155,8 +146,8 @@ namespace Konversation
                  selectAllCompleted = false;
 
             QItemSelectionModel *selectionModel = m_transferView->selectionModel();
-            foreach (const QModelIndex &index, m_transferView->rowIndexes())
-            {
+            const auto rowIndices = m_transferView->rowIndexes();
+            for (const QModelIndex &index : rowIndices) {
                 Transfer::Type type = (Transfer::Type)index.data(TransferListModel::TransferType).toInt();
                 Transfer::Status status = (Transfer::Status)index.data(TransferListModel::TransferStatus).toInt();
 
@@ -184,7 +175,7 @@ namespace Konversation
                 }
             }
 
-            if (!KAuthorized::authorizeAction("allow_downloading"))
+            if (!KAuthorized::authorizeAction(QStringLiteral("allow_downloading")))
             {
                 accept = false;
             }
@@ -215,7 +206,7 @@ namespace Konversation
 
             if (index.isValid())
             {
-                Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                 if (transfer)
                 {
                     m_detailPanel->setTransfer(transfer);
@@ -225,12 +216,12 @@ namespace Konversation
 
         void TransferPanel::acceptDcc()
         {
-            foreach (const QModelIndex &index, m_transferView->selectedRows())
-            {
+            const auto selectedRowIndices = m_transferView->selectedRows();
+            for (const QModelIndex &index : selectedRowIndices) {
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Receive &&
                     index.data(TransferListModel::TransferStatus).toInt() == Transfer::Queued)
                 {
-                    Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->start();
@@ -242,11 +233,11 @@ namespace Konversation
 
         void TransferPanel::abortDcc()
         {
-            foreach (const QModelIndex &index, m_transferView->selectedRows())
-            {
+            const auto selectedRowIndices = m_transferView->selectedRows();
+            for (const QModelIndex &index : selectedRowIndices) {
                 if (index.data(TransferListModel::TransferStatus).toInt() < Transfer::Done)
                 {
-                    Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->abort();
@@ -259,12 +250,12 @@ namespace Konversation
         void TransferPanel::resendFile()
         {
             QList<Transfer*> transferList;
-            foreach (const QModelIndex &index, m_transferView->selectedRows())
-            {
+            const auto selectedRowIndices = m_transferView->selectedRows();
+            for (const QModelIndex &index : selectedRowIndices) {
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Send &&
                     index.data(TransferListModel::TransferStatus).toInt() >= Transfer::Done)
                 {
-                    Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (!transfer)
                     {
                         continue;
@@ -273,8 +264,7 @@ namespace Konversation
                 }
             }
 
-            foreach (Transfer* transfer, transferList)
-            {
+            for (Transfer* transfer : qAsConst(transferList)) {
                 TransferSend *newTransfer = Application::instance()->getDccTransferManager()->newUpload();
 
                 newTransfer->setConnectionId(transfer->getConnectionId());
@@ -303,14 +293,13 @@ namespace Konversation
             if (transfer && transfer->getStatus() >= Transfer::Done)
             {
                 //item will be gone
-                transfer = 0;
+                transfer = nullptr;
             }
 
             QModelIndexList indexes = m_transferView->selectedRows();
             QModelIndexList indexesToRemove;
 
-            foreach (const QModelIndex &index, indexes)
-            {
+            for (const QModelIndex &index : qAsConst(indexes)) {
                 if (index.data(TransferListModel::TransferStatus).toInt() >= Transfer::Done)
                 {
                     indexesToRemove.append(index);
@@ -322,8 +311,7 @@ namespace Konversation
             std::sort(indexesToRemove.begin(), indexesToRemove.end(), rowGreaterThan);
 
             //remove from last to first item, to keep a valid row
-            foreach (const QModelIndex &index, indexesToRemove)
-            {
+            for (const QModelIndex &index : qAsConst(indexesToRemove)) {
                 m_transferView->model()->removeRow(index.row(), QModelIndex());
                 //needed, otherwise valid rows "can be treated" as invalid,
                 //proxymodel does not keep up with changes
@@ -331,19 +319,17 @@ namespace Konversation
             }
 
             //remove all gone items
-            foreach (const QModelIndex &index, indexesToRemove)
-            {
+            for (const QModelIndex &index : qAsConst(indexesToRemove)) {
                 indexes.removeOne(index);
             }
 
             m_transferView->clearSelection();
             QList<int> toSelectList;
+            toSelectList.reserve(indexes.size());
             //select everything that got not removed
-            foreach (const QModelIndex &index, indexes)
-            {
+            for (const QModelIndex &index : qAsConst(indexes)) {
                 int offset = 0;
-                foreach (const QModelIndex &removedIndex, indexesToRemove)
-                {
+                for (const QModelIndex &removedIndex : qAsConst(indexesToRemove)) {
                     if (removedIndex.row() < index.row())
                     {
                         ++offset;
@@ -357,7 +343,7 @@ namespace Konversation
             {
                 m_detailPanel->setTransfer(transfer);
             }
-            else if (!transfer || m_transferView->itemCount() == 0 || m_transferView->selectedIndexes().count() == 0)
+            else if (!transfer || m_transferView->itemCount() == 0 || m_transferView->selectedIndexes().isEmpty())
             {
                 m_detailPanel->clear();
             }
@@ -372,14 +358,14 @@ namespace Konversation
             if (transfer && transfer->getStatus() >= Transfer::Done)
             {
                 //item will be gone
-                transfer = 0;
+                transfer = nullptr;
             }
 
             QModelIndexList indexesToRemove;
             QModelIndexList selectedIndexes = m_transferView->selectedRows();
 
-            foreach (const QModelIndex &index, m_transferView->rowIndexes())
-            {
+            const auto rowIndices = m_transferView->rowIndexes();
+            for (const QModelIndex &index : rowIndices) {
                 if (index.data(TransferListModel::TransferStatus).toInt() >= Transfer::Done)
                 {
                     indexesToRemove.append(index);
@@ -391,8 +377,7 @@ namespace Konversation
             std::sort(indexesToRemove.begin(), indexesToRemove.end(), rowGreaterThan);
 
             //remove from last to first item, to keep a valid row
-            foreach (const QModelIndex &index, indexesToRemove)
-            {
+            for (const QModelIndex &index : qAsConst(indexesToRemove)) {
                 m_transferView->model()->removeRow(index.row(), QModelIndex());
                 //needed, otherwise valid rows "can be treated" as invalid,
                 //proxymodel does not keep up with changes
@@ -400,19 +385,17 @@ namespace Konversation
             }
 
             //remove all gone items
-            foreach (const QModelIndex &index, indexesToRemove)
-            {
+            for (const QModelIndex &index : qAsConst(indexesToRemove)) {
                 selectedIndexes.removeOne(index);
             }
 
             m_transferView->clearSelection();
             QList<int> toSelectList;
+            toSelectList.reserve(selectedIndexes.size());
             //select everything that got not removed
-            foreach (const QModelIndex &index, selectedIndexes)
-            {
+            for (const QModelIndex &index : qAsConst(selectedIndexes)) {
                 int offset = 0;
-                foreach (const QModelIndex &removedIndex, indexesToRemove)
-                {
+                for (const QModelIndex &removedIndex : qAsConst(indexesToRemove)) {
                     if (removedIndex.row() < index.row())
                     {
                         ++offset;
@@ -426,7 +409,7 @@ namespace Konversation
             {
                 m_detailPanel->setTransfer(transfer);
             }
-            else if (m_transferView->itemCount() == 0 || m_transferView->selectedIndexes().count() == 0 || !transfer)
+            else if (m_transferView->itemCount() == 0 || m_transferView->selectedIndexes().isEmpty() || !transfer)
             {
                 m_detailPanel->clear();
             }
@@ -454,12 +437,12 @@ namespace Konversation
                 }
             }
 
-            foreach (const QModelIndex &index, m_transferView->selectedRows())
-            {
+            const auto selectedRowIndices = m_transferView->selectedRows();
+            for (const QModelIndex &index : selectedRowIndices) {
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Send ||
                     index.data(TransferListModel::TransferStatus).toInt() == Transfer::Done)
                 {
-                    Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->runFile();
@@ -470,9 +453,9 @@ namespace Konversation
 
         void TransferPanel::openLocation()
         {
-            foreach (const QModelIndex &index, m_transferView->selectedRows())
-            {
-                Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+            const auto selectedRowIndices = m_transferView->selectedRows();
+            for (const QModelIndex &index : selectedRowIndices) {
+                Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                 if (transfer)
                 {
                     openLocation(transfer);
@@ -500,7 +483,7 @@ namespace Konversation
 
         void TransferPanel::doubleClicked(const QModelIndex &index)
         {
-            Transfer *transfer = static_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+            Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
             if (transfer)
             {
                 transfer->runFile();
@@ -512,21 +495,17 @@ namespace Konversation
         {
         }
 
-        TransferView *TransferPanel::getTransferView()
+        TransferView *TransferPanel::getTransferView() const
         {
             return m_transferView;
         }
 
         void TransferPanel::openLocation(Transfer *transfer)
         {
-            QString urlString = transfer->getFileURL().toString(QUrl::PreferLocalFile|QUrl::RemoveFilename|QUrl::StripTrailingSlash);
-            if (!urlString.isEmpty())
-            {
-                QUrl url(QUrl::fromLocalFile(urlString));
-                new KRun(url, 0, true);
-            }
+            auto *job = new KIO::OpenFileManagerWindowJob(nullptr);
+            job->setHighlightUrls({ transfer->getFileURL() });
+            job->start();
         }
-
     }
 }
 
