@@ -1,31 +1,22 @@
 /*
-  This class represents a DCC transferview for transfermodel.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
-
-/*
-  Copyright (C) 2009,2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009, 2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "transferview.h"
 
-#include <KDebug>
-#include <KMenu>
+#include "dcccommon.h"
+#include "preferences.h"
+#include "konversation_log.h"
+
 #include <KCategoryDrawer>
 #include <KLocalizedString>
-#include <KGlobalSettings>
 
+#include <QMenu>
 #include <QHeaderView>
 #include <QKeyEvent>
 
-#include <preferences.h>
-#include "dcccommon.h"
 
 namespace Konversation
 {
@@ -49,7 +40,7 @@ namespace Konversation
             setRootIsDecorated(false); //not implemented for special items
             setSelectionMode(QAbstractItemView::ExtendedSelection);
 
-            m_categoryDrawer = new KCategoryDrawerV3(0);
+            m_categoryDrawer = new KCategoryDrawer(nullptr);
 
             setItemDelegate(new TransferSizeDelegate(m_categoryDrawer, this));
 
@@ -60,32 +51,28 @@ namespace Konversation
             setProgressBarDeletegate();
 
             header()->setContextMenuPolicy(Qt::CustomContextMenu);
-            connect(header(), SIGNAL(customContextMenuRequested(QPoint)),
-                    this, SLOT(headerCustomContextMenuRequested(QPoint)));
+            connect(header(), &QWidget::customContextMenuRequested,
+                    this, &TransferView::headerCustomContextMenuRequested);
 
             m_activeTransfers = 0;
             m_itemCategoryToRemove = 0;
             m_updateTimer = new QTimer(this);
-            m_updateTimer->setInterval(DccCommon::graphicEffectLevelToUpdateInterval(
-                                           KGlobalSettings::graphicEffectsLevel()));
+            m_updateTimer->setInterval(1000);
 
-            connect(m_updateTimer, SIGNAL(timeout()), this, SLOT(update()));
+            connect(m_updateTimer, &QTimer::timeout, this, &TransferView::update);
 
-            connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this, SLOT(globalSettingsChanged(int)));
-
-            connect(model(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                     this, SLOT(rowsAboutToBeRemovedFromModel(QModelIndex,int,int)));
+            connect(model(), &QAbstractItemModel::rowsAboutToBeRemoved,
+                     this, &TransferView::rowsAboutToBeRemovedFromModel);
             //we can't use rowsRemoved here, it seems when rowsRemoved is emitted
             //the rows are not permanently removed from model,
             //so if we trigger a new removeRows in our slot,
             //the new remove happens before the old pending
-            connect(m_dccModel, SIGNAL(rowsPermanentlyRemoved(int,int)),
-                    this, SLOT(rowsRemovedFromModel(int,int)));
+            connect(m_dccModel, &TransferListModel::rowsPermanentlyRemoved, this, &TransferView::rowsRemovedFromModel);
         }
 
         TransferView::~TransferView()
         {
-            disconnect(m_updateTimer, 0, 0, 0);
+            disconnect(m_updateTimer, nullptr, nullptr, nullptr);
 
             saveColumns();
             clear();
@@ -125,10 +112,10 @@ namespace Konversation
         void TransferView::addTransfer(Transfer *transfer)
         {
             //save selected rows
-            QModelIndexList selectedIndexes = selectedRows();
+            const QModelIndexList selectedIndexes = selectedRows();
             QList<QVariant> selectedItems;
-            foreach (const QModelIndex &index, selectedIndexes)
-            {
+            selectedItems.reserve(selectedIndexes.size());
+            for (const QModelIndex &index : selectedIndexes) {
                 selectedItems.append(index.data(TransferListModel::TransferPointer));
             }
 
@@ -136,12 +123,12 @@ namespace Konversation
             {
                 if (!(m_categorieFlags & SendCategory))
                 {
-                    addItem(0, TransferItemData::SendCategory);
+                    addItem(nullptr, TransferItemData::SendCategory);
                     m_categorieFlags |= SendCategory;
                 }
                 if ((m_categorieFlags & ReceiveCategory) && !(m_categorieFlags & SpacerRow))
                 {
-                    addItem(0, TransferItemData::SpaceRow);
+                    addItem(nullptr, TransferItemData::SpaceRow);
                     m_categorieFlags |= SpacerRow;
                 }
                 addItem(transfer, TransferItemData::SendItem);
@@ -150,12 +137,12 @@ namespace Konversation
             {
                 if (!(m_categorieFlags & ReceiveCategory))
                 {
-                    addItem(0, TransferItemData::ReceiveCategory);
+                    addItem(nullptr, TransferItemData::ReceiveCategory);
                     m_categorieFlags |= ReceiveCategory;
                 }
                 if ((m_categorieFlags & SendCategory) && !(m_categorieFlags & SpacerRow))
                 {
-                    addItem(0, TransferItemData::SpaceRow);
+                    addItem(nullptr, TransferItemData::SpaceRow);
                     m_categorieFlags |= SpacerRow;
                 }
                 addItem(transfer, TransferItemData::ReceiveItem);
@@ -168,19 +155,19 @@ namespace Konversation
                 if (m_activeTransfers > 0 && !m_updateTimer->isActive())
                 {
                     m_updateTimer->start();
-                    kDebug() << "timer start";
+                    qCDebug(KONVERSATION_LOG) << "timer start";
                 }
             }
 
-            connect (transfer, SIGNAL(statusChanged(Konversation::DCC::Transfer*,int,int)),
-                     this, SLOT(transferStatusChanged(Konversation::DCC::Transfer*,int,int)));
+            connect (transfer, &Transfer::statusChanged,
+                     this, &TransferView::transferStatusChanged);
 
             clearSelection();
 
             //restore selected
             QList<int> rows;
-            foreach (const QModelIndex &index, rowIndexes())
-            {
+            const auto rowIndices = rowIndexes();
+            for (const QModelIndex &index : rowIndices) {
                 QVariant pointer = index.data(TransferListModel::TransferPointer);
                 if (selectedItems.contains(pointer))
                 {
@@ -298,9 +285,9 @@ namespace Konversation
                 return QModelIndex();
             }
 
-            foreach (const QModelIndex &rowIndex, rowIndexes())
-            {
-                Transfer *rowTransfer = static_cast<Transfer*>(qVariantValue<QObject*>(rowIndex.data(TransferListModel::TransferPointer)));
+            const auto rowIndices = rowIndexes();
+            for (const QModelIndex &rowIndex : rowIndices) {
+                Transfer *rowTransfer = qobject_cast<Transfer*>(rowIndex.data(TransferListModel::TransferPointer).value<QObject*>());
                 if (rowTransfer == transfer)
                 {
                     return rowIndex;
@@ -311,8 +298,8 @@ namespace Konversation
 
         void TransferView::headerCustomContextMenuRequested(const QPoint &pos)
         {
-            KMenu menu(this);
-            menu.addTitle(i18n("Columns"));
+            QMenu menu(this);
+            menu.addSection(i18n("Columns"));
 
             for (int i = 0; i < m_dccModel->columnCount(); ++i)
             {
@@ -334,31 +321,31 @@ namespace Konversation
         //                 connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleFilenameColumn(bool)));
         //                 break;
                     case TransferHeaderData::PartnerNick:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(togglePartnerNickColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::togglePartnerNickColumn);
                         break;
                     case TransferHeaderData::Progress:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleProgressColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleProgressColumn);
                         break;
                     case TransferHeaderData::OfferDate:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleStartedAtColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleStartedAtColumn);
                         break;
                     case TransferHeaderData::Position:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(togglePositionColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::togglePositionColumn);
                         break;
                     case TransferHeaderData::CurrentSpeed:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleCurrentSpeedColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleCurrentSpeedColumn);
                         break;
                     case TransferHeaderData::SenderAdress:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleSenderAdressColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleSenderAdressColumn);
                         break;
                     case TransferHeaderData::Status:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleStatusColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleStatusColumn);
                         break;
                     case TransferHeaderData::TimeLeft:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toggleTimeLeftColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toggleTimeLeftColumn);
                         break;
                     case TransferHeaderData::TypeIcon:
-                        connect (tAction, SIGNAL(toggled(bool)), this, SLOT(toogleTypeIconColumn(bool)));
+                        connect(tAction, &QAction::toggled, this, &TransferView::toogleTypeIconColumn);
                         break;
                 }
 
@@ -428,7 +415,7 @@ namespace Konversation
                     return i;
                 }
             }
-            kDebug() << "unknown headerType: " << headerType;
+            qCDebug(KONVERSATION_LOG) << "unknown headerType: " << headerType;
             return -1;
         }
 
@@ -447,11 +434,14 @@ namespace Konversation
 
         void TransferView::saveColumns()
         {
+            const int columnCount = header()->count();
             QList<int> columnWidths;
+            columnWidths.reserve(columnCount);
             QList<int> columnOrder;
+            columnOrder.reserve(columnCount);
             QList<int> columnVisible;
-            for (int i = 0; i < header()->count(); ++i)
-            {
+            columnVisible.reserve(columnCount);
+            for (int i = 0; i < columnCount; ++i) {
                 int index = header()->logicalIndex(i);
 
                 columnWidths.append(columnWidth(index));
@@ -507,7 +497,7 @@ namespace Konversation
             }
             else
             {
-                kDebug() << "transferview fallback, did we crash last time?\n"
+                qCDebug(KONVERSATION_LOG) << "transferview fallback, did we crash last time?\n"
                          << " columnOrder.count():"<< columnOrder.count()
                          << " columnWidths.count():"<< columnWidths.count()
                          << " columnVisible.count():"<< columnVisible.count()
@@ -549,8 +539,8 @@ namespace Konversation
         void TransferView::selectAllCompleted()
         {
             QItemSelection selection;
-            foreach (const QModelIndex &index, rowIndexes())
-            {
+            const auto rowIndices = rowIndexes();
+            for (const QModelIndex &index : rowIndices) {
                 if (index.data(TransferListModel::TransferStatus).toInt() >= Transfer::Done)
                 {
                     selection.append(QItemSelectionRange(index));
@@ -568,13 +558,12 @@ namespace Konversation
             selectionModel()->select(m_proxyModel->index(row, 0), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         }
 
-        void TransferView::selectRows(QList<int> rows)
+        void TransferView::selectRows(const QList<int>& rows)
         {
             QItemSelection selection;
-            foreach (const QModelIndex &index, rowIndexes())
-            {
-                foreach (int row, rows)
-                {
+            const auto rowIndices = rowIndexes();
+            for (const QModelIndex &index : rowIndices) {
+                for (int row : rows) {
                     if (row == index.row())
                     {
                         selection.append(QItemSelectionRange(index));
@@ -588,8 +577,8 @@ namespace Konversation
         void TransferView::update()
         {
             const int columnCount = model()->columnCount()-1;
-            foreach (const QModelIndex &rowIndex, rowIndexes(0))
-            {
+            const auto rowIndices = rowIndexes(0);
+            for (const QModelIndex &rowIndex : rowIndices) {
                 int status = rowIndex.data(TransferListModel::TransferStatus).toInt();
                 if (status == Transfer::Transferring)
                 {
@@ -617,7 +606,7 @@ namespace Konversation
                     m_itemCategoryToRemove &= ~Transfer::Send;
                     m_categorieFlags &= ~TransferView::SendCategory;
                     int removed = removeItems(TransferItemData::SendCategory);
-                    //kDebug() << "Sendremoved:" << removed;
+                    //qCDebug(KONVERSATION_LOG) << "Sendremoved:" << removed;
                     if (removed > 0 && (m_categorieFlags & SpacerRow))
                     {
                         removeItems(TransferItemData::SpaceRow);
@@ -632,7 +621,7 @@ namespace Konversation
                     m_itemCategoryToRemove &= ~Transfer::Receive;
                     m_categorieFlags &= ~TransferView::ReceiveCategory;
                     int removed = removeItems(TransferItemData::ReceiveCategory);
-                    //kDebug() << "Receiveremoved:" << removed;
+                    //qCDebug(KONVERSATION_LOG) << "Receiveremoved:" << removed;
                     if (removed > 0 && (m_categorieFlags & SpacerRow))
                     {
                         removeItems(TransferItemData::SpaceRow);
@@ -642,17 +631,6 @@ namespace Konversation
             }
         }
 
-        void TransferView::globalSettingsChanged(int category)
-        {
-#if KDE_IS_VERSION(4,8,1)
-            if (category == KGlobalSettings::SETTINGS_STYLE)
-#else
-            Q_UNUSED(category);
-#endif
-                m_updateTimer->setInterval(DccCommon::graphicEffectLevelToUpdateInterval(
-                                               KGlobalSettings::graphicEffectsLevel()));
-        }
-
         int TransferView::removeItems(TransferItemData::ItemDisplayType displaytype)
         {
             int removed = 0;
@@ -671,4 +649,4 @@ namespace Konversation
     }
 }
 
-#include "transferview.moc"
+
