@@ -1,23 +1,17 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009-2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009-2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "whiteboard.h"
 
 #include "whiteboardtoolbar.h"
 #include "whiteboardpaintarea.h"
+#include "konversation_log.h"
 
 #include <QScrollArea>
 
-#include "qdebug.h"
-
 namespace Konversation
 {
     namespace DCC
@@ -75,29 +69,33 @@ namespace Konversation
 
         void WhiteBoard::receivedWhiteBoardLine(const QString& line)
         {
-            // qDebug() << line;
-            if (line.isEmpty() || !line.contains(' '))
+            // qCDebug(KONVERSATION_LOG) << line;
+            if (line.isEmpty() || !line.contains(QLatin1Char(' ')))
                 return;
 
             //fontname can have spaces, as well as text
             QStringList firstSplit;
-            firstSplit.append(line.section(' ', 0 ,0));
-            firstSplit.append(line.section(' ', 1));
+            firstSplit.append(line.section(QLatin1Char(' '), 0 ,0));
+            firstSplit.append(line.section(QLatin1Char(' '), 1));
 
             if (firstSplit.isEmpty())
                 return;
 
             const QString ctcpCommand(firstSplit.at(0));
-            // qDebug() << "ctcpCommand" << ctcpCommand;
-            // qDebug() << "firstSize" << firstSplit.size();
+            // qCDebug(KONVERSATION_LOG) << "ctcpCommand" << ctcpCommand;
+            // qCDebug(KONVERSATION_LOG) << "firstSize" << firstSplit.size();
 
-            if (ctcpCommand == "DR" && firstSplit.size() == 2)
+            if (ctcpCommand == QLatin1String("DR") && firstSplit.size() == 2)
             {
                 // DR tooltype,width,pencolor,brushcolor,x1,y1,x2,y2
-                const QStringList drArgsList = firstSplit.at(1).split(',', QString::SkipEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                const QStringList drArgsList = firstSplit.at(1).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+                const QStringList drArgsList = firstSplit.at(1).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
                 if (drArgsList.size() != 8)
                 {
-                    qDebug() << "wrong size:" << drArgsList.size();
+                    qCDebug(KONVERSATION_LOG) << "wrong size:" << drArgsList.size();
                     return;
                 }
 
@@ -106,7 +104,7 @@ namespace Konversation
                 int toolType = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse tooltype:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse tooltype:" << tmp;
                     return;
                 }
 
@@ -114,21 +112,21 @@ namespace Konversation
                 int lineWidth = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse linewidth:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse linewidth:" << tmp;
                     return;
                 }
 
                 QColor penColor = parseColor(drArgsList.at(2), &ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse pencolor:" << drArgsList.at(2);
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse pencolor:" << drArgsList.at(2);
                     return;
                 }
 
                 QColor brushColor = parseColor(drArgsList.at(3), &ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse brush:" << drArgsList.at(3);
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse brush:" << drArgsList.at(3);
                     return;
                 }
 
@@ -136,7 +134,7 @@ namespace Konversation
                 int xFrom = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse xFrom:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse xFrom:" << tmp;
                     return;
                 }
 
@@ -144,7 +142,7 @@ namespace Konversation
                 int yFrom = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse yFrom:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse yFrom:" << tmp;
                     return;
                 }
 
@@ -152,7 +150,7 @@ namespace Konversation
                 int xTo = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse xTo:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse xTo:" << tmp;
                     return;
                 }
 
@@ -160,7 +158,7 @@ namespace Konversation
                 int yTo = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "unabled to parse yTo:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "unabled to parse yTo:" << tmp;
                     return;
                 }
 
@@ -174,45 +172,49 @@ namespace Konversation
                 {
                 case WhiteBoardGlobals::Line:
                 case WhiteBoardGlobals::Pencil:
-                    // qDebug() << "drawing a line" << lineWidth << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a line" << lineWidth << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawLine(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Rectangle:
-                    // qDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawRectangle(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FilledRectangle:
-                    // qDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawFilledRectangle(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Ellipse:
-                    // qDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawEllipse(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FilledEllipse:
-                    // qDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawFilledEllipse(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Eraser:
-                    // qDebug() << "drawing a Eraser" << xFrom << yFrom << xTo << yTo;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a Eraser" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->useEraser(lineWidth, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FloodFill:
-                    // qDebug() << "drawing a FloodFill" << xFrom << yFrom;
+                    // qCDebug(KONVERSATION_LOG) << "drawing a FloodFill" << xFrom << yFrom;
                     m_paintArea->useFloodFill(xFrom, yFrom, penColor);
                     break;
                 case WhiteBoardGlobals::Arrow:
-                    // qDebug() << "drawing an Arrow" << xFrom << yFrom;
+                    // qCDebug(KONVERSATION_LOG) << "drawing an Arrow" << xFrom << yFrom;
                     m_paintArea->drawArrow(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 }
             }
-            else if (ctcpCommand == "TXT" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("TXT") && firstSplit.size() == 2)
             {
-                QStringList txtArgsList = firstSplit.at(1).split(',', QString::KeepEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                QStringList txtArgsList = firstSplit.at(1).split(QLatin1Char(','), QString::KeepEmptyParts);
+#else
+                QStringList txtArgsList = firstSplit.at(1).split(QLatin1Char(','), Qt::KeepEmptyParts);
+#endif
                 if (txtArgsList.size() < 3)
                 {
-                    qDebug() << "txt wrong size:" << txtArgsList.size();
+                    qCDebug(KONVERSATION_LOG) << "txt wrong size:" << txtArgsList.size();
                     return;
                 }
 
@@ -221,7 +223,7 @@ namespace Konversation
                 int x1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txt unabled to parse x1:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txt unabled to parse x1:" << tmp;
                     return;
                 }
 
@@ -229,22 +231,26 @@ namespace Konversation
                 int y1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txt unabled to parse y1:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txt unabled to parse y1:" << tmp;
                     return;
                 }
 
                 txtArgsList.removeFirst();
                 txtArgsList.removeFirst();
-                QString text(txtArgsList.join(","));
+                QString text(txtArgsList.join(QLatin1Char(',')));
 
                 m_paintArea->useText(x1,y1,text);
             }
-            else if (ctcpCommand == "TXTEX" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("TXTEX") && firstSplit.size() == 2)
             {
-                QStringList txtArgsList = firstSplit.at(1).split(',', QString::KeepEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                QStringList txtArgsList = firstSplit.at(1).split(QLatin1Char(','), QString::KeepEmptyParts);
+#else
+                QStringList txtArgsList = firstSplit.at(1).split(QLatin1Char(','), Qt::KeepEmptyParts);
+#endif
                 if (txtArgsList.size() < 8)
                 {
-                    qDebug() << "txtex wrong size:" << txtArgsList.size();
+                    qCDebug(KONVERSATION_LOG) << "txtex wrong size:" << txtArgsList.size();
                     return;
                 }
 
@@ -253,7 +259,7 @@ namespace Konversation
                 int x1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse x1:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse x1:" << tmp;
                     return;
                 }
 
@@ -261,7 +267,7 @@ namespace Konversation
                 int y1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse y1:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse y1:" << tmp;
                     return;
                 }
 
@@ -271,7 +277,7 @@ namespace Konversation
                 int fontSize = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse fontsize:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse fontsize:" << tmp;
                     return;
                 }
 
@@ -279,21 +285,21 @@ namespace Konversation
                 int fontStyle = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse fontstyle:" << tmp;
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse fontstyle:" << tmp;
                     return;
                 }
 
                 QColor penColor = parseColor(txtArgsList.at(5), &ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse pencolor:" << txtArgsList.at(5);
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse pencolor:" << txtArgsList.at(5);
                     return;
                 }
 
                 QColor brushColor = parseColor(txtArgsList.at(6), &ok);
                 if (!ok)
                 {
-                    qDebug() << "txtex unabled to parse brush:" << txtArgsList.at(6);
+                    qCDebug(KONVERSATION_LOG) << "txtex unabled to parse brush:" << txtArgsList.at(6);
                     return;
                 }
 
@@ -317,61 +323,65 @@ namespace Konversation
                 txtArgsList.removeFirst(); // fontstyle
                 txtArgsList.removeFirst(); // textcolor
                 txtArgsList.removeFirst(); // bgcolor
-                QString text(txtArgsList.join(","));
-                // qDebug() << "TXTEX" << text << fontSize << fontName;
+                QString text(txtArgsList.join(QLatin1Char(',')));
+                // qCDebug(KONVERSATION_LOG) << "TXTEX" << text << fontSize << fontName;
                 m_paintArea->useTextExtended(x1,y1,tFont,penColor,brushColor,text);
             }
-            else if (ctcpCommand == "CLS" && firstSplit.size() == 1)
+            else if (ctcpCommand == QLatin1String("CLS") && firstSplit.size() == 1)
             {
                 //CLS
                 m_paintArea->clear();
             }
-            else if (ctcpCommand == "CAN" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("CAN") && firstSplit.size() == 2)
             {
                 //TODO implement me
                 const QString& can = firstSplit.at(1).toLower();
-                if (can == "use-wb2")
+                if (can == QLatin1String("use-wb2"))
                 {
                     //no we currently can't, I lied
-                    emitDo("use-wb2");
+                    emitDo(QStringLiteral("use-wb2"));
                     return;
                 }
-                else if (can == "txtex")
+                else if (can == QLatin1String("txtex"))
                 {
-                    emitDo("TXTEX");
+                    emitDo(QStringLiteral("TXTEX"));
                     m_toolbar->setSupportedTextType(WhiteBoardToolBar::ExtentedText);
                     return;
                 }
-                qDebug() << "unhandled CAN" << firstSplit.at(1);
+                qCDebug(KONVERSATION_LOG) << "unhandled CAN" << firstSplit.at(1);
             }
-            else if (ctcpCommand == "CANT" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("CANT") && firstSplit.size() == 2)
             {
                 //TODO implement me
                 const QString& cannot = firstSplit.at(1).toLower();
-                if (cannot == "txtex")
+                if (cannot == QLatin1String("txtex"))
                 {
                     m_toolbar->setSupportedTextType(WhiteBoardToolBar::SimpleText);
                     return;
                 }
-                qDebug() << "unhandled CANT" << firstSplit.at(1);
+                qCDebug(KONVERSATION_LOG) << "unhandled CANT" << firstSplit.at(1);
             }
-            else if (ctcpCommand == "DO" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("DO") && firstSplit.size() == 2)
             {
                 //TODO implement me
                 const QString& doString = firstSplit.at(1).toLower();
-                if (doString == "txtex")
+                if (doString == QLatin1String("txtex"))
                 {
                     m_toolbar->setSupportedTextType(WhiteBoardToolBar::ExtentedText);
                     return;
                 }
             }
-            else if (ctcpCommand == "BLT" && firstSplit.size() == 2)
+            else if (ctcpCommand == QLatin1String("BLT") && firstSplit.size() == 2)
             {
                 // BLT x1src,y1src,x2src,y2src,xdest,ydest
-                const QStringList drArgsList = firstSplit.at(1).split(',', QString::SkipEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                const QStringList drArgsList = firstSplit.at(1).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+                const QStringList drArgsList = firstSplit.at(1).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
                 if (drArgsList.size() != 6)
                 {
-                    qDebug() << "blt wrong size:" << drArgsList.size();
+                    qCDebug(KONVERSATION_LOG) << "blt wrong size:" << drArgsList.size();
                     return;
                 }
 
@@ -392,13 +402,13 @@ namespace Konversation
 
                 if (!finalOk)
                 {
-                    qDebug() << "blt unabled to parse coords:" << firstSplit.at(1);
+                    qCDebug(KONVERSATION_LOG) << "blt unabled to parse coords:" << firstSplit.at(1);
                     return;
                 }
 
                 if (x2src <= x1src || y2src <= y1src)
                 {
-                    qDebug() << "blt coords invalid:" << firstSplit.at(1);
+                    qCDebug(KONVERSATION_LOG) << "blt coords invalid:" << firstSplit.at(1);
                     return;
                 }
                 m_paintArea->useBlt(x1src, y1src, x2src, y2src, xdest, ydest);
@@ -407,9 +417,9 @@ namespace Konversation
 
         void WhiteBoard::clear()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             m_paintArea->clear();
-            static const QString cls = QString("\x01""CLS\x01");
+            const QString cls = QStringLiteral("\x01""CLS\x01");
             emit rawWhiteBoardCommand(cls);
         }
 
@@ -465,7 +475,7 @@ namespace Konversation
         void WhiteBoard::usedText(int x, int y, const QString& text)
         {
             //TXT x,y,text
-            static const QString txtLineCommand("\x01""TXT %1,%2,%3\x01");
+            const QString txtLineCommand = QStringLiteral("\x01""TXT %1,%2,%3\x01");
 
             emit rawWhiteBoardCommand(txtLineCommand.arg(x).arg(y).arg(text));
         }
@@ -473,15 +483,15 @@ namespace Konversation
         void WhiteBoard::usedTextExtended(int x, int y, const QFont& font, const QColor& textColor, const QColor& background, const QString& text)
         {
             //TXTEX x,y,fontname,ptsize,style,textcolor,bgcolor,text
-            static const QString txtexLineCommand("\x01""TXTEX %1,%2,%3,%4,%5,%6,%7,%8\x01");
+            const QString txtexLineCommand = QStringLiteral("\x01""TXTEX %1,%2,%3,%4,%5,%6,%7,%8\x01");
 
             QString fontname = font.family();
             QString fontSize = QString::number(font.pointSize());
             QString fontStyle = QString::number(fontToStyle(font));
 
             emit rawWhiteBoardCommand(txtexLineCommand.arg(x).arg(y).arg(
-                                                           fontname).arg(fontSize).arg(fontStyle).arg(colorToString(textColor)).arg(
-                                                           colorToString(background)).arg(text));
+                                                           fontname, fontSize, fontStyle, colorToString(textColor),
+                                                           colorToString(background), text));
         }
 
         QColor WhiteBoard::parseColor(const QString& colorString, bool* ok)
@@ -533,8 +543,8 @@ namespace Konversation
 
         void WhiteBoard::connected()
         {
-            emitCan("use-wb2");
-            emitCan("TXTEX");
+            emitCan(QStringLiteral("use-wb2"));
+            emitCan(QStringLiteral("TXTEX"));
         }
 
         void WhiteBoard::emitDRCommand(WhiteBoardGlobals::WhiteBoardTool tool, int lineWidth,
@@ -546,35 +556,35 @@ namespace Konversation
                 return;
             }
 
-            QString drLineCommand("\x01""DR %2,%3,%4,%5,%6,%7,%8,%9\x01");
+            QString drLineCommand = QStringLiteral("\x01""DR %2,%3,%4,%5,%6,%7,%8,%9\x01");
             drLineCommand = drLineCommand.arg(tool).arg(
-                                          lineWidth).arg(colorToString(penColor)).arg(colorToString(brushColor)).arg(
+                                          lineWidth).arg(colorToString(penColor), colorToString(brushColor)).arg(
                                           xFrom).arg(yFrom).arg(xTo).arg(yTo);
-            // qDebug() << drLineCommand;
+            // qCDebug(KONVERSATION_LOG) << drLineCommand;
             emit rawWhiteBoardCommand(drLineCommand);
         }
 
         void WhiteBoard::emitCan(const QString& canString)
         {
-            static const QString can = QString("\x01""CAN %1\x01");
+            const QString can = QStringLiteral("\x01""CAN %1\x01");
             emit rawWhiteBoardCommand(can.arg(canString));
         }
 
         void WhiteBoard::emitCant(const QString& cantString)
         {
-            static const QString cant = QString("\x01""CANT %1\x01");
+            const QString cant = QStringLiteral("\x01""CANT %1\x01");
             emit rawWhiteBoardCommand(cant.arg(cantString));
         }
 
         void WhiteBoard::emitDo(const QString& doString)
         {
-            static const QString doCommand = QString("\x01""DO %1\x01");
+            const QString doCommand = QStringLiteral("\x01""DO %1\x01");
             emit rawWhiteBoardCommand(doCommand.arg(doString));
         }
 
         void WhiteBoard::emitDont(const QString& doNotString)
         {
-            static const QString doNot = QString("\x01""DONT %1\x01"); //krazy:exclude=spelling
+            const QString doNot = QStringLiteral("\x01""DONT %1\x01"); //krazy:exclude=spelling
             emit rawWhiteBoardCommand(doNot.arg(doNotString));
         }
 
