@@ -1,30 +1,21 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "whiteboardtoolbar.h"
 
-#include <QHBoxLayout>
-#include <QLayout>
-#include <QDir>
-#include <QImageWriter>
-#include <QPainter>
-#include <QPushButton>
-#include <QUrl>
-#include <QIcon>
-#include <QDebug>
-#include <QFileDialog>
+#include "whiteboardfontchooser.h"
+#include "konversation_log.h"
 
 #include <KLocalizedString>
 
-#include "whiteboardfontchooser.h"
+#include <QDir>
+#include <QPainter>
+#include <QPushButton>
+#include <QIcon>
+#include <QFileDialog>
 
 namespace Konversation
 {
@@ -34,65 +25,65 @@ namespace Konversation
             : QWidget(parent),
               m_lineWidthPixmap(20, 20),
               m_textType(SimpleText),
-              m_fontDialog(0)
+              m_fontDialog(nullptr)
         {
             setupUi(this);
 
-            m_clearPushButton->setIcon(QIcon::fromTheme("document-edit"));
+            m_clearPushButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
             m_clearPushButton->setToolTip(i18n("Clear Image"));
-            m_savePushButton->setIcon(QIcon::fromTheme("document-save"));
+            m_savePushButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
             m_savePushButton->setToolTip(i18n("Save As..."));
 
-            m_pencilPushButton->setIcon(QIcon::fromTheme("draw-freehand"));
+            m_pencilPushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-freehand")));
             m_pencilPushButton->setToolTip(i18n("Freehand Drawing"));
             m_pencilPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Pencil, m_pencilPushButton);
             m_pencilPushButton->setChecked(true);
 
-            m_linePushButton->setIcon(QIcon::fromTheme("draw-line"));
+            m_linePushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-line")));
             m_linePushButton->setToolTip(i18n("Draw a straight line"));
             m_linePushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Line, m_linePushButton);
 
-            m_rectanglePushButton->setIcon(QIcon::fromTheme("draw-rectangle"));
+            m_rectanglePushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-rectangle")));
             m_rectanglePushButton->setToolTip(i18n("Draw a rectangle"));
             m_rectanglePushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Rectangle, m_rectanglePushButton);
             m_toggleButtonHash.insert(WhiteBoardGlobals::FilledRectangle, m_rectanglePushButton);
 
-            m_ellipsePushButton->setIcon(QIcon::fromTheme("draw-circle"));
+            m_ellipsePushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-circle")));
             m_ellipsePushButton->setToolTip(i18n("Draw an ellipse"));
             m_ellipsePushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Ellipse, m_ellipsePushButton);
             m_toggleButtonHash.insert(WhiteBoardGlobals::FilledEllipse, m_ellipsePushButton);
 
-            m_textPushButton->setIcon(QIcon::fromTheme("draw-text"));
+            m_textPushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-text")));
             m_textPushButton->setToolTip(i18n("Draw text"));
             m_textPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Text, m_textPushButton);
 
             m_selectionPushButton->setEnabled(false); // it has no function in current whiteboard
-            m_selectionPushButton->setIcon(QIcon::fromTheme("select-rectangular"));
+            m_selectionPushButton->setIcon(QIcon::fromTheme(QStringLiteral("select-rectangular")));
             m_selectionPushButton->setToolTip(i18nc("dcc whiteboard selection tool", "Selection"));
             m_selectionPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Selection, m_selectionPushButton);
 
-            m_eraserPushButton->setIcon(QIcon::fromTheme("draw-eraser"));
+            m_eraserPushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-eraser")));
             m_eraserPushButton->setToolTip(i18n("Eraser"));
             m_eraserPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Eraser, m_eraserPushButton);
 
-            m_fillPushButton->setIcon(QIcon::fromTheme("fill-color"));
+            m_fillPushButton->setIcon(QIcon::fromTheme(QStringLiteral("fill-color")));
             m_fillPushButton->setToolTip(i18n("Fill a contiguous area with the foreground color"));
             m_fillPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::FloodFill, m_fillPushButton);
 
-            m_arrowPushButton->setIcon(QIcon::fromTheme("draw-arrow-forward"));
+            m_arrowPushButton->setIcon(QIcon::fromTheme(QStringLiteral("draw-arrow-forward")));
             m_arrowPushButton->setToolTip(i18n("Draw an arrow"));
             m_arrowPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::Arrow, m_arrowPushButton);
 
-            m_colorPickerPushButton->setIcon(QIcon::fromTheme("color-picker"));
+            m_colorPickerPushButton->setIcon(QIcon::fromTheme(QStringLiteral("color-picker")));
             m_colorPickerPushButton->setToolTip(i18n("Select a color from the image"));
             m_colorPickerPushButton->setFlat(true);
             m_toggleButtonHash.insert(WhiteBoardGlobals::ColorPicker, m_colorPickerPushButton);
@@ -151,7 +142,7 @@ namespace Konversation
             }
             else
             {
-                qDebug() << "unhandled tool:" << tool;
+                qCDebug(KONVERSATION_LOG) << "unhandled tool:" << tool;
             }
         }
 
@@ -164,7 +155,7 @@ namespace Konversation
             }
             else
             {
-                qDebug() << "unhandled tool:" << tool;
+                qCDebug(KONVERSATION_LOG) << "unhandled tool:" << tool;
             }
         }
 
@@ -184,9 +175,9 @@ namespace Konversation
             {
                 if (m_fontDialog)
                 {
-                    disconnect(m_fontDialog, 0, 0, 0);
+                    disconnect(m_fontDialog, nullptr, nullptr, nullptr);
                     delete m_fontDialog;
-                    m_fontDialog = 0;
+                    m_fontDialog = nullptr;
                 }
             }
         }
@@ -198,7 +189,7 @@ namespace Konversation
 
         void WhiteBoardToolBar::connectToggleButtons()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             connect(m_pencilPushButton, &QPushButton::toggled, this, &WhiteBoardToolBar::pencilToggled);
             connect(m_linePushButton, &QPushButton::toggled, this, &WhiteBoardToolBar::lineToggled);
             connect(m_rectanglePushButton, &QPushButton::toggled, this, &WhiteBoardToolBar::rectangleToggled);
@@ -213,17 +204,17 @@ namespace Konversation
 
         void WhiteBoardToolBar::disconnectToggleButtons()
         {
-            qDebug();
-            disconnect(m_pencilPushButton, 0, 0, 0);
-            disconnect(m_linePushButton, 0, 0, 0);
-            disconnect(m_rectanglePushButton, 0, 0, 0);
-            disconnect(m_ellipsePushButton, 0, 0, 0);
-            disconnect(m_textPushButton, 0, 0, 0);
-            disconnect(m_selectionPushButton, 0, 0, 0);
-            disconnect(m_eraserPushButton, 0, 0, 0);
-            disconnect(m_fillPushButton, 0, 0, 0);
-            disconnect(m_arrowPushButton, 0, 0, 0);
-            disconnect(m_colorPickerPushButton, 0, 0, 0);
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
+            disconnect(m_pencilPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_linePushButton, nullptr, nullptr, nullptr);
+            disconnect(m_rectanglePushButton, nullptr, nullptr, nullptr);
+            disconnect(m_ellipsePushButton, nullptr, nullptr, nullptr);
+            disconnect(m_textPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_selectionPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_eraserPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_fillPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_arrowPushButton, nullptr, nullptr, nullptr);
+            disconnect(m_colorPickerPushButton, nullptr, nullptr, nullptr);
         }
 
         void WhiteBoardToolBar::clearClicked()
@@ -243,8 +234,8 @@ namespace Konversation
             if (ret == QDialog::Accepted && fileDialog)
             {
                 QStringList saveList = fileDialog->selectedFiles();
-                qDebug() << saveList;
-                if (saveList.count() > 0)
+                qCDebug(KONVERSATION_LOG) << saveList;
+                if (!saveList.isEmpty())
                 emit save(saveList.at(0));
             }
             delete fileDialog;
@@ -342,7 +333,7 @@ namespace Konversation
         void WhiteBoardToolBar::handleToggleButton(QPushButton* button, bool checked, Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool tool)
         {
             disconnectToggleButtons();
-            qDebug() << "tool:" << tool << "checked:" << checked;
+            qCDebug(KONVERSATION_LOG) << "tool:" << tool << "checked:" << checked;
             if (checked)
             {
                 unCheckOtherButtons(button);
@@ -358,8 +349,7 @@ namespace Konversation
 
         void WhiteBoardToolBar::unCheckOtherButtons(QPushButton* button)
         {
-            foreach(QPushButton* pushButton, m_toggleButtonHash)
-            {
+            for (QPushButton* pushButton : qAsConst(m_toggleButtonHash)) {
                 if (pushButton != button && pushButton->isChecked())
                 {
                     pushButton->setChecked(false);
@@ -387,19 +377,19 @@ namespace Konversation
 
         void WhiteBoardToolBar::formSelectionChanged()
         {
-            // qDebug();
+            // qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             QList<QListWidgetItem *> selectList = m_formOptionListWidget->selectedItems();
             const int selectedRow = m_formOptionListWidget->row(selectList.first());
             if (selectedRow == 0)
             {
                 if (m_rectanglePushButton->isChecked())
                 {
-                    qDebug() << "emit rectangle";
+                    qCDebug(KONVERSATION_LOG) << "emit rectangle";
                     emit toolChanged(WhiteBoardGlobals::Rectangle);
                 }
                 else if (m_ellipsePushButton->isChecked())
                 {
-                    qDebug() << "emit ellipse";
+                    qCDebug(KONVERSATION_LOG) << "emit ellipse";
                     emit toolChanged(WhiteBoardGlobals::Ellipse);
                 }
             }
@@ -407,12 +397,12 @@ namespace Konversation
             {
                 if (m_rectanglePushButton->isChecked())
                 {
-                    qDebug() << "emit filledrectangle";
+                    qCDebug(KONVERSATION_LOG) << "emit filledrectangle";
                     emit toolChanged(WhiteBoardGlobals::FilledRectangle);
                 }
                 else if (m_ellipsePushButton->isChecked())
                 {
-                    qDebug() << "emit filledellipse";
+                    qCDebug(KONVERSATION_LOG) << "emit filledellipse";
                     emit toolChanged(WhiteBoardGlobals::FilledEllipse);
                 }
             }
@@ -441,14 +431,14 @@ namespace Konversation
 
         void WhiteBoardToolBar::fillFormOptionList(FormOption form)
         {
-            disconnect(m_formOptionListWidget, 0, 0, 0);
+            disconnect(m_formOptionListWidget, nullptr, nullptr, nullptr);
             m_formOptionListWidget->clear();
             const int width = m_formOptionListWidget->contentsRect().width() - m_formOptionListWidget->lineWidth()*4 - 3;
             const int drawHeight = 20 - 2;
             const int widthLayoutOffset = 2;
             const QSize sizeHint(width, 20);
-            // qDebug() << "wanted width" << width;
-            // qDebug() << "actual width" << m_formOptionListWidget->contentsRect().width();
+            // qCDebug(KONVERSATION_LOG) << "wanted width" << width;
+            // qCDebug(KONVERSATION_LOG) << "actual width" << m_formOptionListWidget->contentsRect().width();
             switch (form)
             {
                 case Rectangle:
