@@ -1,15 +1,10 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
-/*
-  copyright: (C) 2004, 2009 by Peter Simonsson
-  email:     peter.simonsson@gmail.com
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
-*/
 #ifndef KONVERSATIONIDENTITYDIALOG_H
 #define KONVERSATIONIDENTITYDIALOG_H
 
@@ -29,10 +24,10 @@ namespace Konversation
     {
         Q_OBJECT
         public:
-            explicit IdentityDialog(QWidget *parent = 0);
-            ~IdentityDialog() override {}
+            explicit IdentityDialog(QWidget *parent = nullptr);
+            ~IdentityDialog() {}
             void setCurrentIdentity(int index);
-            IdentityPtr setCurrentIdentity(IdentityPtr identity);
+            IdentityPtr setCurrentIdentity(const IdentityPtr &identity);
             IdentityPtr currentIdentity() const;
 
         public Q_SLOTS:
@@ -41,10 +36,10 @@ namespace Konversation
         Q_SIGNALS:
             void identitiesChanged();
 
-        protected:
+        private:
             bool checkCurrentIdentity();
 
-        protected Q_SLOTS:
+        private Q_SLOTS:
             void updateIdentity(int index);
             void refreshCurrentIdentity();
 
@@ -62,7 +57,9 @@ namespace Konversation
             KEditListWidget* m_nicknameLBox;
 
             KMessageWidget* m_additionalAuthInfo;
-    };
 
+            Q_DISABLE_COPY(IdentityDialog)
+    };
 }
+
 #endif
