@@ -1,20 +1,15 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2004-2016 Peter Simonsson <peter.simonsson@gmail.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004-2016 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #include "channel.h"
+
 #include "channeloptionsdialog.h"
 #include "application.h"
-#include "server.h"
 #include "nick.h"
 #include "nicklistview.h"
 #include "quickbutton.h"
@@ -27,33 +22,32 @@
 #include "topichistorymodel.h"
 #include "notificationhandler.h"
 #include "viewcontainer.h"
+#include "konversation_log.h"
 
+#include <KPasswordDialog>
+#include <KMessageBox>
+#include <KComboBox>
+
+#include <QLineEdit>
 #include <QRegExp>
 #include <QSplitter>
-#include <QTimer>
 #include <QToolButton>
 #include <QHeaderView>
 #include <QInputDialog>
+#include <QRandomGenerator>
 
-#include <KLineEdit>
-#include <KPasswordDialog>
-#include <KMessageBox>
-#include <KIconLoader>
-#include <KComboBox>
-
-#define DELAYED_SORT_TRIGGER    10
+constexpr int DELAYED_SORT_TRIGGER = 10;
 
 using namespace Konversation;
 
 bool nickTimestampLessThan(const Nick* nick1, const Nick* nick2)
 {
-    int returnValue = nick2->getChannelNick()->timeStamp() - nick1->getChannelNick()->timeStamp();
-    if( returnValue == 0) {
-        returnValue = QString::compare(nick1->getChannelNick()->loweredNickname(),
-                                       nick2->getChannelNick()->loweredNickname());
+    if(nick2->getChannelNick()->timeStamp() == nick1->getChannelNick()->timeStamp()) {
+        return QString::compare(nick1->getChannelNick()->loweredNickname(),
+                                nick2->getChannelNick()->loweredNickname()) < 0;
     }
 
-    return (returnValue < 0);
+    return nick1->getChannelNick()->timeStamp() < nick2->getChannelNick()->timeStamp();
 }
 
 bool nickLessThan(const Nick* nick1, const Nick* nick2)
@@ -71,9 +65,9 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     //HACK I needed the channel name at time of setServer, but setName needs m_server..
     //     This effectively assigns the name twice, but none of the other logic has been moved or updated.
     name=_name;
-    m_ownChannelNick = 0;
-    m_optionsDialog = NULL;
-    m_delayedSortTimer = 0;
+    m_ownChannelNick = nullptr;
+    m_optionsDialog = nullptr;
+    m_delayedSortTimer = nullptr;
     m_delayedSortTrigger = 0;
     m_processedNicksCount = 0;
     m_processedOpsCount = 0;
@@ -116,25 +110,25 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     m_vertSplitter->setStretchFactor(m_vertSplitter->indexOf(topicWidget), 0);
 
     QGridLayout* topicLayout = new QGridLayout(topicWidget);
-    topicLayout->setMargin(0);
+    topicLayout->setContentsMargins(0, 0, 0, 0);
     topicLayout->setSpacing(0);
 
     m_topicButton = new QToolButton(topicWidget);
     m_topicButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     m_topicButton->setToolTip(i18n("Edit Channel Settings"));
     m_topicButton->setAutoRaise(true);
-    connect(m_topicButton, SIGNAL(clicked()), this, SLOT(showOptionsDialog()));
+    connect(m_topicButton, &QAbstractButton::clicked, this, &Channel::showOptionsDialog);
 
     topicLine = new Konversation::TopicLabel(topicWidget);
     topicLine->setContextMenuOptions(IrcContextMenus::ShowChannelActions | IrcContextMenus::ShowLogAction, true);
     topicLine->setChannelName(getName());
     topicLine->setWordWrap(true);
     topicLine->setWhatsThis(i18n("<qt><p>Every channel on IRC has a topic associated with it.  This is simply a message that everybody can see.</p><p>If you are an operator, or the channel mode <em>'T'</em> has not been set, then you can change the topic by clicking the Edit Channel Properties button to the left of the topic.  You can also view the history of topics there.</p></qt>"));
-    connect(topicLine, SIGNAL(setStatusBarTempText(QString)), this, SIGNAL(setStatusBarTempText(QString)));
-    connect(topicLine, SIGNAL(clearStatusBarTempText()), this, SIGNAL(clearStatusBarTempText()));
+    connect(topicLine, &TopicLabel::setStatusBarTempText, this, &ChatWindow::setStatusBarTempText);
+    connect(topicLine, &TopicLabel::clearStatusBarTempText, this, &ChatWindow::clearStatusBarTempText);
 
     m_topicHistory = new TopicHistoryModel(this);
-    connect(m_topicHistory, SIGNAL(currentTopicChanged(QString)), topicLine, SLOT(setText(QString)));
+    connect(m_topicHistory, &TopicHistoryModel::currentTopicChanged, topicLine, &TopicLabel::setText);
 
     topicLayout->addWidget(m_topicButton, 0, 0);
     topicLayout->addWidget(topicLine, 0, 1, -1, 1);
@@ -142,7 +136,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     // The box holding the channel modes
     modeBox = new QFrame(topicWidget);
     QHBoxLayout* modeBoxLayout = new QHBoxLayout(modeBox);
-    modeBoxLayout->setMargin(0);
+    modeBoxLayout->setContentsMargins(0, 0, 0, 0);
     modeBox->hide();
     modeBox->setSizePolicy(hfixed);
     modeT = new ModeButton(QStringLiteral("T"),modeBox,0);
@@ -185,8 +179,8 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     modeBoxLayout->addWidget(limit);
     limit->setToolTip(i18n("Maximum users allowed in channel"));
     limit->setWhatsThis(i18n("<qt><p>This is the channel user limit - the maximum number of users that can be in the channel at a time.  If you are an operator, you can set this.  The channel mode <b>T</b>opic (button to left) will automatically be set if set this.</p></qt>"));
-    connect(limit,SIGNAL (returnPressed()),this,SLOT (channelLimitChanged()) );
-    connect(limit,SIGNAL (editingFinished()), this, SLOT(channelLimitChanged()) );
+    connect(limit, QOverload<>::of(&QLineEdit::returnPressed), this, &Channel::channelLimitChanged);
+    connect(limit,&QLineEdit::editingFinished, this, &Channel::channelLimitChanged );
 
     topicLayout->addWidget(modeBox, 0, 2);
     topicLayout->setRowStretch(1, 10);
@@ -210,34 +204,35 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     m_horizSplitter->setStretchFactor(m_horizSplitter->indexOf(nickListButtons), 0);
     QVBoxLayout* nickListButtonsLayout = new QVBoxLayout(nickListButtons);
     nickListButtonsLayout->setSpacing(0);
-    nickListButtonsLayout->setMargin(0);
+    nickListButtonsLayout->setContentsMargins(0, 0, 0, 0);
 
     nicknameListView=new NickListView(nickListButtons, this);
     nickListButtons->layout()->addWidget(nicknameListView);
     nicknameListView->installEventFilter(this);
 
     // initialize buttons grid, will be set up in updateQuickButtons
-    m_buttonsGrid = 0;
+    m_buttonsGrid = nullptr;
 
     // The box holding the Nickname button and Channel input
     commandLineBox = new QFrame(this);
     QHBoxLayout* commandLineLayout = new QHBoxLayout(commandLineBox);
     commandLineBox->setLayout(commandLineLayout);
-    commandLineLayout->setMargin(0);
+    commandLineLayout->setContentsMargins(0, 0, 0, 0);
     commandLineLayout->setSpacing(spacing());
 
     nicknameCombobox = new KComboBox(commandLineBox);
     nicknameCombobox->setEditable(true);
     nicknameCombobox->setSizeAdjustPolicy(KComboBox::AdjustToContents);
-    KLineEdit* nicknameComboboxLineEdit = qobject_cast<KLineEdit*>(nicknameCombobox->lineEdit());
-    if (nicknameComboboxLineEdit) nicknameComboboxLineEdit->setClearButtonShown(false);
+    QLineEdit* nicknameComboboxLineEdit = nicknameCombobox->lineEdit();
+    nicknameComboboxLineEdit->setClearButtonEnabled(false);
     nicknameCombobox->setWhatsThis(i18n("<qt><p>This shows your current nick, and any alternatives you have set up.  If you select or type in a different nickname, then a request will be sent to the IRC server to change your nick.  If the server allows it, the new nickname will be selected.  If you type in a new nickname, you need to press 'Enter' at the end.</p><p>You can edit the alternative nicknames from the <em>Identities</em> option in the <em>Settings</em> menu.</p></qt>"));
 
     awayLabel = new AwayLabel(commandLineBox);
     awayLabel->hide();
     cipherLabel = new QLabel(commandLineBox);
     cipherLabel->hide();
-    cipherLabel->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("document-encrypt"), KIconLoader::Toolbar));
+    const int toolBarIconSize = cipherLabel->style()->pixelMetric(QStyle::PixelMetric::PM_ToolBarIconSize);
+    cipherLabel->setPixmap(QIcon::fromTheme(QStringLiteral("document-encrypt")).pixmap(toolBarIconSize));
     m_inputBar = new IRCInput(commandLineBox);
 
     commandLineLayout->addWidget(nicknameCombobox);
@@ -278,45 +273,45 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     getTextView()->setSizePolicy(greedy);
     nicknameListView->setSizePolicy(hmodest);
 
-    connect(m_inputBar,SIGNAL (submit()),this,SLOT (channelTextEntered()) );
-    connect(m_inputBar,SIGNAL (envelopeCommand()),this,SLOT (channelPassthroughCommand()) );
-    connect(m_inputBar,SIGNAL (nickCompletion()),this,SLOT (completeNick()) );
-    connect(m_inputBar,SIGNAL (endCompletion()),this,SLOT (endCompleteNick()) );
-    connect(m_inputBar,SIGNAL (textPasted(QString)),this,SLOT (textPasted(QString)) );
+    connect(m_inputBar,&IRCInput::submit,this,&Channel::channelTextEntered );
+    connect(m_inputBar,&IRCInput::envelopeCommand,this,&Channel::channelPassthroughCommand );
+    connect(m_inputBar,&IRCInput::nickCompletion,this,&Channel::completeNick );
+    connect(m_inputBar,&IRCInput::endCompletion,this,&Channel::endCompleteNick );
+    connect(m_inputBar,&IRCInput::textPasted,this,&Channel::textPasted );
 
-    connect(getTextView(), SIGNAL(textPasted(bool)), m_inputBar, SLOT(paste(bool)));
-    connect(getTextView(),SIGNAL (gotFocus()),m_inputBar,SLOT (setFocus()) );
-    connect(getTextView(),SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
-    connect(getTextView(),SIGNAL (autoText(QString)),this,SLOT (sendText(QString)) );
+    connect(getTextView(), &IRCView::textPasted, m_inputBar, &IRCInput::paste);
+    connect(getTextView(), &IRCView::gotFocus, m_inputBar, QOverload<>::of(&IRCInput::setFocus));
+    connect(getTextView(), &IRCView::sendFile, this, &Channel::sendFileMenu );
+    connect(getTextView(), &IRCView::autoText, this, &Channel::sendText);
 
-    connect(nicknameListView,SIGNAL (itemDoubleClicked(QTreeWidgetItem*,int)),this,SLOT (doubleClickCommand(QTreeWidgetItem*,int)) );
-    connect(nicknameCombobox,SIGNAL (activated(int)),this,SLOT(nicknameComboboxChanged()));
+    connect(nicknameListView,&QTreeWidget::itemDoubleClicked,this,&Channel::doubleClickCommand );
+    connect(nicknameCombobox, QOverload<int>::of(&KComboBox::activated), this, &Channel::nicknameComboboxChanged);
 
     if(nicknameCombobox->lineEdit())
-        connect(nicknameCombobox->lineEdit(), SIGNAL (returnPressed()),this,SLOT(nicknameComboboxChanged()));
+        connect(nicknameCombobox->lineEdit(), &QLineEdit::returnPressed,this,&Channel::nicknameComboboxChanged);
 
 
-    connect(&userhostTimer,SIGNAL (timeout()),this,SLOT (autoUserhost()));
+    connect(&userhostTimer,&QTimer::timeout,this,&Channel::autoUserhost);
 
     m_whoTimer.setSingleShot(true);
-    connect(&m_whoTimer, SIGNAL(timeout()), this, SLOT(autoWho()));
-    connect(Application::instance(), SIGNAL(appearanceChanged()), this, SLOT(updateAutoWho()));
+    connect(&m_whoTimer, &QTimer::timeout, this, &Channel::autoWho);
+    connect(Application::instance(), &Application::appearanceChanged, this, &Channel::updateAutoWho);
 
     // every 5 minutes decrease everyone's activity by 1 unit
     m_fadeActivityTimer.start(5*60*1000);
 
-    connect(&m_fadeActivityTimer, SIGNAL(timeout()), this, SLOT(fadeActivity()));
+    connect(&m_fadeActivityTimer, &QTimer::timeout, this, &Channel::fadeActivity);
 
     updateAppearance();
 
     #ifdef HAVE_QCA2
-    m_cipher = 0;
+    m_cipher = nullptr;
     #endif
 
     // Setup delayed sort timer
     m_delayedSortTimer = new QTimer(this);
     m_delayedSortTimer->setSingleShot(true);
-    connect(m_delayedSortTimer, SIGNAL(timeout()), this, SLOT(delayedSortNickList()));
+    connect(m_delayedSortTimer, &QTimer::timeout, this, &Channel::delayedSortNickList);
 }
 
 //FIXME there is some logic in setLogfileName that needs to be split out and called here if the server display name gets changed
@@ -324,12 +319,12 @@ void Channel::setServer(Server* server)
 {
     if (m_server != server)
     {
-        connect(server, SIGNAL(connectionStateChanged(Server*,Konversation::ConnectionState)),
-                SLOT(connectionStateChanged(Server*,Konversation::ConnectionState)));
-        connect(server, SIGNAL(nickInfoChanged()),
-                this, SLOT(updateNickInfos()));
-        connect(server, SIGNAL(channelNickChanged(QString)),
-                this, SLOT(updateChannelNicks(QString)));
+        connect(server, &Server::connectionStateChanged,
+                this, &Channel::connectionStateChanged);
+        connect(server, QOverload<>::of(&Server::nickInfoChanged),
+                this, &Channel::updateNickInfos);
+        connect(server, &Server::channelNickChanged,
+                this, &Channel::updateChannelNicks);
     }
 
     ChatWindow::setServer(server);
@@ -339,8 +334,8 @@ void Channel::setServer(Server* server)
     refreshModeButtons();
     nicknameCombobox->setModel(m_server->nickListModel());
 
-    connect(awayLabel, SIGNAL(unaway()), m_server, SLOT(requestUnaway()));
-    connect(awayLabel, SIGNAL(awayMessageChanged(QString)), m_server, SLOT(requestAway(QString)));
+    connect(awayLabel, &AwayLabel::unaway, m_server, &Server::requestUnaway);
+    connect(awayLabel, &AwayLabel::awayMessageChanged, m_server, &Server::requestAway);
 }
 
 void Channel::connectionStateChanged(Server* server, Konversation::ConnectionState state)
@@ -392,15 +387,15 @@ void Channel::setEncryptedOutput(bool e)
 
 Channel::~Channel()
 {
-    qDebug() << "(" << getName() << ")";
+    qCDebug(KONVERSATION_LOG) << "(" << getName() << ")";
 
     // Purge nickname list
     purgeNicks();
-    qDebug() << "Nicks purged.";
+    qCDebug(KONVERSATION_LOG) << "Nicks purged.";
 
     // Unlink this channel from channel list
     m_server->removeChannel(this);
-    qDebug() << "Channel removed.";
+    qCDebug(KONVERSATION_LOG) << "Channel removed.";
 
     if (m_recreationScheduled)
     {
@@ -409,7 +404,7 @@ Channel::~Channel()
     }
 }
 
-bool Channel::rejoinable()
+bool Channel::rejoinable() const
 {
     if (getServer() && getServer()->isConnected())
         return !m_joined;
@@ -423,7 +418,7 @@ void Channel::rejoin()
         m_server->sendJoinCommand(getName(), getPassword());
 }
 
-bool Channel::log()
+bool Channel::log() const
 {
     return ChatWindow::log() && !Preferences::self()->privateOnly();
 }
@@ -440,7 +435,7 @@ ChannelNickPtr Channel::getChannelNick(const QString &ircnick) const
 
 void Channel::purgeNicks()
 {
-    m_ownChannelNick = 0;
+    m_ownChannelNick = nullptr;
 
     // Purge nickname list
     qDeleteAll(nicknameList);
@@ -468,10 +463,12 @@ void Channel::textPasted(const QString& text)
 {
     if(m_server)
     {
-        QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-        for(int index=0;index<multiline.count();index++)
-        {
-            QString line=multiline[index];
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        const QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+        const QStringList multiline = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
+        for (QString line : multiline) {
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
             if(line.startsWith(cChar)) line=cChar+line;
@@ -532,10 +529,10 @@ void Channel::completeNick()
         // remember old cursor position locally
         oldPos = pos;
         // step back to []{}-_^`\| or start of line
-        QString regexpStr("[^A-Z0-9a-z\\_\\[\\]\\{\\}\\-\\^\\`\\\\\\|");
+        QString regexpStr(QStringLiteral("[^A-Z0-9a-z\\_\\[\\]\\{\\}\\-\\^\\`\\\\\\|"));
 
         if(!Preferences::self()->prefixCharacter().isEmpty())
-            regexpStr += "\\" + Preferences::self()->prefixCharacter();
+            regexpStr += QLatin1Char('\\') + Preferences::self()->prefixCharacter();
 
         regexpStr += QLatin1Char(']');
         QRegExp tmp(regexpStr);
@@ -568,7 +565,7 @@ void Channel::completeNick()
                 {
                     if(Preferences::self()->nickCompletionMode() == 1)
                     {
-                        QString nicksFound = found.join(QStringLiteral(" "));
+                        QString nicksFound = found.join(QLatin1Char(' '));
                         appendServerMessage(i18n("Completion"), i18n("Possible completions: %1.", nicksFound));
                     }
                     else
@@ -583,8 +580,7 @@ void Channel::completeNick()
                     uint timeStamp = 0;
                     int listPosition = 0;
 
-                    foreach (Nick* nick, nicknameList)
-                    {
+                    for (Nick* nick : qAsConst(nicknameList)) {
                         if(nick->getChannelNick()->getNickname().startsWith(pattern, Preferences::self()->nickCompletionCaseSensitive() ? Qt::CaseSensitive : Qt::CaseInsensitive) &&
                           (nick->getChannelNick()->timeStamp() > timeStamp))
                         {
@@ -700,7 +696,7 @@ void Channel::setAutoJoin(bool autojoin)
     {
         Konversation::ChannelSettings before;
 
-        QList<Channel *> channelList = m_server->getChannelList();
+        const QList<Channel *> channelList = m_server->getChannelList();
 
         if (channelList.count() > 1)
         {
@@ -709,22 +705,14 @@ void Channel::setAutoJoin(bool autojoin)
             int index = -1;
             int ownIndex = m_server->getViewContainer()->getViewIndex(this);
 
-            foreach (Channel* channel, channelList)
-            {
+            for (Channel* channel : channelList) {
                 index = m_server->getViewContainer()->getViewIndex(channel);
 
                 if (index && index > ownIndex) channelMap.insert(index, channel);
             }
 
-            if (channelMap.count())
-            {
-                QMap<int, Channel*>::Iterator it2;
-                Channel* channel;
-
-                for (it2 = channelMap.begin(); it2 != channelMap.end(); ++it2)
-                {
-                    channel = it2.value();
-
+            if (!channelMap.isEmpty()) {
+                for (Channel* channel : qAsConst(channelMap)) {
                     if (channel->autoJoin())
                     {
                         before = channel->channelSettings();
@@ -747,13 +735,12 @@ void Channel::setAutoJoin(bool autojoin)
 
 
 
-QString Channel::getPassword()
+QString Channel::getPassword() const
 {
     QString password;
 
-    for (QStringList::const_iterator it = m_modeList.constBegin(); it != m_modeList.constEnd(); ++it)
-    {
-        if ((*it)[0] == QLatin1Char('k')) password = (*it).mid(1);
+    for (const QString& mode : m_modeList) {
+        if (mode[0] == QLatin1Char('k')) password = mode.mid(1);
     }
 
     if (password.isEmpty() && m_server->getServerGroup())
@@ -768,7 +755,7 @@ QString Channel::getPassword()
     return password;
 }
 
-const Konversation::ChannelSettings Channel::channelSettings()
+Konversation::ChannelSettings Channel::channelSettings() const
 {
     Konversation::ChannelSettings channel;
 
@@ -817,14 +804,15 @@ void Channel::sendText(const QString& sendLine)
     QString outputAll(sendLine);
 
     // replace aliases and wildcards
-    m_server->getOutputFilter()->replaceAliases(outputAll, this);
+    OutputFilter::replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-    QStringList outList = outputAll.split(QRegExp(QStringLiteral("[\r\n]+")), QString::SkipEmptyParts);
-    for(int index=0;index<outList.count();index++)
-    {
-        QString output(outList[index]);
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    const QStringList outList = outputAll.split(QRegExp(QStringLiteral("[\r\n]+")), QString::SkipEmptyParts);
+#else
+    const QStringList outList = outputAll.split(QRegExp(QStringLiteral("[\r\n]+")), Qt::SkipEmptyParts);
+#endif
+    for (const QString& output : outList){
         // encoding stuff is done in Server()
         Konversation::OutputFilterResult result = m_server->getOutputFilter()->parse(m_server->getNickname(), output, getName(), this);
 
@@ -837,14 +825,12 @@ void Channel::sendText(const QString& sendLine)
             else if(result.type == Konversation::PrivateMessage) msgHelper(result.typeString, result.output);
             else append(m_server->getNickname(), result.output);
         }
-        else if (result.outputList.count())
-        {
+        else if (!result.outputList.isEmpty()) {
             if (result.type == Konversation::Message)
             {
-                QStringListIterator it(result.outputList);
-
-                while (it.hasNext())
-                    append(m_server->getNickname(), it.next());
+                for (const QString& out : qAsConst(result.outputList)) {
+                    append(m_server->getNickname(), out);
+                }
             }
             else if (result.type == Konversation::Action)
             {
@@ -871,12 +857,11 @@ void Channel::setNickname(const QString& newNickname)
     nicknameCombobox->setCurrentIndex(nicknameCombobox->findText(newNickname));
 }
 
-QStringList Channel::getSelectedNickList()
+QStringList Channel::getSelectedNickList() const
 {
     QStringList selectedNicks;
 
-    foreach (Nick* nick, nicknameList)
-    {
+    for (Nick* nick : qAsConst(nicknameList)) {
         if (nick->isSelected())
             selectedNicks << nick->getChannelNick()->getNickname();
     }
@@ -893,7 +878,7 @@ void Channel::channelLimitChanged()
 
 void Channel::modeButtonClicked(int id, bool on)
 {
-    char mode[]={'t','n','s','i','p','m','k','l'};
+    const char mode[] = {'t','n','s','i','p','m','k','l'};
     QString command(QStringLiteral("MODE %1 %2%3 %4"));
     QString args = getPassword();
 
@@ -929,7 +914,7 @@ void Channel::modeButtonClicked(int id, bool on)
             args=limit->text();
     }
     // put together the mode command and send it to the server queue
-    m_server->queue(command.arg(getName()).arg((on) ? QStringLiteral("+") : QStringLiteral("-")).arg(mode[id]).arg(args));
+    m_server->queue(command.arg(getName(), (on) ? QStringLiteral("+") : QStringLiteral("-")).arg(mode[id]).arg(args));
 }
 
 void Channel::quickButtonClicked(const QString &buttonText)
@@ -949,10 +934,9 @@ void Channel::addNickname(ChannelNickPtr channelnick)
 {
     QString nickname = channelnick->loweredNickname();
 
-    Nick* nick=0;
+    Nick* nick=nullptr;
 
-    foreach (Nick* lookNick, nicknameList)
-    {
+    for (Nick* lookNick : qAsConst(nicknameList)) {
         if(lookNick->getChannelNick()->loweredNickname() == nickname)
         {
             nick = lookNick;
@@ -960,7 +944,7 @@ void Channel::addNickname(ChannelNickPtr channelnick)
         }
     }
 
-    if (nick == 0)
+    if (nick == nullptr)
     {
         fastAddNickname(channelnick);
 
@@ -1019,7 +1003,7 @@ void Channel::fastAddNickname(ChannelNickPtr channelnick, Nick *nick)
         // nicks get sorted later
         nicknameList.append(nick);
     } else {
-        NickList::iterator it = qLowerBound(nicknameList.begin(), nicknameList.end(), nick, nickLessThan);
+        NickList::iterator it = std::lower_bound(nicknameList.begin(), nicknameList.end(), nick, nickLessThan);
         nicknameList.insert(it, nick);
     }
 
@@ -1027,7 +1011,7 @@ void Channel::fastAddNickname(ChannelNickPtr channelnick, Nick *nick)
 }
 
 /* Determines whether Nick/Part/Join event should be shown or skipped based on user settings. */
-bool Channel::shouldShowEvent(ChannelNickPtr channelNick)
+bool Channel::shouldShowEvent(ChannelNickPtr channelNick) const
 {
     if (Preferences::self()->hideUnimportantEvents())
     {
@@ -1037,7 +1021,7 @@ bool Channel::shouldShowEvent(ChannelNickPtr channelNick)
 
             if (Preferences::self()->hideUnimportantEventsExcludeActiveThreshold() == 0) // last 10 minutes
                 activityThreshold = 600;
-            if (Preferences::self()->hideUnimportantEventsExcludeActiveThreshold() == 1) // last hour
+            else if (Preferences::self()->hideUnimportantEventsExcludeActiveThreshold() == 1) // last hour
                 activityThreshold = 3600;
             else if (Preferences::self()->hideUnimportantEventsExcludeActiveThreshold() == 2) // last day
                 activityThreshold = 86400;
@@ -1046,7 +1030,7 @@ bool Channel::shouldShowEvent(ChannelNickPtr channelNick)
 
             if (m_server->isWatchedNick(channelNick->getNickname()))
                 return true; // nick is on our watched list, so we probably want to see the event
-            else if (channelNick->timeStamp()+activityThreshold > QDateTime::currentDateTime().toTime_t())
+            else if (channelNick->timeStamp()+activityThreshold > QDateTime::currentDateTime().toSecsSinceEpoch())
                 return true; // the nick has spoken within activity threshold
             else
                 return false;
@@ -1216,7 +1200,7 @@ void Channel::removeNick(ChannelNickPtr channelNick, const QString &reason, bool
         }
         else
         {
-            qWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
+            qCWarning(KONVERSATION_LOG) << "Nickname " << channelNick->getNickname() << " not found!";
         }
     }
 }
@@ -1302,9 +1286,9 @@ void Channel::kickNick(ChannelNickPtr channelNick, const QString &kicker, const
         adjustNicks(-1);
         Nick* nick = getNickByName(channelNick->loweredNickname());
 
-        if(nick == 0)
+        if(nick == nullptr)
         {
-            qWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
+            qCWarning(KONVERSATION_LOG) << "Nickname " << channelNick->getNickname() << " not found!";
         }
         else
         {
@@ -1365,7 +1349,7 @@ void Channel::emitUpdateInfo()
     emit updateInfo(info);
 }
 
-QString Channel::getTopic()
+QString Channel::getTopic() const
 {
     return m_topicHistory->currentTopic();
 }
@@ -1850,9 +1834,9 @@ void Channel::clearModeList()
     QString k;
 
     // Keep channel password in the backing store, for rejoins.
-    for (QStringList::const_iterator it = m_modeList.constBegin(); it != m_modeList.constEnd(); ++it)
-    {
-        if ((*it)[0] == QLatin1Char('k')) k = (*it);
+    for (const QString& mode : qAsConst(m_modeList)) {
+        if (mode[0] == QLatin1Char('k'))
+            k = mode;
     }
 
     m_modeList.clear();
@@ -1890,7 +1874,7 @@ void Channel::clearModeList()
 
 void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
 {
-    ModeButton* widget=0;
+    ModeButton* widget=nullptr;
 
     if(mode=='t') widget=modeT;
     else if(mode=='n') widget=modeN;
@@ -1914,9 +1898,8 @@ void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
     }
     else
     {
-        QStringList removable = m_modeList.filter(QRegExp(QString(QStringLiteral("^%1.*")).arg(mode)));
-        foreach(const QString &mode, removable)
-        {
+        const QStringList removable = m_modeList.filter(QRegExp(QStringLiteral("^%1.*").arg(mode)));
+        for (const QString &mode : removable) {
             m_modeList.removeOne(mode);
         }
     }
@@ -1926,14 +1909,14 @@ void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
 void Channel::updateQuickButtons()
 {
     delete m_buttonsGrid;
-    m_buttonsGrid = 0;
+    m_buttonsGrid = nullptr;
 
     // the grid that holds the quick action buttons
     m_buttonsGrid = new QWidget (nickListButtons); //Q3Grid(2, nickListButtons);
     nickListButtons->layout()->addWidget(m_buttonsGrid);
     m_buttonsGrid->hide();
     QGridLayout* layout = new QGridLayout (m_buttonsGrid);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     int col = 0;
     int row = 0;
@@ -1949,7 +1932,7 @@ void Channel::updateQuickButtons()
         layout->addWidget (quickButton, row, col);
         row += col;
 
-        connect(quickButton, SIGNAL(clicked(QString)), this, SLOT(quickButtonClicked(QString)));
+        connect(quickButton, QOverload<const QString&>::of(&QuickButton::clicked), this, &Channel::quickButtonClicked);
 
         // Get the button definition
         QString buttonText=newButtonList[index];
@@ -2072,7 +2055,7 @@ void Channel::syncSplitters()
 
     if (vertSizes.isEmpty())
     {
-        vertSizes << m_topicButton->height() << (height() - m_topicButton->height());
+        vertSizes = { m_topicButton->height(), (height() - m_topicButton->height()) };
         Preferences::self()->setTopicSplitterSizes(vertSizes);
     }
 
@@ -2081,7 +2064,7 @@ void Channel::syncSplitters()
         // An approximation of a common NICKLEN plus the width of the icon,
         // tested with 8pt and 10pt DejaVu Sans and Droid Sans.
         int listWidth = fontMetrics().averageCharWidth() * 17 + 20;
-        horizSizes << (width() - listWidth) << listWidth;
+        horizSizes = { (width() - listWidth), listWidth };
         Preferences::self()->setChannelSplitterSizes(horizSizes);
     }
 
@@ -2143,7 +2126,7 @@ void Channel::updateAppearance()
     if (m_delayedSortTimer)
     {
         m_delayedSortTrigger = DELAYED_SORT_TRIGGER + 1;
-        m_delayedSortTimer->start(500 + qrand()%2000);
+        m_delayedSortTimer->start(500 + QRandomGenerator::global()->bounded(2000));
     }
 
     ChatWindow::updateAppearance();
@@ -2184,7 +2167,7 @@ void Channel::endOfNames()
     {
         m_initialNamesReceived = true;
 
-        if (m_server->hasAwayNotify() && !Preferences::self()->autoWhoContinuousEnabled())
+        if (m_server->capabilities() & Server::AwayNotify && !Preferences::self()->autoWhoContinuousEnabled())
         {
             // Do one who request to get the initial away state for the channel
             QMetaObject::invokeMethod(m_server, "requestWho", Qt::QueuedConnection, Q_ARG(QString, getName()));
@@ -2249,8 +2232,7 @@ void Channel::autoUserhost()
 
         QString nickString;
 
-        foreach (Nick* nick, getNickList())
-        {
+        for (Nick* nick : qAsConst(nicknameList)) {
             if(nick->getChannelNick()->getHostmask().isEmpty())
             {
                 if(limit--) nickString = nickString + nick->getChannelNick()->getNickname() + QLatin1Char(' ');
@@ -2280,7 +2262,7 @@ void Channel::setAutoUserhost(bool state)
         nicknameListView->header()->setSectionResizeMode(Nick::HostmaskColumn, QHeaderView::Fixed);
         userhostTimer.start(10000);
         m_nicknameListViewTextChanged |= 0xFF; // ResizeColumnsToContents
-        QTimer::singleShot(0, this, SLOT(autoUserhost())); // resize columns ASAP
+        QTimer::singleShot(0, this, &Channel::autoUserhost); // resize columns ASAP
     }
     else
     {
@@ -2306,6 +2288,9 @@ void Channel::scheduleAutoWho(int msec)
     // If this is called mid-interval (e.g. due to the ENDOFWHO from a manual WHO)
     // it will reset the interval to avoid cutting it short.
 
+    if (m_server->whoRequestsDisabled())
+        return;
+
     if (m_whoTimer.isActive())
         m_whoTimer.stop();
 
@@ -2330,6 +2315,7 @@ void Channel::autoWho()
     }
 
     m_server->requestWho(getName());
+    m_whoTimerStarted.start();
 }
 
 void Channel::updateAutoWho()
@@ -2385,17 +2371,17 @@ void Channel::updateAutoWho()
 
 void Channel::fadeActivity()
 {
-    foreach (Nick *nick,  nicknameList) {
+    for (Nick *nick : qAsConst(nicknameList)) {
         nick->getChannelNick()->lessActive();
     }
 }
 
-bool Channel::canBeFrontView()
+bool Channel::canBeFrontView() const
 {
     return true;
 }
 
-bool Channel::searchView()
+bool Channel::searchView() const
 {
     return true;
 }
@@ -2510,14 +2496,14 @@ void Channel::processQueuedNicks(bool flush)
 
         QString userHost;
 
-        if(m_server->hasUserHostInNames())
+        if(m_server->capabilities() & Server::UserHostInNames)
         {
             int index = nickname.indexOf(QLatin1Char('!'));
 
             if(index >= 0)
             {
                 userHost = nickname.mid(index + 1);
-                nickname = nickname.left(index);
+                nickname.truncate(index);
             }
         }
 
@@ -2570,14 +2556,14 @@ void Channel::setChannelEncoding(const QString& encoding) // virtual
         Preferences::setChannelEncoding(m_server->getDisplayName(), getName(), encoding);
 }
 
-QString Channel::getChannelEncoding() // virtual
+QString Channel::getChannelEncoding() const // virtual
 {
     if(m_server->getServerGroup())
         return Preferences::channelEncoding(m_server->getServerGroup()->id(), getName());
     return Preferences::channelEncoding(m_server->getDisplayName(), getName());
 }
 
-QString Channel::getChannelEncodingDefaultDesc()  // virtual
+QString Channel::getChannelEncodingDefaultDesc() const  // virtual
 {
     return i18n("Identity Default ( %1 )", getServer()->getIdentity()->getCodecName());
 }
@@ -2648,7 +2634,7 @@ void Channel::repositionNick(Nick *nick)
         nicknameList.removeAt(index);
         fastAddNickname(nick->getChannelNick(), nick);
     } else {
-        qWarning() << "Nickname " << nick->getChannelNick()->getNickname() << " not found!"<< endl;
+        qCWarning(KONVERSATION_LOG) << "Nickname " << nick->getChannelNick()->getNickname() << " not found!";
     }
 }
 
@@ -2696,8 +2682,8 @@ void Channel::addBan(const QString& ban)
 
 void Channel::removeBan(const QString& ban)
 {
-  foreach(const QString &string, m_BanList)
-  {
+  const QStringList currentBanList = m_BanList;
+  for (const QString &string : currentBanList) {
     if (string.section(QLatin1Char(' '), 0, 0) == ban)
     {
       m_BanList.removeOne(string);
@@ -2720,7 +2706,7 @@ void Channel::append(const QString& nickname, const QString& message, const QHas
         Nick* nick = getNickByName(nickname);
 
         if(nick) {
-            nick->getChannelNick()->setTimeStamp(QDateTime::currentDateTime().toTime_t());
+            nick->getChannelNick()->setTimeStamp(QDateTime::currentDateTime().toSecsSinceEpoch());
         }
     }
 
@@ -2734,7 +2720,7 @@ void Channel::appendAction(const QString& nickname, const QString& message, cons
         Nick* nick = getNickByName(nickname);
 
         if(nick) {
-            nick->getChannelNick()->setTimeStamp(QDateTime::currentDateTime().toTime_t());
+            nick->getChannelNick()->setTimeStamp(QDateTime::currentDateTime().toSecsSinceEpoch());
         }
     }
 
@@ -2761,7 +2747,7 @@ void Channel::nickActive(const QString& nickname) //FIXME reported to crash, can
 }
 
 #ifdef HAVE_QCA2
-Konversation::Cipher* Channel::getCipher()
+Konversation::Cipher* Channel::getCipher() const
 {
     if(!m_cipher)
         m_cipher = new Konversation::Cipher();
@@ -2771,8 +2757,7 @@ Konversation::Cipher* Channel::getCipher()
 
 void Channel::updateNickInfos()
 {
-    foreach(Nick* nick, nicknameList)
-    {
+    for (Nick* nick : qAsConst(nicknameList)) {
         if(nick->getChannelNick()->getNickInfo()->isChanged())
         {
             nick->refresh();
@@ -2785,8 +2770,7 @@ void Channel::updateChannelNicks(const QString& channel)
     if(channel != name.toLower())
         return;
 
-    foreach(Nick* nick, nicknameList)
-    {
+    for (Nick* nick : qAsConst(nicknameList)) {
         if(nick->getChannelNick()->isChanged())
         {
             nick->refresh();
@@ -2819,7 +2803,7 @@ NickList::NickList() : QList<Nick*>()
 }
 
 QString NickList::completeNick(const QString& pattern, bool& complete, QStringList& found,
-                   bool skipNonAlfaNum, bool caseSensitive)
+                   bool skipNonAlfaNum, bool caseSensitive) const
 {
     found.clear();
     QString prefix(QLatin1Char('^'));
@@ -2835,8 +2819,7 @@ QString NickList::completeNick(const QString& pattern, bool& complete, QStringLi
     QRegExp regexp(prefix + QRegExp::escape(pattern));
     regexp.setCaseSensitivity(caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
 
-    foreach (Nick* nick, *this)
-    {
+    for (Nick* nick : *this) {
         newNick = nick->getChannelNick()->getNickname();
 
         if(!prefix.isEmpty() && newNick.contains(prefixCharacter))
@@ -2852,8 +2835,8 @@ QString NickList::completeNick(const QString& pattern, bool& complete, QStringLi
 
     std::sort(foundNicks.begin(), foundNicks.end(), nickTimestampLessThan);
 
-    foreach (Nick *nick, foundNicks)
-    {
+    found.reserve(found.size() + foundNicks.size());
+    for (Nick *nick : qAsConst(foundNicks)) {
         found.append(nick->getChannelNick()->getNickname());
     }
 
@@ -2889,10 +2872,9 @@ QString NickList::completeNick(const QString& pattern, bool& complete, QStringLi
     return QString();
 }
 
-bool NickList::containsNick(const QString& nickname)
+bool NickList::containsNick(const QString& nickname) const
 {
-    foreach (Nick* nick, *this)
-    {
+    for (Nick* nick : *this) {
         if (nick->getChannelNick()->getNickname()==nickname)
             return true;
     }
