@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Nick Information
-  begin:     Sat Jan 17 2004
-  copyright: (C) 2004 by Gary Cramblitt
-  email:     garycramblitt@comcast.net
+    SPDX-FileCopyrightText: 2004 Gary Cramblitt <garycramblitt@comcast.net>
 */
 
 /*
@@ -87,7 +79,7 @@ QDateTime NickInfo::getOnlineSince() const
     return m_onlineSince;
 }
 
-uint NickInfo::getNickColor()
+uint NickInfo::getNickColor() const
 {
     // do we already have a color?
     if (!m_nickColor) m_nickColor = Konversation::colorForNick(m_nickname) + 1;
@@ -205,7 +197,7 @@ QString NickInfo::tooltip() const
 }
 
 
-QString NickInfo::getBestAddresseeName()
+QString NickInfo::getBestAddresseeName() const
 {
     if(!getRealName().isEmpty())
     {
@@ -248,7 +240,7 @@ void NickInfo::setPrintedOnline(bool printed)
     m_printedOnline=printed;
 }
 
-bool NickInfo::getPrintedOnline()
+bool NickInfo::getPrintedOnline() const
 {
     return m_printedOnline;
 }
