@@ -1,17 +1,9 @@
 // -*- mode: c++; c-file-style: "bsd"; c-basic-offset: 4; tabs-width: 4; indent-tabs-mode: nil -*-
 
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  shows a user tree of friends per server
-  begin:     Sam Aug 31 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "nicksonline.h"
@@ -25,13 +17,10 @@
 #include "query.h"
 #include "mainwindow.h"
 #include "viewcontainer.h"
-#include "nicksonlineitem.h"
 
-#include <QInputDialog>
 #include <QToolTip>
 #include <QTreeWidget>
 
-#include <KIconLoader>
 #include <KToolBar>
 
 
@@ -83,7 +72,7 @@ NicksOnline::NicksOnline(QWidget* parent): ChatWindow(parent)
 
     connect(m_nickListView, &QTreeWidget::itemDoubleClicked, this, &NicksOnline::processDoubleClick);
 
-    setupToolbarActions(0);
+    setupToolbarActions(nullptr);
 
     // Create context menu.
     m_popupMenu = new QMenu(this);
@@ -116,7 +105,7 @@ bool NicksOnline::eventFilter(QObject*obj, QEvent* event )
 {
     if( ( obj == m_nickListView->viewport() ) && ( event->type() == QEvent::ToolTip ) )
     {
-        QHelpEvent* helpEvent = static_cast<QHelpEvent*>( event );
+        auto* helpEvent = static_cast<QHelpEvent*>(event);
 
         QTreeWidgetItem *item = m_nickListView->itemAt( helpEvent->pos() );
 
@@ -142,11 +131,6 @@ bool NicksOnline::eventFilter(QObject*obj, QEvent* event )
     return ChatWindow::eventFilter( obj, event );
 }
 
-QTreeWidget* NicksOnline::getNickListView()
-{
-    return m_nickListView;
-}
-
 /**
  * Returns the named child of parent item in a NicksOnlineItem
  * @param parent            Pointer to a NicksOnlineItem.
@@ -154,15 +138,17 @@ QTreeWidget* NicksOnline::getNickListView()
  * @param type              The type of entry to be found
  * @return                  Pointer to the child QListViewItem or 0 if not found.
  */
-QTreeWidgetItem* NicksOnline::findItemChild(const QTreeWidgetItem* parent, const QString& name, NicksOnlineItem::NickListViewColumn type)
+QTreeWidgetItem* NicksOnline::findItemChild(const QTreeWidgetItem* parent, const QString& name,
+                                            NicksOnlineItem::NickListViewColumn type) const
 {
-    if (!parent) return 0;
+    if (!parent) return nullptr;
     for (int i = 0; i < parent->childCount(); ++i)
     {
         QTreeWidgetItem* child = parent->child(i);
-        if(static_cast<NicksOnlineItem*>(child)->type() == type && child->text(0) == name) return child;
+        if (static_cast<NicksOnlineItem*>(child)->type() == type && child->text(0) == name)
+            return child;
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -171,15 +157,16 @@ QTreeWidgetItem* NicksOnline::findItemChild(const QTreeWidgetItem* parent, const
  * @param type              The type of entry to be found
  * @return                  Pointer to the child QListViewItem or 0 if not found.
  */
-QTreeWidgetItem* NicksOnline::findItemType(const QTreeWidgetItem* parent, NicksOnlineItem::NickListViewColumn type)
+QTreeWidgetItem* NicksOnline::findItemType(const QTreeWidgetItem* parent, NicksOnlineItem::NickListViewColumn type) const
 {
-    if (!parent) return 0;
+    if (!parent) return nullptr;
     for (int i = 0; i < parent->childCount(); ++i)
     {
         QTreeWidgetItem* child = parent->child(i);
-        if(static_cast<NicksOnlineItem*>(child)->type() == type) return child;
+        if (static_cast<NicksOnlineItem*>(child)->type() == type)
+            return child;
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -187,7 +174,7 @@ QTreeWidgetItem* NicksOnline::findItemType(const QTreeWidgetItem* parent, NicksO
  * @param name              The name of the network.
  * @return                  Pointer to the QListViewItem or 0 if not found.
  */
-QTreeWidgetItem* NicksOnline::findNetworkRoot(int serverGroupId)
+QTreeWidgetItem* NicksOnline::findNetworkRoot(int serverGroupId) const
 {
     for (int i = 0; i < m_nickListView->invisibleRootItem()->childCount(); ++i)
     {
@@ -197,7 +184,7 @@ QTreeWidgetItem* NicksOnline::findNetworkRoot(int serverGroupId)
             return child;
     }
 
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -208,7 +195,7 @@ QTreeWidgetItem* NicksOnline::findNetworkRoot(int serverGroupId)
  * @return needWhois        True if a WHOIS needs to be performed on the nick
  *                          to get additional information.
  */
-QString NicksOnline::getNickAdditionalInfo(NickInfoPtr nickInfo, bool& needWhois)
+QString NicksOnline::getNickAdditionalInfo(NickInfoPtr nickInfo, bool& needWhois) const
 {
     Q_UNUSED(needWhois)
 
@@ -219,17 +206,17 @@ QString NicksOnline::getNickAdditionalInfo(NickInfoPtr nickInfo, bool& needWhois
         {
             niInfo += i18n("Away");
             if (!nickInfo->getAwayMessage().isEmpty())
-                niInfo += QStringLiteral(" (") + nickInfo->getAwayMessage() + QLatin1Char(')');
+                niInfo += QLatin1String(" (") + nickInfo->getAwayMessage() + QLatin1Char(')');
         }
         if (!nickInfo->getHostmask().isEmpty())
             niInfo += QLatin1Char(' ') + nickInfo->getHostmask();
         if (!nickInfo->getRealName().isEmpty())
-            niInfo += QStringLiteral(" (") + nickInfo->getRealName() + QLatin1Char(')');
+            niInfo += QLatin1String(" (") + nickInfo->getRealName() + QLatin1Char(')');
         if (!nickInfo->getNetServer().isEmpty())
         {
             niInfo += i18n( " online via %1", nickInfo->getNetServer() );
             if (!nickInfo->getNetServerInfo().isEmpty())
-                niInfo += QStringLiteral(" (") + nickInfo->getNetServerInfo() + QLatin1Char(')');
+                niInfo += QLatin1String(" (") + nickInfo->getNetServerInfo() + QLatin1Char(')');
         }
         if (!nickInfo->getOnlineSince().isNull())
             niInfo += i18n( " since %1", nickInfo->getPrettyOnlineSince() );
@@ -266,17 +253,17 @@ void NicksOnline::updateServerOnlineList(Server* servr)
     // watch list.
     networkRoot->setText(nlvcServerName, serverName);
     // Update list of servers in the network that are connected.
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList serverList = networkRoot->text(nlvcAdditionalInfo).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    QStringList serverList = networkRoot->text(nlvcAdditionalInfo).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     if (!serverList.contains(serverName)) serverList.append(serverName);
-    networkRoot->setText(nlvcAdditionalInfo, serverList.join(QStringLiteral(",")));
+    networkRoot->setText(nlvcAdditionalInfo, serverList.join(QLatin1Char(',')));
     // Get watch list.
-    QStringList watchList = servr->getWatchList();
-    QStringList::iterator itEnd = watchList.end();
-    QString nickname;
+    const QStringList watchList = servr->getWatchList();
 
-    for (QStringList::iterator it = watchList.begin(); it != itEnd; ++it)
-    {
-        nickname = (*it);
+    for (const QString& nickname : watchList) {
         NickInfoPtr nickInfo = getOnlineNickInfo(networkName, nickname);
 
         if (nickInfo && nickInfo->getPrintedOnline())
@@ -291,7 +278,7 @@ void NicksOnline::updateServerOnlineList(Server* servr)
             QTreeWidgetItem* nickRoot = findItemChild(networkRoot, nickname, NicksOnlineItem::NicknameItem);
             if (!nickRoot)
                 nickRoot = new NicksOnlineItem(NicksOnlineItem::NicknameItem, networkRoot, nickname, nickAdditionalInfo);
-            NicksOnlineItem* nickitem = static_cast<NicksOnlineItem*>(nickRoot);
+            auto* nickitem = static_cast<NicksOnlineItem*>(nickRoot);
             nickitem->setConnectionId(server->connectionId ());
             // Mark nick as online
             nickitem->setOffline(false);
@@ -309,18 +296,14 @@ void NicksOnline::updateServerOnlineList(Server* servr)
                 }
             }
 
-            QStringList channelList = server->getNickChannels(nickname);
-            QStringList::iterator itEnd2 = channelList.end();
+            const QStringList channelList = server->getNickChannels(nickname);
 
-            for (QStringList::iterator it2 = channelList.begin(); it2 != itEnd2; ++it2)
-            {
+            for (const QString& channelName : channelList) {
                 // Known channels where nickname is online and mode in each channel.
                 // FIXME: If user connects to multiple servers in same network, the
                 // channel info will differ between the servers, resulting in inaccurate
                 // mode and led info displayed.
 
-                QString channelName = (*it2);
-
                 ChannelNickPtr channelNick = server->getChannelNick(channelName, nickname);
                 QString nickMode;
                 if (channelNick->hasVoice()) nickMode = nickMode + i18n(" Voice");
@@ -363,7 +346,7 @@ void NicksOnline::updateServerOnlineList(Server* servr)
                 nickRoot = new NicksOnlineItem(NicksOnlineItem::NicknameItem, networkRoot, nickname);
             // remove channels from the nick
             qDeleteAll(nickRoot->takeChildren());
-            NicksOnlineItem* nickitem = static_cast<NicksOnlineItem*>(nickRoot);
+            auto* nickitem = static_cast<NicksOnlineItem*>(nickRoot);
             nickitem->setConnectionId(servr->connectionId ());
             // Mark nick as offline
             nickitem->setOffline (true);
@@ -389,8 +372,8 @@ void NicksOnline::updateServerOnlineList(Server* servr)
     {
         networkRoot->setExpanded(true);
         // Connect server NickInfo updates.
-        connect (servr, SIGNAL(nickInfoChanged(Server*,NickInfoPtr)),
-            this, SLOT(slotNickInfoChanged(Server*,NickInfoPtr)));
+        connect (servr, QOverload<Server*, NickInfoPtr>::of(&Server::nickInfoChanged),
+            this, &NicksOnline::slotNickInfoChanged);
     }
 }
 
@@ -401,13 +384,12 @@ void NicksOnline::updateServerOnlineList(Server* servr)
  * @param nickname           Nick name.
  * @return                   NickInfo if nick is online in any server, otherwise 0.
  */
-NickInfoPtr NicksOnline::getOnlineNickInfo(QString& networkName, QString& nickname)
+NickInfoPtr NicksOnline::getOnlineNickInfo(const QString& networkName, const QString& nickname) const
 {
     // Get list of pointers to all servers.
     Application* konvApp = Application::instance();
     const QList<Server*> serverList = konvApp->getConnectionManager()->getServerList();
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         if (server->getDisplayName() == networkName)
         {
             NickInfoPtr nickInfo = server->getNickInfo(nickname);
@@ -423,12 +405,11 @@ NickInfoPtr NicksOnline::getOnlineNickInfo(QString& networkName, QString& nickna
  * @param groupName          Server group name.
  * @param nickname           Nick name.
  */
-void NicksOnline::requestWhois(QString& networkName, QString& nickname)
+void NicksOnline::requestWhois(const QString& networkName, const QString& nickname)
 {
     Application* konvApp = Application::instance();
     const QList<Server*> serverList = konvApp->getConnectionManager()->getServerList();
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         if (server->getDisplayName() == networkName)
         {
             server->requestWhois(nickname);
@@ -452,7 +433,7 @@ void NicksOnline::updateNotifyList()
     QStringList nicks;
     for (int j = 0; j < networkRoot->childCount(); ++j)
     {
-      NicksOnlineItem *item = dynamic_cast<NicksOnlineItem*>(networkRoot->child(j));
+      auto* item = static_cast<NicksOnlineItem*>(networkRoot->child(j));
       if (item->type() == NicksOnlineItem::NicknameItem)
       {
         // add the nick to the list
@@ -480,7 +461,11 @@ void NicksOnline::refreshAllServerOnlineLists()
     {
         QTreeWidgetItem *child = m_nickListView->invisibleRootItem()->child(i);
         QString networkName = child->text(nlvcNetwork);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList serverNameList = child->text(nlvcAdditionalInfo).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+        QStringList serverNameList = child->text(nlvcAdditionalInfo).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
         QStringList::Iterator itEnd = serverNameList.end();
         QStringList::Iterator it = serverNameList.begin();
         while (it != itEnd)
@@ -488,8 +473,7 @@ void NicksOnline::refreshAllServerOnlineLists()
             QString serverName = *it;
             // Locate server in server list.
             bool found = false;
-            foreach (Server* server, serverList)
-            {
+            for (Server* server : serverList) {
                 if ((server->getServerName() == serverName) &&
                     (server->getDisplayName() == networkName)) found = true;
             }
@@ -506,11 +490,10 @@ void NicksOnline::refreshAllServerOnlineLists()
             i--;
         }
         else
-            child->setText(nlvcAdditionalInfo, serverNameList.join(QStringLiteral(",")));
+            child->setText(nlvcAdditionalInfo, serverNameList.join(QLatin1Char(',')));
     }
     // Display info for all currently-connected servers.
-    foreach (Server* server, serverList)
-    {
+    for (Server* server : serverList) {
         updateServerOnlineList(server);
     }
     // Refresh buttons.
@@ -530,7 +513,7 @@ void NicksOnline::timerFired()
  */
 void NicksOnline::processDoubleClick(QTreeWidgetItem* item, int column)
 {
-    Q_UNUSED(column);
+    Q_UNUSED(column)
 
     NicksOnlineItem* nickitem = dynamic_cast<NicksOnlineItem*>(item);
 
@@ -542,7 +525,7 @@ void NicksOnline::processDoubleClick(QTreeWidgetItem* item, int column)
         emit doubleClicked(nickitem->connectionId(), nickitem->text(nlvcNick));
     if (nickitem->type() == NicksOnlineItem::ChannelItem)
     {
-      NicksOnlineItem* nickRoot = dynamic_cast<NicksOnlineItem*>(nickitem->parent());
+      auto* nickRoot = static_cast<NicksOnlineItem*>(nickitem->parent());
       Server* server = Application::instance()->getConnectionManager()->getServerByConnectionId(nickRoot->connectionId());
       ChatWindow* channel = server->getChannelByName(nickitem->text(nlvcChannel));
 
@@ -562,11 +545,11 @@ void NicksOnline::processDoubleClick(QTreeWidgetItem* item, int column)
  * @return serverName       Name of the server for the nick at the item, or Null if not a nick.
  * @return nickname         The nickname at the item.
  */
-bool NicksOnline::getItemServerAndNick(const QTreeWidgetItem* item, QString& serverName, QString& nickname)
+bool NicksOnline::getItemServerAndNick(const QTreeWidgetItem* item, QString& serverName, QString& nickname) const
 {
     if (!item) return false;
     // convert into NicksOnlineItem
-    const NicksOnlineItem* nlItem=static_cast<const NicksOnlineItem*>(item);
+    const auto* nlItem = static_cast<const NicksOnlineItem*>(item);
     // If on a network, return false;
     if (nlItem->type() == NicksOnlineItem::NetworkRootItem) return false;
     // get server name
@@ -581,7 +564,7 @@ bool NicksOnline::getItemServerAndNick(const QTreeWidgetItem* item, QString& ser
     return true;
 }
 
-NickInfoPtr NicksOnline::getNickInfo(const QTreeWidgetItem* item)
+NickInfoPtr NicksOnline::getNickInfo(const QTreeWidgetItem* item) const
 {
     QString serverName;
     QString nickname;
@@ -609,15 +592,15 @@ NickInfoPtr NicksOnline::getNickInfo(const QTreeWidgetItem* item)
  * @see getItemServerAndNick
  */
 QTreeWidgetItem* NicksOnline::getServerAndNickItem(const QString& serverName,
-const QString& nickname)
+                                                   const QString& nickname) const
 {
     Server* server = Application::instance()->getConnectionManager()->getServerByName(serverName);
-    if (!server) return 0;
+    if (!server) return nullptr;
     QString networkName = server->getDisplayName();
     QList<QTreeWidgetItem*> items = m_nickListView->findItems(networkName, Qt::MatchExactly | Qt::MatchCaseSensitive, nlvcNetwork);
-    if (items.count() == 0) return 0;
+    if (items.isEmpty()) return nullptr;
     QTreeWidgetItem* networkRoot = items.at(0);
-    if (!networkRoot) return 0;
+    if (!networkRoot) return nullptr;
     QTreeWidgetItem* nickRoot = findItemChild(networkRoot, nickname, NicksOnlineItem::NicknameItem);
     return nickRoot;
 }
@@ -634,19 +617,18 @@ const QString& nickname)
  */
 void NicksOnline::doCommand(QAction* id)
 {
-    if(id == 0)
+    if(id == nullptr)
         return;
     if ( id == m_addNickname )
     {
         int serverGroupId = -1;
 
-        if (m_nickListView->selectedItems().count())
-        {
+        if (!m_nickListView->selectedItems().isEmpty()) {
             NicksOnlineItem *networkRoot = dynamic_cast<NicksOnlineItem*>(m_nickListView->selectedItems().at(0));
             if (networkRoot)
             {
                 while (networkRoot->type() != NicksOnlineItem::NetworkRootItem)
-                    networkRoot = dynamic_cast<NicksOnlineItem*>(networkRoot->parent());
+                    networkRoot = static_cast<NicksOnlineItem*>(networkRoot->parent());
 
                 serverGroupId = networkRoot->data(0, Qt::UserRole).toInt();
             }
@@ -659,7 +641,7 @@ void NicksOnline::doCommand(QAction* id)
 
     QString serverName;
     QString nickname;
-    if (m_nickListView->selectedItems().count() == 0) return;
+    if (m_nickListView->selectedItems().isEmpty()) return;
     QTreeWidgetItem* item = m_nickListView->selectedItems().at(0);
     NicksOnlineItem* nickitem = dynamic_cast<NicksOnlineItem*>(item);
 
@@ -685,11 +667,9 @@ void NicksOnline::doCommand(QAction* id)
 
     if ( id == m_joinChannel )
     {
-        if (m_nickListView->selectedItems().count() > 0)
-        {
+        if (!m_nickListView->selectedItems().isEmpty()) {
             // only join real channels
-            if (static_cast<NicksOnlineItem*>(m_nickListView->selectedItems().at(0))->type() == NicksOnlineItem::ChannelItem)
-            {
+            if (static_cast<NicksOnlineItem*>(m_nickListView->selectedItems().at(0))->type() == NicksOnlineItem::ChannelItem) {
                 QString contactChannel = m_nickListView->selectedItems().at(0)->text(nlvcChannel);
                 server->queue( QStringLiteral("JOIN ")+contactChannel );
             }
@@ -721,7 +701,7 @@ void NicksOnline::setupToolbarActions(NicksOnlineItem *item)
   m_openQuery->setEnabled(false);
   m_joinChannel->setEnabled(false);
   // check for null
-  if (item == 0)
+  if (item == nullptr)
     return;
   // add items depending on the item type
   switch (item->type())
@@ -749,24 +729,24 @@ void NicksOnline::setupPopupMenuActions(NicksOnlineItem *item)
   // clear the popup menu
   m_popupMenu->clear();
   // check for null
-  if (item == 0)
+  if (item == nullptr)
     return;
   // add items depending on the item type
   switch (item->type())
   {
   case NicksOnlineItem::NetworkRootItem:
-    m_popupMenu->insertAction(0, m_addNickname);
+    m_popupMenu->insertAction(nullptr, m_addNickname);
     break;
   case NicksOnlineItem::ChannelItem:
-    m_popupMenu->insertAction(0, m_joinChannel);
+    m_popupMenu->insertAction(nullptr, m_joinChannel);
     break;
   case NicksOnlineItem::NicknameItem:
-    m_popupMenu->insertAction(0, m_removeNickname);
+    m_popupMenu->insertAction(nullptr, m_removeNickname);
     if (!item->isOffline())
     {
       m_popupMenu->addSeparator();
-      m_popupMenu->insertAction(0, m_whois);
-      m_popupMenu->insertAction(0, m_openQuery);
+      m_popupMenu->insertAction(nullptr, m_whois);
+      m_popupMenu->insertAction(nullptr, m_openQuery);
     }
     break;
   }
@@ -777,7 +757,7 @@ void NicksOnline::setupPopupMenuActions(NicksOnlineItem *item)
  */
 void NicksOnline::slotNickListView_SelectionChanged()
 {
-    if (m_nickListView->selectedItems().count() == 0)
+    if (m_nickListView->selectedItems().isEmpty())
       return;
     setupToolbarActions(dynamic_cast<NicksOnlineItem*>(m_nickListView->selectedItems().at(0)));
 }
@@ -788,14 +768,14 @@ void NicksOnline::slotNickListView_SelectionChanged()
 void NicksOnline::slotCustomContextMenuRequested(const QPoint& point)
 {
     QTreeWidgetItem *item = m_nickListView->itemAt(point);
-    if (item == 0)
+    if (item == nullptr)
       return;
     // select the item
     item->setSelected(true);
     // set up actions
     setupPopupMenuActions(dynamic_cast<NicksOnlineItem*>(item));
     // show the popup menu
-    if (m_popupMenu->actions().count() > 0)
+    if (!m_popupMenu->actions().isEmpty())
       m_popupMenu->popup(QCursor::pos());
 }
 
@@ -810,7 +790,7 @@ void NicksOnline::slotPopupMenu_Activated(QAction* id)
 /**
  * Received from server when a NickInfo changes its information.
  */
-void NicksOnline::slotNickInfoChanged(Server* server, const NickInfoPtr nickInfo)
+void NicksOnline::slotNickInfoChanged(Server* server, const NickInfoPtr &nickInfo)
 {
     if (!nickInfo) return;
     QString nickname = nickInfo->getNickname();
@@ -851,7 +831,7 @@ void NicksOnline::refreshItem(QTreeWidgetItem* item)
             if (nickInfo)
                 nickAdditionalInfo = getNickAdditionalInfo(nickInfo, needWhois);
             item->setText(nlvcAdditionalInfo, nickAdditionalInfo);
-            if (m_nickListView->selectedItems().count() != 0 && item == m_nickListView->selectedItems().at(0))
+            if (!m_nickListView->selectedItems().isEmpty() && item == m_nickListView->selectedItems().at(0))
                 setupToolbarActions(dynamic_cast<NicksOnlineItem*>(m_nickListView->selectedItems().at(0)));
         }
     }
