@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #include "query.h"
@@ -25,7 +20,6 @@
 
 #include <QSplitter>
 
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KSqueezedTextLabel>
 
@@ -60,14 +54,14 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
     setTextView(ircViewBox->ircView());               // Server will be set later in setServer();
     ircViewBox->ircView()->setContextMenuOptions(IrcContextMenus::ShowNickActions, true);
     textView->setAcceptDrops(true);
-    connect(textView,SIGNAL(urlsDropped(QList<QUrl>)),this,SLOT(urlsDropped(QList<QUrl>)));
+    connect(textView,&IRCView::urlsDropped,this,&Query::urlsDropped);
 
     // This box holds the input line
     QWidget* inputBox=new QWidget(this);
     QHBoxLayout* inputBoxLayout = new QHBoxLayout(inputBox);
     inputBox->setObjectName(QStringLiteral("input_log_box"));
     inputBoxLayout->setSpacing(spacing());
-    inputBoxLayout->setMargin(0);
+    inputBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     awayLabel=new AwayLabel(inputBox);
     inputBoxLayout->addWidget(awayLabel);
@@ -75,7 +69,8 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
     blowfishLabel = new QLabel(inputBox);
     inputBoxLayout->addWidget(blowfishLabel);
     blowfishLabel->hide();
-    blowfishLabel->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("document-encrypt"), KIconLoader::Toolbar));
+    const int toolBarIconSize = blowfishLabel->style()->pixelMetric(QStyle::PixelMetric::PM_ToolBarIconSize);
+    blowfishLabel->setPixmap(QIcon::fromTheme(QStringLiteral("document-encrypt")).pixmap(toolBarIconSize));
     m_inputBar=new IRCInput(inputBox);
     inputBoxLayout->addWidget(m_inputBar);
 
@@ -86,16 +81,16 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
     connect(m_inputBar, &IRCInput::submit, this, &Query::queryTextEntered);
     connect(m_inputBar, &IRCInput::envelopeCommand, this, &Query::queryPassthroughCommand);
     connect(m_inputBar, &IRCInput::textPasted, this, &Query::textPasted);
-    connect(getTextView(), SIGNAL(textPasted(bool)), m_inputBar, SLOT(paste(bool)));
-    connect(getTextView(),SIGNAL (gotFocus()),m_inputBar,SLOT (setFocus()) );
+    connect(getTextView(), &IRCView::textPasted, m_inputBar, &IRCInput::paste);
+    connect(getTextView(), &IRCView::gotFocus, m_inputBar, QOverload<>::of(&IRCInput::setFocus));
 
-    connect(textView,SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
-    connect(textView,SIGNAL (autoText(QString)),this,SLOT (sendText(QString)) );
+    connect(textView,&IRCView::sendFile,this,&Query::sendFileMenu );
+    connect(textView, &IRCView::autoText, this, &Query::sendText);
 
     updateAppearance();
 
     #ifdef HAVE_QCA2
-    m_cipher = 0;
+    m_cipher = nullptr;
     #endif
 }
 
@@ -114,10 +109,10 @@ void Query::setServer(Server* newServer)
 {
     if (m_server != newServer)
     {
-        connect(newServer, SIGNAL(connectionStateChanged(Server*,Konversation::ConnectionState)),
-                SLOT(connectionStateChanged(Server*,Konversation::ConnectionState)));
-        connect(newServer, SIGNAL(nickInfoChanged(Server*,NickInfoPtr)),
-                this, SLOT(updateNickInfo(Server*,NickInfoPtr)));
+        connect(newServer, &Server::connectionStateChanged,
+                this, &Query::connectionStateChanged);
+        connect(newServer, QOverload<Server*,NickInfoPtr>::of(&Server::nickInfoChanged),
+                this, &Query::updateNickInfo);
     }
 
     ChatWindow::setServer(newServer);
@@ -125,8 +120,8 @@ void Query::setServer(Server* newServer)
     if (!(newServer->getKeyForRecipient(getName()).isEmpty()))
         blowfishLabel->show();
 
-    connect(awayLabel, SIGNAL(unaway()), m_server, SLOT(requestUnaway()));
-    connect(awayLabel, SIGNAL(awayMessageChanged(QString)), m_server, SLOT(requestAway(QString)));
+    connect(awayLabel, &AwayLabel::unaway, m_server, &Server::requestUnaway);
+    connect(awayLabel, &AwayLabel::awayMessageChanged, m_server, &Server::requestAway);
 }
 
 void Query::connectionStateChanged(Server* server, Konversation::ConnectionState state)
@@ -228,13 +223,15 @@ void Query::sendText(const QString& sendLine)
     QString outputAll(sendLine);
 
     // replace aliases and wildcards
-    m_server->getOutputFilter()->replaceAliases(outputAll, this);
+    OutputFilter::replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-    QStringList outList = outputAll.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-    for(int index=0;index<outList.count();index++)
-    {
-        QString output(outList[index]);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    const QStringList outList = outputAll.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+    const QStringList outList = outputAll.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
+    for (const QString& output : outList) {
 
         // encoding stuff is done in Server()
         Konversation::OutputFilterResult result = m_server->getOutputFilter()->parse(m_server->getNickname(), output, getName(), this);
@@ -248,14 +245,12 @@ void Query::sendText(const QString& sendLine)
             else if(!result.typeString.isEmpty()) appendQuery(result.typeString, result.output);
             else appendQuery(m_server->getNickname(), result.output);
         }
-        else if (result.outputList.count())
-        {
+        else if (!result.outputList.isEmpty()) {
             if (result.type == Konversation::Message)
             {
-                QStringListIterator it(result.outputList);
-
-                while (it.hasNext())
-                    appendQuery(m_server->getNickname(), it.next());
+                for (const QString& out : qAsConst(result.outputList)) {
+                    appendQuery(m_server->getNickname(), out);
+                }
             }
             else if (result.type == Konversation::Action)
             {
@@ -281,10 +276,12 @@ void Query::textPasted(const QString& text)
 {
     if(m_server)
     {
-        QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-        for(int index=0;index<multiline.count();index++)
-        {
-            QString line=multiline[index];
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        const QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+        const QStringList multiline = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
+        for (QString line : multiline) {
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
             if(line.startsWith(cChar)) line=cChar+line;
@@ -345,7 +342,7 @@ void Query::setNickInfo(const NickInfoPtr & nickInfo)
     nickInfoChanged();
 }
 
-void Query::updateNickInfo(Server* server, NickInfoPtr nickInfo)
+void Query::updateNickInfo(Server* server, const NickInfoPtr &nickInfo)
 {
     if (!m_nickInfo || server != m_server || nickInfo != m_nickInfo)
         return;
@@ -363,7 +360,7 @@ void Query::nickInfoChanged()
             text += QStringLiteral(" - ");
         text += m_nickInfo->getHostmask();
         if(m_nickInfo->isAway() && !m_nickInfo->getAwayMessage().isEmpty())
-            text += QStringLiteral(" (") + m_nickInfo->getAwayMessage() + QStringLiteral(") ");
+            text += QLatin1String(" (") + m_nickInfo->getAwayMessage() + QLatin1String(") ");
         queryHostmask->setText(Konversation::removeIrcMarkup(text));
 
         QString strTooltip;
@@ -383,13 +380,13 @@ void Query::nickInfoChanged()
     emitUpdateInfo();
 }
 
-NickInfoPtr Query::getNickInfo()
+NickInfoPtr Query::getNickInfo() const
 {
     return m_nickInfo;
 }
 
-bool Query::canBeFrontView()        { return true; }
-bool Query::searchView()       { return true; }
+bool Query::canBeFrontView() const  { return true; }
+bool Query::searchView() const      { return true; }
                                                   // virtual
 void Query::setChannelEncoding(const QString& encoding)
 {
@@ -399,14 +396,14 @@ void Query::setChannelEncoding(const QString& encoding)
         Preferences::setChannelEncoding(m_server->getDisplayName(), getName(), encoding);
 }
 
-QString Query::getChannelEncoding()               // virtual
+QString Query::getChannelEncoding() const              // virtual
 {
     if(m_server->getServerGroup())
         return Preferences::channelEncoding(m_server->getServerGroup()->id(), getName());
     return Preferences::channelEncoding(m_server->getDisplayName(), getName());
 }
 
-QString Query::getChannelEncodingDefaultDesc()    // virtual
+QString Query::getChannelEncodingDefaultDesc() const   // virtual
 {
     return i18n("Identity Default ( %1 )",getServer()->getIdentity()->getCodecName());
 }
@@ -475,7 +472,7 @@ void Query::quitNick(const QString& reason, const QHash<QString, QString> &messa
 }
 
 #ifdef HAVE_QCA2
-Konversation::Cipher* Query::getCipher()
+Konversation::Cipher* Query::getCipher() const
 {
     if(!m_cipher)
         m_cipher = new Konversation::Cipher();
