@@ -1,16 +1,11 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2005-2016 Peter Simonsson <peter.simonsson@gmail.com>
-  Copyright (C) 2006-2008 Eli J. MacKenzie <argonel at gmail.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2005-2016 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eli J. MacKenzie <argonel at gmail.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef SERVER_H
@@ -32,14 +27,15 @@
 #include "cipher.h"
 #endif
 
+#include <QElapsedTimer>
 #include <QTimer>
 #include <QPointer>
 
 #include <QHostInfo>
+#include <QSslSocket>
 
 #include <QExplicitlySharedDataPointer>
-#include <kprocess.h>
-#include <ktcpsocket.h>
+#include <KProcess>
 #include <preferences.h>
 
 class QAbstractItemModel;
@@ -69,6 +65,7 @@ class Server : public QObject
     Q_OBJECT
     friend class IRCQueue;
     friend class QueueTuner;
+    friend class ViewContainer;
 
     public:
         enum QueuePriority
@@ -93,32 +90,47 @@ class Server : public QObject
         };
         Q_DECLARE_FLAGS(CapModifiers, CapModifier)
 
+        enum CapabilityFlag {
+            NoCapabilies = 0x00,
+            AwayNotify = 0x01,
+            ExtendedJoin = 0x02,
+            WHOX = 0x04,
+            ServerTime = 0x08,
+            UserHostInNames = 0x10,
+            SASL = 0x20,
+            MultiPrefix = 0x40,
+            AccountNotify = 0x80,
+            SelfMessage = 0x100,
+        };
+        Q_DECLARE_FLAGS(CapabilityFlags, CapabilityFlag)
+
         Server(QObject* parent, ConnectionSettings& settings);
         ~Server() override;
 
         void cycle();
         void abortScheduledRecreation() { m_recreationScheduled = false; }
 
-        int connectionId() { return m_connectionId; }
+        int connectionId() const { return m_connectionId; }
 
         ConnectionSettings& getConnectionSettings() { return m_connectionSettings; }
+        const ConnectionSettings& getConnectionSettings() const { return m_connectionSettings; }
         void setConnectionSettings(ConnectionSettings& settings) { m_connectionSettings = settings; }
 
-        QString getDisplayName() { return m_connectionSettings.name(); }
-        QString getServerName() { return m_connectionSettings.server().host(); }
+        QString getDisplayName() const { return m_connectionSettings.name(); }
+        QString getServerName() const { return m_connectionSettings.server().host(); }
 
-        Konversation::ServerGroupSettingsPtr getServerGroup() { return m_connectionSettings.serverGroup(); }
-        IdentityPtr getIdentity() { return m_connectionSettings.identity(); }
+        Konversation::ServerGroupSettingsPtr getServerGroup() const { return m_connectionSettings.serverGroup(); }
+        IdentityPtr getIdentity() const { return m_connectionSettings.identity(); }
 
-        Konversation::ConnectionState getConnectionState() { return m_connectionState; }
+        Konversation::ConnectionState getConnectionState() const { return m_connectionState; }
 
-        bool isConnected() { return (m_connectionState == Konversation::SSConnected); }
-        bool isConnecting() { return (m_connectionState == Konversation::SSConnecting); }
-        bool isScheduledToConnect() { return (m_connectionState == Konversation::SSScheduledToConnect); }
+        bool isConnected() const { return (m_connectionState == Konversation::SSConnected); }
+        bool isConnecting() const { return (m_connectionState == Konversation::SSConnecting); }
+        bool isScheduledToConnect() const { return (m_connectionState == Konversation::SSScheduledToConnect); }
 
         bool getUseSSL() const;
         QString getSSLInfo() const;
-        int getPort();
+        int getPort() const;
         int getLag() const;
 
         void updateAutoJoin(Konversation::ChannelList channels = Konversation::ChannelList());
@@ -149,11 +161,11 @@ class Server : public QObject
         QString getChannelTypes() const;
 
         void setModesCount(int count);
-        int getModesCount();
+        int getModesCount() const;
 
         // extended user modes support
         void setChanModes(const QString&);                 //grab modes types from RPL_ISUPPORT CHANMODES
-        QString banAddressListModes() { return m_banAddressListModes; }     // aka "TYPE A" modes https://tools.ietf.org/html/draft-brocklesby-irc-isupport-03#section-3.3
+        QString banAddressListModes() const { return m_banAddressListModes; }     // aka "TYPE A" modes https://tools.ietf.org/html/draft-brocklesby-irc-isupport-03#section-3.3
 
         void setPrefixes(const QString &modes, const QString& prefixes);
         QString getServerNickPrefixes() const;
@@ -170,7 +182,7 @@ class Server : public QObject
         QString getNextNickname();
 
         InputFilter* getInputFilter() { return &m_inputFilter; }
-        Konversation::OutputFilter* getOutputFilter() { return m_outputFilter; }
+        Konversation::OutputFilter* getOutputFilter() const { return m_outputFilter; }
 
         Channel* joinChannel(const QString& name, const QString& hostmask, const QHash<QString, QString> &messageTags);
         void removeChannel(Channel* channel);
@@ -180,7 +192,7 @@ class Server : public QObject
         void appendStatusMessage(const QString& type,const QString& message, const QHash<QString, QString> &messageTags);
         void appendMessageToFrontmost(const QString& type,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool parseURL = true);
 
-        int getPreLength(const QString& command, const QString& dest);
+        int getPreLength(const QString& command, const QString& dest) const;
 
         void dbusRaw(const QString& command);
         void dbusSay(const QString& target,const QString& command);
@@ -193,10 +205,10 @@ class Server : public QObject
         void updateChannelMode(const QString& nick, const QString& channel, char mode, bool plus, const QString& parameter, const QHash<QString, QString> &messageTags);
         void updateChannelModeWidgets(const QString& channel, char mode, const QString& parameter);
 
-        Channel* getChannelByName(const QString& name);
-        Query* getQueryByName(const QString& name);
-        ChatWindow* getChannelOrQueryByName(const QString& name);
-        QString parseWildcards(const QString& toParse, ChatWindow* context = 0, const QStringList nicks = QStringList());
+        Channel* getChannelByName(const QString& name) const;
+        Query* getQueryByName(const QString& name) const;
+        ChatWindow* getChannelOrQueryByName(const QString& name) const;
+        QString parseWildcards(const QString& toParse, ChatWindow* context = nullptr, const QStringList &nicks = QStringList());
         QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QStringList &nickList, const QString& inputLineText);
         QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QString& nick, const QString& inputLineText);
 
@@ -210,10 +222,10 @@ class Server : public QObject
         StatusPanel* getStatusView() const { return m_statusView; }
         virtual bool closeYourself(bool askForConfirmation=true);
 
-        QString getOwnIpByNetworkInterface();
-        QString getOwnIpByServerMessage();
+        QString getOwnIpByNetworkInterface() const;
+        QString getOwnIpByServerMessage() const;
 
-        bool isAway() { return m_away; }
+        bool isAway() const { return m_away; }
         void setAway(bool away, const QHash<QString, QString> &messageTags);
         QString awayTime() const;
 
@@ -227,7 +239,7 @@ class Server : public QObject
          * notify list, and has not initiated a query with you, may well be online,
          * but server doesn't know if it is or not, in which case False is returned.
          */
-        bool isNickOnline(const QString &nickname);
+        bool isNickOnline(const QString &nickname) const;
         /** Given a nickname, returns NickInfo object.
          *  @param nickname    The desired nickname.  Case insensitive.
          *  @return            Pointer to the nickinfo for this nickname if one exists.
@@ -240,7 +252,7 @@ class Server : public QObject
          *  - The nick initiated a query with the user.
          *  A NickInfo is destroyed when it is offline.
          */
-        NickInfoPtr getNickInfo(const QString& nickname);
+        NickInfoPtr getNickInfo(const QString& nickname) const;
         /** Given a nickname, returns an existing NickInfo object, or creates a new NickInfo object.
          *  Guaranteed to return a nickinfo.
          *  @param nickname    The desired nickname.  Case sensitive.
@@ -256,7 +268,7 @@ class Server : public QObject
          *
          * @return A QMap of NickInfoPtrs indexed by lowercase nickname.
          */
-        const NickInfoMap* getAllNicks();
+        const NickInfoMap* getAllNicks() const;
         /** Returns the list of members for a channel in the joinedChannels list.
          *  A joinedChannel is one that you are in, as opposed to a channel that you aren't in,
          *  but one of your watched nicks is in.
@@ -289,7 +301,7 @@ class Server : public QObject
          *  @param nickname    The desired nickname.  Case insensitive.
          *  @return            A list of joined channels the nick is in.  Empty if none.
          */
-        QStringList getNickJoinedChannels(const QString& nickname);
+        QStringList getNickJoinedChannels(const QString& nickname) const;
         /** Returns a list of all the channels (joined or unjoined) that a nick is in.
          *  @param nickname    The desired nickname.  Case insensitive.
          *  @return            A list of channels the nick is in.  Empty if none.
@@ -297,12 +309,12 @@ class Server : public QObject
          *  A nick will not appear in the Unjoined channels list unless a WHOIS
          *  has been performed on it.
          */
-        QStringList getNickChannels(const QString& nickname);
+        QStringList getNickChannels(const QString& nickname) const;
         /** Returns a list of all the channels we're in that nickname is also in.
          *  @param nickname    The desired nickname.  Case insensitive.
          *  @return            A list of channels the nick is in that we're also in.  Empty if none.
          */
-        QStringList getSharedChannels(const QString& nickname);
+        QStringList getSharedChannels(const QString& nickname) const;
         /** Returns pointer to the ChannelNick (mode and pointer to NickInfo) for a
          *  given channel and nickname.
          *  @param channelName The desired channel name.  Case insensitive.
@@ -311,7 +323,7 @@ class Server : public QObject
          *                     to the NickInfo and the mode of the nick in the channel.
          *                     0 if not found.
          */
-        ChannelNickPtr getChannelNick(const QString& channelName, const QString& nickname);
+        ChannelNickPtr getChannelNick(const QString& channelName, const QString& nickname) const;
         /** Updates a nickname in a channel.  If not on the joined or unjoined lists, and nick
          *  is in the watch list, adds the channel and nick to the unjoinedChannels list.
          *  If mode != 99, sets the mode for the nick in the channel.
@@ -331,17 +343,17 @@ class Server : public QObject
         /**
          * Returns a lower case list of all the nicks on the user watch list.
          */
-        QStringList getWatchList();
+        QStringList getWatchList() const;
         /**
          * Return true if the given nickname is on the watch list.
          */
-        bool isWatchedNick(const QString& nickname);
+        bool isWatchedNick(const QString& nickname) const;
         /**
          * Returns a list of all the nicks on the watch list that are not in joined
          * channels.  ISON command is sent for these nicks.
          */
-        QStringList getISONList();
-        QString getISONListString();
+        QStringList getISONList() const;
+        QString getISONListString() const;
 
         ViewContainer* getViewContainer() const;
 
@@ -388,12 +400,9 @@ class Server : public QObject
 
         bool capEndDelayed() const { return m_capEndDelayed; }
 
-        bool hasAwayNotify() const { return m_hasAwayNotify; }
-        bool hasExtendedJoin() const { return m_hasExtendedJoin; }
-        void setHasWHOX(bool state) { m_hasWHOX = state; }
-        bool hasWHOX() const { return m_hasWHOX; }
-        bool hasServerTime() const { return m_hasServerTime; }
-        bool hasUserHostInNames() const { return m_hasUserHostInNames; }
+        void setHasWHOX(bool state) { m_capabilities.setFlag(WHOX, state); }
+        CapabilityFlags capabilities() const { return m_capabilities; }
+        bool whoRequestsDisabled() const { return m_whoRequestsDisabled; }
 
     // IRCQueueManager
         bool validQueue(QueuePriority priority); ///< is this queue index valid?
@@ -494,7 +503,7 @@ class Server : public QObject
         void requestBan(const QStringList& users,const QString& channel,const QString& option);
         void requestUnban(const QString& mask,const QString& channel);
 
-        void addDccSend(const QString &recipient, QUrl fileURL, bool passive = Preferences::self()->dccPassiveSend(), const QString &altFileName = QString(), quint64 fileSize = 0);
+        void addDccSend(const QString &recipient, const QUrl &fileURL, bool passive = Preferences::self()->dccPassiveSend(), const QString &altFileName = QString(), quint64 fileSize = 0);
         void removeQuery(Query *query);
         void notifyListStarted(int serverGroupId);
         void startNotifyTimer(int msec=0);
@@ -551,7 +560,7 @@ class Server : public QObject
         void capDenied(const QString& name);
         void sendAuthenticate(const QString& message);
 
-    protected Q_SLOTS:
+    private Q_SLOTS:
         void hostFound();
         void preShellCommandExited(int exitCode, QProcess::ExitStatus exitStatus);
         void preShellCommandError(QProcess::ProcessError eror);
@@ -560,14 +569,14 @@ class Server : public QObject
         void incoming();
         void processIncomingData();
         /// Sends the QString to the socket. No longer has any internal concept of queueing
-        void toServer(QString&, IRCQueue *);
+        void toServer(const QString&, IRCQueue *);
         /// Because KBufferedSocket has no closed(int) signal we use this slot to call broken(0)
         void closed();
-        void broken(KTcpSocket::Error error);
+        void broken(QAbstractSocket::SocketError error);
         /** This is connected to the SSLSocket failed.
          * @param reason The reason why this failed.  This is already translated, ready to show the user.
          */
-        void sslError(const QList<KSslError>&);
+        void sslError(const QList<QSslError>&);
         void connectionEstablished(const QString& ownHost);
         void notifyResponse(const QString& nicksOnline);
 
@@ -592,7 +601,7 @@ class Server : public QObject
         void scriptNotFound(const QString& name);
         void scriptExecutionError(const QString& name);
         void userhost(const QString& nick,const QString& hostmask,bool away,bool ircOp);
-        void setTopicAuthor(const QString& channel,const QString& author, QDateTime t);
+        void setTopicAuthor(const QString& channel,const QString& author, const QDateTime &t);
         void endOfWho(const QString& target);
         void endOfNames(const QString& target);
         void invitation(const QString& nick,const QString& channel);
@@ -618,15 +627,11 @@ class Server : public QObject
 
         void requestOpenChannelListPanel(const QString& filter);
 
-    private Q_SLOTS:
         /** Called in the server constructor if the preferences are set to run a command on a new server instance.
          *  This sets up the kprocess, runs it, and connects the signals to call preShellCommandExited when done. */
         void doPreShellCommand();
 
-    protected:
-        // constants
-        static const int BUFFER_LEN=513;
-
+    private:
         /// Initialize the timers
         void initTimers();
 
@@ -660,7 +665,7 @@ class Server : public QObject
         * @param nickname           The nickname that is offline
         * @param nickInfo           Pointer to NickInfo for nick
         */
-        void setWatchedNickOffline(const QString& nickname, const NickInfoPtr nickInfo);
+        void setWatchedNickOffline(const QString& nickname, const NickInfoPtr &nickInfo);
 
         /**
          * If nickname is no longer on any channel list, or the query list, delete it altogether.
@@ -707,6 +712,42 @@ class Server : public QObject
         QStringList getAutoJoinCommands() const { return m_autoJoinCommands; }
         void setAutoJoinCommands(const QStringList& commands) { m_autoJoinCommands = commands; }
 
+        void rebuildTargetPrefixMatcher();          ///< updates the regexp when prefixes change
+
+        void updateConnectionState(Konversation::ConnectionState state);
+        bool isSocketConnected() const;
+
+        void purgeData();
+
+        /// Recovers the filename from the dccArguments list from pos 0 to size-offset-1
+        /// joining with a space and cleans the filename using cleanDccFileName.
+        /// The filename only needs to be recovered if it contains a space, in case
+        /// it does not, the cleaned string at pos 0 is returned.
+        /// "offset" states how many fixed arguments the dcc command has, where the
+        /// filename is variable. For example "filename ip port filesize", offset is 3.
+        inline QString recoverDccFileName(const QStringList& dccArguments, int offset) const;
+
+        /// Cleans the filename from extra '"'. We just remove '"' if it is the first
+        /// and last char, if the filename really contains a '"' it comes as two chars,
+        /// escaped "\"", and is not affected.
+        /// Some clients return the filename with multiple '"' around the filename
+        /// but all we want is the plain filename.
+        inline QString cleanDccFileName(const QString& filename) const;
+
+        /// Checks if the port is in a valid range
+        inline quint16 stringToPort(const QString &port, bool *ok = nullptr);
+
+        /// Creates a list of known users and returns the one chosen by the user
+        inline QString recipientNick() const;
+
+        void collectStats(int bytes, int encodedBytes);
+
+        void initCapablityNames();
+
+    private:
+        // constants
+        static const int BUFFER_LEN=513;
+
         unsigned int m_completeQueryPosition;
         QList<int> m_nickIndices;
         QStringList m_referenceNicklist;
@@ -717,7 +758,6 @@ class Server : public QObject
         QString m_serverNickPrefixModes;            ///< if supplied: mode flags related to nickname prefixes
 
         QRegularExpression m_targetMatcher;         ///< a character set composed of m_serverNickPrefixes and m_channelPrefixes
-        void rebuildTargetPrefixMatcher();          ///< updates the regexp when prefixes change
 
         QString m_banAddressListModes;              // "TYPE A" modes from RPL_ISUPPORT CHANMODES=A,B,C,D
 
@@ -728,15 +768,15 @@ class Server : public QObject
 
         QStringList m_autoJoinCommands;
 
-        KTcpSocket* m_socket;
+        QSslSocket *m_socket;
 
         QTimer m_incomingTimer;
         QTimer m_notifyTimer;
         QStringList m_notifyCache;                  // List of users found with ISON
-        int m_checkTime;                            // Time elapsed while waiting for server 303 response
         int m_currentLag;
 
         QStringList m_inputBuffer;
+        QByteArray m_lineBuffer;
 
         QList<IRCQueue *> m_queues;
         // Stats used in QueueTuner
@@ -765,37 +805,9 @@ class Server : public QObject
         int m_awayTime;
 
         Konversation::ConnectionState m_connectionState;
-        void updateConnectionState(Konversation::ConnectionState state);
-        bool isSocketConnected() const;
 
         KProcess m_preShellCommand;
 
-    private:
-        void purgeData();
-
-        /// Recovers the filename from the dccArguments list from pos 0 to size-offset-1
-        /// joining with a space and cleans the filename using cleanDccFileName.
-        /// The filename only needs to be recovered if it contains a space, in case
-        /// it does not, the cleaned string at pos 0 is returned.
-        /// "offset" states how many fixed arguments the dcc command has, where the
-        /// filename is variable. For example "filename ip port filesize", offset is 3.
-        inline QString recoverDccFileName(const QStringList& dccArguments, int offset) const;
-
-        /// Cleans the filename from extra '"'. We just remove '"' if it is the first
-        /// and last char, if the filename really contains a '"' it comes as two chars,
-        /// escaped "\"", and is not affected.
-        /// Some clients return the filename with multiple '"' around the filename
-        /// but all we want is the plain filename.
-        inline QString cleanDccFileName(const QString& filename) const;
-
-        /// Checks if the port is in a valid range
-        inline quint16 stringToPort(const QString &port, bool *ok = 0);
-
-        /// Creates a list of known users and returns the one chosen by the user
-        inline QString recipientNick() const;
-
-        void collectStats(int bytes, int encodedBytes);
-
         /// Helper object to construct ISON (notify) list.
         ServerISON* m_serverISON;
         /// All nicks known to this server.  Note this is NOT a list of all nicks on the server.
@@ -828,7 +840,7 @@ class Server : public QObject
         bool m_processingIncoming;
 
         /// Measures the lag between PING and PONG
-        QTime m_lagTime;
+        QElapsedTimer m_lagTime;
         /// Updates the gui when the lag gets too high
         QTimer m_pingResponseTimer;
         /// Wait before sending the next PING
@@ -861,13 +873,15 @@ class Server : public QObject
 
         bool m_recreationScheduled;
 
-        bool m_hasAwayNotify;
-        bool m_hasExtendedJoin;
-        bool m_hasWHOX;
-        bool m_hasServerTime;
-        bool m_hasUserHostInNames;
+        CapabilityFlags m_capabilities;
+        QHash<QString, CapabilityFlag> m_capabilityNames;
+
+        bool m_whoRequestsDisabled;
+
+        Q_DISABLE_COPY(Server)
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Server::CapModifiers)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Server::CapabilityFlags)
 
 #endif
