@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef KONVERSATIONSERVERLISTDIALOG_H
@@ -27,13 +22,16 @@ namespace Konversation
     class ServerListItem : public QTreeWidgetItem
     {
         public:
-            ServerListItem(QTreeWidget* tree, QStringList & strings);
-            ServerListItem(QTreeWidgetItem* parent, QStringList & strings);
+            ServerListItem(QTreeWidget* tree, const QStringList & strings);
+            ServerListItem(QTreeWidgetItem* parent, const QStringList & strings);
+            ~ServerListItem() override = default;
             bool operator<(const QTreeWidgetItem &other) const override;
             enum DataRole
             {
                 SortIndex = Qt::UserRole + 2
             };
+    private:
+            Q_DISABLE_COPY(ServerListItem)
     };
 
     class ServerListDialog : public QDialog, private Ui::ServerListDialogUI
@@ -41,8 +39,8 @@ namespace Konversation
         Q_OBJECT
 
         public:
-            explicit ServerListDialog(const QString& title, QWidget *parent = 0);
-            ~ServerListDialog() override;
+            explicit ServerListDialog(const QString& title, QWidget *parent = nullptr);
+            ~ServerListDialog();
             enum DataRole
             {
                 ServerGroupId = Qt::UserRole + 1,
@@ -59,8 +57,8 @@ namespace Konversation
             void connectTo(Konversation::ConnectionFlag flag, ConnectionSettings connectionSettings);
             void serverGroupsChanged(const Konversation::ServerGroupSettingsPtr serverGroup = Konversation::ServerGroupSettingsPtr());
 
-        protected Q_SLOTS:
-            virtual void slotOk();
+        private Q_SLOTS:
+            void slotOk();
             void slotAdd();
             void slotEdit();
             void slotDelete();
@@ -75,21 +73,22 @@ namespace Konversation
 
             void setShowAtStartup(bool show);
 
-        protected:
+        private:
             QTreeWidgetItem* insertServerGroup(ServerGroupSettingsPtr serverGroup);
             void addServerGroup(ServerGroupSettingsPtr serverGroup);
 
-            int m_lastSortColumn;
-            Qt::SortOrder m_lastSortOrder;
+            int selectedChildrenCount(QTreeWidgetItem* item);
 
         private:
-            int selectedChildrenCount(QTreeWidgetItem* item);
+            int m_lastSortColumn;
+            Qt::SortOrder m_lastSortOrder;
 
             bool m_selectedItem;
             int m_selectedServerGroupId;
             ServerSettings m_selectedServer;
             QTreeWidgetItem* m_selectedItemPtr;
 
+            Q_DISABLE_COPY(ServerListDialog)
     };
 }
 #endif
