@@ -1,15 +1,7 @@
 /*
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-ServerListView is derived from QTreeWidget and implements overly
-complex custom drag'n'drop behavior needed in ServerListDialog.
-
-Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #include "serverlistview.h"
@@ -59,26 +51,24 @@ void ServerListView::dragEnterEvent(QDragEnterEvent *e)
 
 bool ServerListView::badDropSelection()
 {
-    QList<QTreeWidgetItem*> items = selectedItems();
+    const QList<QTreeWidgetItem*> items = selectedItems();
     QList<QTreeWidgetItem*> children;
     QTreeWidgetItem* parent;
     int t=0; //top item count
-    foreach (QTreeWidgetItem* item, items)
-    {
+    for (QTreeWidgetItem* item : items) {
         if (indexOfTopLevelItem(item)<0) // is a child
         {
                 children.append(item);
                 parent = children.at(0)->parent();
                 // make sure all the children have the same parent
-                for (int i=0; i < children.count(); i++)
-                {
-                    if (children.at(i)->parent() != parent)
+                for (QTreeWidgetItem* child : qAsConst(children)) {
+                    if (child->parent() != parent)
                         return true;
                 }
         }
         else    t++;
 
-        if (t > 0 && children.count() > 0) //make sure we don't have a top and a child selected
+        if (t > 0 && !children.isEmpty()) //make sure we don't have a top and a child selected
             return true;
     }
     return false;
