@@ -1,13 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  copyright: (C) 2004 by Peter Simonsson
-  email:     psn@linux.se
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
 #include "notificationhandler.h"
@@ -20,7 +14,6 @@
 #include "server.h"
 #include "transfer.h"
 
-#include <QTextDocument>
 
 #include <KLocalizedString>
 #include <KNotification>
@@ -51,16 +44,17 @@ namespace Konversation
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView()));
 
         QString eventTitle = i18nc("Notification title; see Event/message in konversation.notifyrc", "New message from %1 in %2", fromNick, chatWin->getName());
+        KNotification* msg;
 
         if (message.isEmpty())
         {
-            KNotification::event(QLatin1String("message"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("message"), eventTitle, QStringLiteral("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QLatin1Char('>'));
+                konvApp->osd()->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QLatin1Char('>'));
             }
         }
         else
@@ -68,16 +62,19 @@ namespace Konversation
             QString cleanedMessage = removeIrcMarkup(message);
             QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("message"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("message"), eventTitle, QStringLiteral("&lt;%1&gt; %2").arg(fromNick, forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QStringLiteral("> ") + cleanedMessage);
+                konvApp->osd()->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QStringLiteral("> ") + cleanedMessage);
             }
         }
 
+        msg->setDefaultAction(i18n("Open"));
+        connect(msg, &KNotification::defaultActivated, chatWin, &ChatWindow::activateView);
+
         if (!Preferences::self()->trayNotifyOnlyOwnNick())
         {
             startTrayNotification(chatWin);
@@ -98,15 +95,16 @@ namespace Konversation
 
         QString eventTitle = i18nc("Notification title; see Event/nick in konversation.notifyrc", "Your nick was mentioned by %1 in %2", fromNick, chatWin->getName());
 
+        KNotification* msg;
         if (message.isEmpty())
         {
-            KNotification::event(QLatin1String("nick"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("nick"), eventTitle, QStringLiteral("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(i18n("[HighLight] (%1) <%2>", chatWin->getName(), fromNick));
+                konvApp->osd()->show(i18n("[HighLight] (%1) <%2>", chatWin->getName(), fromNick));
             }
         }
         else
@@ -114,16 +112,19 @@ namespace Konversation
             QString cleanedMessage = removeIrcMarkup(message);
             QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("nick"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("nick"), eventTitle, QStringLiteral("&lt;%1&gt; %2").arg(fromNick, forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(i18n("[HighLight] (%1) <%2> %3", chatWin->getName(), fromNick, cleanedMessage));
+                konvApp->osd()->show(i18n("[HighLight] (%1) <%2> %3", chatWin->getName(), fromNick, cleanedMessage));
             }
         }
 
+        msg->setDefaultAction(i18n("Open"));
+        connect(msg, &KNotification::defaultActivated, chatWin, &ChatWindow::activateView);
+
         startTrayNotification(chatWin);
     }
 
@@ -141,15 +142,16 @@ namespace Konversation
 
         QString eventTitle = i18nc("Notification title; see Event/message in konversation.notifyrc", "New query message from %1", chatWin->getName());
 
+        KNotification* msg;
         if (message.isEmpty()) // TODO document how this can happen, seems nonsensical
         {
-            KNotification::event(QLatin1String("queryMessage"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("queryMessage"), eventTitle, QStringLiteral("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(i18n("[Query] <%1>", fromNick));
+                konvApp->osd()->show(i18n("[Query] <%1>", fromNick));
             }
         }
         else
@@ -157,16 +159,19 @@ namespace Konversation
             QString cleanedMessage = removeIrcMarkup(message);
             QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("queryMessage"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            msg = KNotification::event(QStringLiteral("queryMessage"), eventTitle, QStringLiteral("&lt;%1&gt; %2").arg(fromNick, forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
                 Application* konvApp = Application::instance();
 
-                konvApp->osd->show(i18n("[Query] <%1> %2", fromNick, cleanedMessage));
+                konvApp->osd()->show(i18n("[Query] <%1> %2", fromNick, cleanedMessage));
             }
         }
 
+        msg->setDefaultAction(i18n("Open"));
+        connect(msg, &KNotification::defaultActivated, chatWin, &ChatWindow::activateView);
+
         startTrayNotification(chatWin);
     }
 
@@ -191,14 +196,14 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("join"), i18n("%1 joined %2",nick, chatWin->getName()), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("join"), i18n("%1 joined %2",nick, chatWin->getName()), QPixmap(), m_mainWindow);
 
         // OnScreen Message
         if(Preferences::self()->oSDShowChannelEvent() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             Application* konvApp = Application::instance();
-            konvApp->osd->show(i18n("%1 joined %2",nick, chatWin->getName()));
+            konvApp->osd()->show(i18n("%1 joined %2",nick, chatWin->getName()));
         }
     }
 
@@ -210,14 +215,14 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("part"), i18n("%1 parted %2",nick, chatWin->getName()), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("part"), i18n("%1 parted %2",nick, chatWin->getName()), QPixmap(), m_mainWindow);
 
         // OnScreen Message
         if(Preferences::self()->oSDShowChannelEvent() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             Application* konvApp = Application::instance();
-            konvApp->osd->show(i18n("%1 parted %2",nick, chatWin->getName()));
+            konvApp->osd()->show(i18n("%1 parted %2",nick, chatWin->getName()));
         }
     }
 
@@ -229,7 +234,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("part"), i18n("%1 quit %2",nick, chatWin->getServer()->getServerName()), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("part"), i18n("%1 quit %2",nick, chatWin->getServer()->getServerName()), QPixmap(), m_mainWindow);
     }
 
     void NotificationHandler::nickChange(ChatWindow* chatWin, const QString& oldNick, const QString& newNick)
@@ -240,7 +245,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("nickchange"), i18n("%1 changed nickname to %2",oldNick, newNick), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("nickchange"), i18n("%1 changed nickname to %2",oldNick, newNick), QPixmap(), m_mainWindow);
     }
 
     void NotificationHandler::dccIncoming(ChatWindow* chatWin, const QString& fromNick)
@@ -251,7 +256,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("dcc_incoming"), i18n("%1 wants to send a file to you",fromNick), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("dcc_incoming"), i18n("%1 wants to send a file to you",fromNick), QPixmap(), m_mainWindow);
     }
 
     void NotificationHandler::dccError(ChatWindow* chatWin, const QString& error)
@@ -262,7 +267,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("dcc_error"), i18n("An error has occurred in a DCC transfer: %1",error), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("dcc_error"), i18n("An error has occurred in a DCC transfer: %1",error), QPixmap(), m_mainWindow);
     }
 
     void NotificationHandler::dccTransferDone(ChatWindow* chatWin, const QString& file, DCC::Transfer* transfer)
@@ -275,15 +280,16 @@ namespace Konversation
 
         if (transfer->getType() == DCC::Transfer::Send)
         {
-            KNotification::event(QLatin1String("dcctransfer_done"), i18nc("%1 - filename","%1 File Transfer is complete",file), QPixmap(), m_mainWindow);
+            KNotification::event(QStringLiteral("dcctransfer_done"), i18nc("%1 - filename","%1 File Transfer is complete",file), QPixmap(), m_mainWindow);
         }
         else
         {
-            KNotification *notification = new KNotification(QStringLiteral("dcctransfer_done"), m_mainWindow);
+            KNotification *notification = new KNotification(QStringLiteral("dcctransfer_done"));
+            notification->setWidget(m_mainWindow);
             notification->setText(i18nc("%1 - filename","%1 File Transfer is complete", file));
             //notification->setPixmap( QPixmap() );
             notification->setActions(QStringList(i18nc("Opens the file from the finished dcc transfer", "Open")));
-            connect(notification, SIGNAL(activated(unsigned)), transfer, SLOT(runFile()));
+            connect(notification, QOverload<unsigned int>::of(&KNotification::activated), transfer, &DCC::Transfer::runFile);
             notification->sendEvent();
         }
     }
@@ -296,7 +302,8 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("mode"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("mode"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("%1 changed modes in %2: %3", nick, subject, change));
         ev->sendEvent();
     }
@@ -311,7 +318,8 @@ namespace Konversation
 
         startTrayNotification(chatWin);
 
-        KNotification *ev=new KNotification(QStringLiteral("query"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("query"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("%1 has started a conversation (query) with you.",fromNick));
         ev->sendEvent();
     }
@@ -324,7 +332,8 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("notify"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("notify"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("%1 is online (%2).", nick, chatWin->getServer()->getServerName()));
         ev->sendEvent();
 
@@ -338,7 +347,8 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("notify"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("notify"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("%1 went offline (%2).", nick, chatWin->getServer()->getServerName()));
         ev->sendEvent();
 
@@ -352,7 +362,8 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("kick"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("kick"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("You are kicked by %1 from %2", nick, channel));
         ev->sendEvent();
 
@@ -366,7 +377,8 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("dccChat"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("dccChat"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("%1 started a DCC chat with you", nick));
         ev->sendEvent();
 
@@ -388,12 +400,12 @@ namespace Konversation
         if(fromNick.isEmpty()) // TODO document this one too
         {
             QString eventTitle = i18nc("Notification title; see Event/highlight in konversation.notifyrc", "Highlight triggered in %1", chatWin->getName());
-            KNotification::event(QLatin1String("highlight"), eventTitle, QString(QStringLiteral("(%1) *** %2")).arg(chatWin->getName()).arg(forKNotify), QPixmap(), m_mainWindow);
+            KNotification::event(QStringLiteral("highlight"), eventTitle, QStringLiteral("(%1) *** %2").arg(chatWin->getName(), forKNotify), QPixmap(), m_mainWindow);
         }
         else
         {
             QString eventTitle = i18nc("Notification title; see Event/highlight in konversation.notifyrc", "Highlight triggered by %2 in %1", chatWin->getName(), fromNick);
-            KNotification::event(QLatin1String("highlight"), eventTitle, QString(QStringLiteral("(%1) &lt;%2&gt; %3")).arg(chatWin->getName()).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            KNotification::event(QStringLiteral("highlight"), eventTitle, QStringLiteral("(%1) &lt;%2&gt; %3").arg(chatWin->getName(), fromNick, forKNotify), QPixmap(), m_mainWindow);
         }
 
         if(Preferences::self()->oSDShowOwnNick() &&
@@ -403,10 +415,10 @@ namespace Konversation
             // if there was no nick associated, this must be a command message, so don't try displaying
             // an empty nick in <>
             if(fromNick.isEmpty())
-                konvApp->osd->show(i18n("[HighLight] (%1) *** %2",chatWin->getName(),cleanedMessage));
+                konvApp->osd()->show(i18n("[HighLight] (%1) *** %2",chatWin->getName(),cleanedMessage));
             // normal highlight message
             else
-                konvApp->osd->show(i18n("[HighLight] (%1) <%2> %3",chatWin->getName(),fromNick,cleanedMessage));
+                konvApp->osd()->show(i18n("[HighLight] (%1) <%2> %3",chatWin->getName(),fromNick,cleanedMessage));
         }
     }
 
@@ -415,7 +427,8 @@ namespace Konversation
         if (!chatWin || !chatWin->notificationsEnabled())
             return;
 
-        KNotification *ev=new KNotification(QStringLiteral("connectionFailure"), m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("connectionFailure"));
+        ev->setWidget(m_mainWindow);
         ev->setText(i18n("Failed to connect to %1", server));
         ev->sendEvent();
 
@@ -429,7 +442,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification::event(QLatin1String("channelJoin"), i18n("You have joined %1.",channel), QPixmap(), m_mainWindow);
+        KNotification::event(QStringLiteral("channelJoin"), i18n("You have joined %1.",channel), QPixmap(), m_mainWindow);
     }
 
 }
