@@ -1,18 +1,9 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy 
-    defined in Section 14 of version 3 of the license.
-*/
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-/*
-  Copyright (C) 2008 Eli J. MacKenzie <argonel at gmail.com>
+    SPDX-FileCopyrightText: 2008 Eli J. MacKenzie <argonel at gmail.com>
 */
 
-
 #ifndef QUEUETUNER_H
 #define QUEUETUNER_H
 
@@ -30,8 +21,7 @@ class QueueTuner: public QWidget, private Ui::QueueTunerBase
 
     public:
         QueueTuner(QWidget* parent, ViewContainer *container);
-        ~QueueTuner() override;
-        void contextMenuEvent (QContextMenuEvent*) override;
+        ~QueueTuner();
 
     public Q_SLOTS:
         void setServer(Server* newServer);
@@ -55,11 +45,15 @@ class QueueTuner: public QWidget, private Ui::QueueTunerBase
     Q_SIGNALS:
         void hidden();
 
+    protected:
+        void contextMenuEvent (QContextMenuEvent*) override;
+
     private:
         Server* m_server;
         QTimer m_timer;
         bool &m_vis;
+
+        Q_DISABLE_COPY(QueueTuner)
 };
 
-
 #endif
