@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Dialog for quick connection to an IRC network without adding a server in the Server List.
-  begin:     Sat June 05 2004
-  copyright: (C) 2004 by Michael Goettsche
-  email:     mail@tuxipuxi.de
+    SPDX-FileCopyrightText: 2004 Michael Goettsche <mail@tuxipuxi.de>
 */
 
 #include "quickconnectdialog.h"
@@ -18,7 +10,6 @@
 #include <QCheckBox>
 
 #include <KLineEdit>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <KGuiItem>
