@@ -1,22 +1,16 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005-2007 Joris Guisson <joris.guisson@gmail.com>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
 */
 
 #include "upnpmcastsocket.h"
 
+#include "konversation_log.h"
+
 #include <QStringList>
-
 #include <QUrl>
-#include <QDebug>
-
 
 #ifdef Q_OS_WIN
 #include <winsock.h>
@@ -39,12 +33,15 @@ namespace Konversation
         UPnPMCastSocket::UPnPMCastSocket() : QUdpSocket ()
         {
             QObject::connect(this, &UPnPMCastSocket::readyRead, this, &UPnPMCastSocket::onReadyRead);
-            QObject::connect(this, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(onError(QAbstractSocket::SocketError)));
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            QObject::connect(this, &UPnPMCastSocket::errorOccurred, this, &UPnPMCastSocket::onError);
+#else
+            QObject::connect(this, QOverload<QAbstractSocket::SocketError>::of(&UPnPMCastSocket::error), this, &UPnPMCastSocket::onError);
+#endif
             for (quint32 i = 0;i < 10;i++)
             {
                 if (!bind(1900 + i,QUdpSocket::ShareAddress))
-                    qDebug() << "Cannot bind to UDP port 1900 : " << errorString() << endl;
+                    qCDebug(KONVERSATION_LOG) << "Cannot bind to UDP port 1900 : " << errorString();
                 else
                     break;
             }
@@ -62,7 +59,7 @@ namespace Konversation
 
         void UPnPMCastSocket::discover()
         {
-            qDebug() << "Trying to find UPnP devices on the local network" << endl;
+            qCDebug(KONVERSATION_LOG) << "Trying to find UPnP devices on the local network";
 
             // send a HTTP M-SEARCH message to 239.255.255.250:1900
             const char* data = "M-SEARCH * HTTP/1.1\r\n"
@@ -72,7 +69,7 @@ namespace Konversation
                     "MX:3\r\n"
                     "\r\n\0";
 
-            writeDatagram(data,strlen(data),QHostAddress("239.255.255.250"),1900);
+            writeDatagram(data,strlen(data),QHostAddress(QStringLiteral("239.255.255.250")),1900);
         }
 
         void UPnPMCastSocket::onXmlFileDownloaded(UPnPRouter* r,bool success)
@@ -109,8 +106,8 @@ namespace Konversation
             UPnPRouter* r = parseResponse(data);
             if (r)
             {
-                QObject::connect(r,SIGNAL(xmlFileDownloaded(UPnPRouter*,bool)),
-                        this,SLOT(onXmlFileDownloaded(UPnPRouter*,bool)));
+                QObject::connect(r,&UPnPRouter::xmlFileDownloaded,
+                        this,&UPnPMCastSocket::onXmlFileDownloaded);
 
                 // download it's xml file
                 r->downloadXMLFile();
@@ -120,36 +117,36 @@ namespace Konversation
 
         UPnPRouter* UPnPMCastSocket::parseResponse(const QByteArray & arr)
         {
-            QStringList lines = QString::fromLatin1(arr).split("\r\n");
+            QStringList lines = QString::fromLatin1(arr).split(QStringLiteral("\r\n"));
             QString server;
             QUrl location;
             QString uuid;
 
             // first read first line and see if contains a HTTP 200 OK message
             QString line = lines.first();
-            if (line.contains("HTTP"))
+            if (line.contains(QLatin1String("HTTP")))
             {
                 // it is either a 200 OK or a NOTIFY
-                if (!line.contains("NOTIFY") && !line.contains("200 OK"))
-                    return 0;
+                if (!line.contains(QLatin1String("NOTIFY")) && !line.contains(QLatin1String("200 OK")))
+                    return nullptr;
             }
             else
-                return 0;
+                return nullptr;
 
             // quick check that the response being parsed is valid
             bool validDevice = false;
             for (int idx = 0;idx < lines.count() && !validDevice; idx++)
             {
                 line = lines[idx];
-                if ((line.contains("ST:") || line.contains("NT:")) && line.contains("InternetGatewayDevice"))
+                if ((line.contains(QLatin1String("ST:")) || line.contains(QLatin1String("NT:"))) && line.contains(QLatin1String("InternetGatewayDevice")))
                 {
                     validDevice = true;
                 }
             }
             if (!validDevice)
             {
-            //	qDebug() << "Not a valid Internet Gateway Device" << endl;
-                return 0;
+            //	qCDebug(KONVERSATION_LOG) << "Not a valid Internet Gateway Device";
+                return nullptr;
             }
 
             // read all lines and try to find the server and location fields
@@ -158,33 +155,33 @@ namespace Konversation
                 line = lines[i];
                 if (line.startsWith(QLatin1String("Location"), Qt::CaseInsensitive))
                 {
-                    location = QUrl(line.mid(line.indexOf(':') + 1).trimmed());
+                    location = QUrl(line.mid(line.indexOf(QLatin1Char(':')) + 1).trimmed());
                     if (!location.isValid())
-                        return 0;
+                        return nullptr;
                 }
                 else if (line.startsWith(QLatin1String("Server"), Qt::CaseInsensitive))
                 {
-                    server = line.mid(line.indexOf(':') + 1).trimmed();
-                    if (server.length() == 0)
-                        return 0;
+                    server = line.mid(line.indexOf(QLatin1Char(':')) + 1).trimmed();
+                    if (server.isEmpty())
+                        return nullptr;
 
                 }
-                else if (line.contains("USN", Qt::CaseInsensitive) && line.contains("uuid", Qt::CaseInsensitive))
+                else if (line.contains(QLatin1String("USN"), Qt::CaseInsensitive) && line.contains(QLatin1String("uuid"), Qt::CaseInsensitive))
                 {
-                    uuid = line.split(':').at(2);
+                    uuid = line.split(QLatin1Char(':')).at(2);
 
-                    if (uuid.length() == 0)
-                        return 0;
+                    if (uuid.isEmpty())
+                        return nullptr;
                 }
             }
 
             if (routers.contains(uuid))
             {
-                return 0;
+                return nullptr;
             }
             else
             {
-                qDebug() << "Detected IGD " << server << "UUID" << uuid << endl;
+                qCDebug(KONVERSATION_LOG) << "Detected IGD " << server << "UUID" << uuid;
                 // everything OK, make a new UPnPRouter
                 return new UPnPRouter(server,location,uuid);
             }
@@ -192,7 +189,7 @@ namespace Konversation
 
         void UPnPMCastSocket::onError(QAbstractSocket::SocketError )
         {
-            qDebug() << "UPnPMCastSocket Error : " << errorString() << endl;
+            qCDebug(KONVERSATION_LOG) << "UPnPMCastSocket Error : " << errorString();
         }
 
         void UPnPMCastSocket::joinUPnPMCastGroup()
@@ -211,7 +208,7 @@ namespace Konversation
             if (setsockopt(fd,IPPROTO_IP,IP_ADD_MEMBERSHIP,(char *)&mreq,sizeof(struct ip_mreq)) < 0)
     #endif
             {
-                qDebug() << "Failed to join multicast group 239.255.255.250" << endl;
+                qCDebug(KONVERSATION_LOG) << "Failed to join multicast group 239.255.255.250";
             }
         }
 
@@ -231,7 +228,7 @@ namespace Konversation
             if (setsockopt(fd,IPPROTO_IP,IP_DROP_MEMBERSHIP,(char *)&mreq,sizeof(struct ip_mreq)) < 0)
     #endif
             {
-                qDebug() << "Failed to leave multicast group 239.255.255.250" << endl;
+                qCDebug(KONVERSATION_LOG) << "Failed to leave multicast group 239.255.255.250";
             }
         }
     }
