@@ -1,33 +1,27 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005-2007 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006-2007 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2005-2007 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006-2007 Eike Hein <hein@kde.org>
 */
 
 #include "channeloptionsdialog.h"
+
 #include "application.h"
-#include "channel.h"
 #include "topichistorymodel.h"
+#include "konversation_log.h"
 
 #include <KColorScheme>
-
-#include <QCheckBox>
-#include <QHeaderView>
-#include <QPushButton>
-#include <QRegExp>
-#include <QStandardItemModel>
-#include <QKeyEvent>
-#include <QItemSelectionModel>
-#include <QTreeWidget>
 #include <KSharedConfig>
 #include <KConfigGroup>
+
+#include <QCheckBox>
+#include <QPushButton>
+#include <QRegularExpression>
+#include <QStandardItemModel>
+#include <QItemSelectionModel>
+#include <QTreeWidget>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 #include <QLocale>
@@ -56,9 +50,9 @@ namespace Konversation
 
         m_ui.setupUi(mainWidget);
 
-        m_ui.addBan->setIcon(QIcon::fromTheme("list-add"));
-        m_ui.updateBan->setIcon(QIcon::fromTheme("edit-rename"));
-        m_ui.removeBan->setIcon(QIcon::fromTheme("list-remove"));
+        m_ui.addBan->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+        m_ui.updateBan->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
+        m_ui.removeBan->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
 
         QStandardItemModel *modesModel = new QStandardItemModel(m_ui.otherModesList);
         m_ui.otherModesList->setModel(modesModel);
@@ -66,25 +60,31 @@ namespace Konversation
 
         m_ui.banListSearchLine->setTreeWidget(m_ui.banList);
 
-        installEventFilter(m_ui.topicHistoryView);
         m_ui.topicHistoryView->setServer(m_channel->getServer());
         m_ui.topicHistoryView->setModel(m_channel->getTopicHistory());
-        m_ui.topicHistorySearchLine->setProxy(static_cast<QSortFilterProxyModel*>(m_ui.topicHistoryView->model()));
-        m_ui.topicHistorySearchLine->lineEdit()->setPlaceholderText(QString());
+
+        m_historySearchTimer = new QTimer(this);
+        m_historySearchTimer->setSingleShot(true);
+
+        connect(m_historySearchTimer, &QTimer::timeout,
+                this, &ChannelOptionsDialog::updateHistoryFilter);
+
+        connect(m_ui.topicHistorySearchLine, &QLineEdit::textChanged,
+                this, &ChannelOptionsDialog::startHistorySearchTimer);
 
         m_editingTopic = false;
 
         m_ui.topicEdit->setChannel(channel);
         m_ui.topicEdit->setMaximumLength(m_channel->getServer()->topicLength());
 
-        connect(m_ui.topicHistoryView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                this, SLOT(topicHistoryItemClicked(QItemSelection)));
+        connect(m_ui.topicHistoryView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                this, &ChannelOptionsDialog::topicHistoryItemClicked);
         connect(m_ui.toggleAdvancedModes, &QPushButton::clicked, this, &ChannelOptionsDialog::toggleAdvancedModes);
         connect(m_ui.topicEdit, &TopicEdit::undoAvailable, this, &ChannelOptionsDialog::topicBeingEdited);
         connect(this, &ChannelOptionsDialog::finished, m_ui.topicEdit, &TopicEdit::clear);
 
         connect(m_channel, &Channel::modesChanged, this, &ChannelOptionsDialog::refreshModes);
-        connect(m_channel->getServer(), SIGNAL(channelNickChanged(QString)), this, SLOT(refreshEnableModes()));
+        connect(m_channel->getServer(), &Server::channelNickChanged, this, [this]() { refreshEnableModes(); });
 
         connect(m_channel, &Channel::banAdded, this, &ChannelOptionsDialog::addBan);
         connect(m_channel, &Channel::banRemoved, this, &ChannelOptionsDialog::removeBan);
@@ -122,6 +122,14 @@ namespace Konversation
             refreshAllowedChannelModes();
             refreshModes();
 
+            m_ui.topicEdit->clear();
+            m_editingTopic = false;
+
+            m_ui.topicHistoryView->selectionModel()->clearSelection();
+            const QModelIndex& currentTopic = m_ui.topicHistoryView->model()->index(m_ui.topicHistoryView->model()->rowCount() - 1, 0);
+            m_ui.topicHistoryView->selectionModel()->select(currentTopic, QItemSelectionModel::Select);
+            m_ui.topicHistoryView->scrollTo(currentTopic, QAbstractItemView::EnsureVisible);
+
             if (!m_ui.topicEdit->isReadOnly())
                 m_ui.topicEdit->setFocus();
 
@@ -134,7 +142,7 @@ namespace Konversation
             if (!sizes.isEmpty())
                 m_ui.splitter->setSizes(sizes);
 
-            Preferences::restoreColumnState(m_ui.banList, "BanList ViewSettings");
+            Preferences::restoreColumnState(m_ui.banList, QStringLiteral("BanList ViewSettings"));
         }
 
         QDialog::showEvent(event);
@@ -147,7 +155,7 @@ namespace Konversation
         config.writeEntry("Size", size());
         config.writeEntry("SplitterSizes", m_ui.splitter->sizes());
 
-        Preferences::saveColumnState(m_ui.banList, "BanList ViewSettings");
+        Preferences::saveColumnState(m_ui.banList, QStringLiteral("BanList ViewSettings"));
 
         QDialog::hideEvent(event);
     }
@@ -163,39 +171,39 @@ namespace Konversation
             if (newTopic.isEmpty())
             {
                 if (!oldTopic.isEmpty())
-                    m_channel->sendText(Preferences::self()->commandChar() + "TOPIC " + m_channel->getName() + " \x01");
+                    m_channel->sendText(Preferences::self()->commandChar() + QLatin1String("TOPIC ") + m_channel->getName() + QLatin1String(" \x01"));
             }
             else
-                m_channel->sendText(Preferences::self()->commandChar() + "TOPIC " + m_channel->getName() + ' ' + newTopic);
+                m_channel->sendText(Preferences::self()->commandChar() + QLatin1String("TOPIC ") + m_channel->getName() + QLatin1Char(' ') + newTopic);
         }
 
-        QStringList newModeList = modes();
-        QStringList currentModeList = m_channel->getModeList();
-        QStringList rmModes;
-        QStringList addModes;
-        QStringList tmp;
-        QString modeString;
-        bool plus;
-        QString command("MODE %1 %2%3 %4");
+        const QStringList newModeList = modes();
+        const QStringList currentModeList = m_channel->getModeList();
 
-        for(QStringList::ConstIterator it = newModeList.constBegin(); it != newModeList.constEnd(); ++it)
+        QString command(QStringLiteral("MODE %1 %2%3 %4"));
+
+        for (const QString &mode : newModeList)
         {
-            modeString = (*it).mid(1);
-            plus = ((*it)[0] == '+');
-            tmp = currentModeList.filter(QRegExp('^' + modeString));
+            const QString modeString = mode.mid(1);
+            const bool plus = mode.at(0) == QLatin1Char('+');
+            const QStringList tmp = currentModeList.filter(QRegularExpression(QLatin1Char('^') + modeString));
 
             if(tmp.isEmpty() && plus)
             {
-                m_channel->getServer()->queue(command.arg(m_channel->getName()).arg("+").arg(modeString[0]).arg(modeString.mid(1)));
+                m_channel->getServer()->queue(command.arg(m_channel->getName(), QStringLiteral("+"),
+                                                          modeString.at(0), modeString.mid(1)));
             }
             else if(!tmp.isEmpty() && !plus)
             {
                 //FIXME: Bahamuth requires the key parameter for -k, but ircd breaks on -l with limit number.
                 //Hence two versions of this.
-                if (modeString[0] == 'k')
-                    m_channel->getServer()->queue(command.arg(m_channel->getName()).arg("-").arg(modeString[0]).arg(modeString.mid(1)));
-                else
-                    m_channel->getServer()->queue(command.arg(m_channel->getName()).arg("-").arg(modeString[0]).arg(QString()));
+                if (modeString.at(0) == QLatin1Char('k')) {
+                    m_channel->getServer()->queue(command.arg(m_channel->getName(), QStringLiteral("-"),
+                                                              modeString.at(0), modeString.mid(1)));
+                } else {
+                    m_channel->getServer()->queue(command.arg(m_channel->getName(), QStringLiteral("-"),
+                                                              modeString.at(0), QString()));
+                }
             }
         }
         hide();
@@ -221,19 +229,23 @@ namespace Konversation
         m_ui.topicHistoryView->setTextSelectable(edited);
     }
 
-    QString ChannelOptionsDialog::topic()
+    QString ChannelOptionsDialog::topic() const
     {
-        return m_ui.topicEdit->toPlainText().replace('\n', ' ');
+        return m_ui.topicEdit->toPlainText().replace(QLatin1Char('\n'), QLatin1Char(' '));
     }
 
     void ChannelOptionsDialog::topicHistoryItemClicked(const QItemSelection& selection)
     {
         if (!m_editingTopic)
         {
+            m_ui.topicEdit->clear();
+
             if (!selection.isEmpty())
+            {
+                m_ui.topicEdit->setUndoRedoEnabled(false);
                 m_ui.topicEdit->setPlainText(m_ui.topicHistoryView->model()->data(selection.indexes().first()).toString());
-            else
-                m_ui.topicEdit->clear();
+                m_ui.topicEdit->setUndoRedoEnabled(true);
+            }
         }
     }
 
@@ -260,10 +272,10 @@ namespace Konversation
 
             if (model)
             {
-                QList<QStandardItem*> items = model->findItems("*", Qt::MatchWildcard, 0);
-                items += model->findItems("*", Qt::MatchWildcard, 1);
+                QList<QStandardItem*> items = model->findItems(QStringLiteral("*"), Qt::MatchWildcard, 0);
+                items += model->findItems(QStringLiteral("*"), Qt::MatchWildcard, 1);
 
-                foreach (QStandardItem* item, items)
+                for (QStandardItem* item : qAsConst(items))
                     item->setEnabled(m_isAnyTypeOfOp);
             }
 
@@ -281,49 +293,48 @@ namespace Konversation
     {
         QString modeString = m_channel->getServer()->allowedChannelModes();
         // These modes are handled in a special way: ntimslkbeI
-        modeString.remove('t');
-        modeString.remove('n');
-        modeString.remove('l');
-        modeString.remove('i');
-        modeString.remove('m');
-        modeString.remove('s');
-        modeString.remove('k');
-        modeString.remove('b');
-        modeString.remove('e');
-        modeString.remove('I');
-        modeString.remove('O');
-        modeString.remove('o');
-        modeString.remove('v');
+        modeString.remove(QLatin1Char('t'));
+        modeString.remove(QLatin1Char('n'));
+        modeString.remove(QLatin1Char('l'));
+        modeString.remove(QLatin1Char('i'));
+        modeString.remove(QLatin1Char('m'));
+        modeString.remove(QLatin1Char('s'));
+        modeString.remove(QLatin1Char('k'));
+        modeString.remove(QLatin1Char('b'));
+        modeString.remove(QLatin1Char('e'));
+        modeString.remove(QLatin1Char('I'));
+        modeString.remove(QLatin1Char('O'));
+        modeString.remove(QLatin1Char('o'));
+        modeString.remove(QLatin1Char('v'));
 
-        QStandardItemModel *modesModel = qobject_cast<QStandardItemModel *>(m_ui.otherModesList->model());
+        auto* modesModel = static_cast<QStandardItemModel *>(m_ui.otherModesList->model());
 
         modesModel->clear();
-        modesModel->setHorizontalHeaderLabels(QStringList() << i18n("Mode") << i18n("Parameter"));
+        modesModel->setHorizontalHeaderLabels(QStringList { i18n("Mode"), i18n("Parameter") });
 
-        for(int i = 0; i < modeString.length(); i++)
-        {
-            QList<QStandardItem *> newRow;
-            QStandardItem *item = 0;
+        for (const QChar mode : qAsConst(modeString)) {
+            const QString modeAsString(mode);
 
-            if(!Preferences::self()->useLiteralModes() && getChannelModesHash().contains(modeString[i]))
-                item = new QStandardItem(i18nc("<mode character> (<mode description>)","%1 (%2)", modeString[i], getChannelModesHash().value(modeString[i])));
+            QStandardItem *item = nullptr;
+            if (!Preferences::self()->useLiteralModes() && getChannelModesHash().contains(mode))
+                item = new QStandardItem(i18nc("<mode character> (<mode description>)","%1 (%2)", mode, getChannelModesHash().value(mode)));
             else
-                item = new QStandardItem(QString(modeString[i]));
-
-            item->setData(QString(modeString[i]));
+                item = new QStandardItem(modeAsString);
+            item->setData(modeAsString);
             item->setCheckable(true);
             item->setEditable(false);
-            newRow.append(item);
-            item = new QStandardItem();
-            item->setEditable(true);
-            newRow.append(item);
+
+            auto* secondItem = new QStandardItem();
+            secondItem->setEditable(true);
+
+            const QList<QStandardItem *> newRow { item, secondItem };
             modesModel->invisibleRootItem()->appendRow(newRow);
         }
     }
 
     void ChannelOptionsDialog::refreshModes()
     {
-        QStringList modes = m_channel->getModeList();
+        const QStringList modes = m_channel->getModeList();
 
         m_ui.topicModeChBox->setChecked(false);
         m_ui.messageModeChBox->setChecked(false);
@@ -335,7 +346,7 @@ namespace Konversation
         m_ui.keyModeChBox->setChecked(false);
         m_ui.keyModeEdit->setText(QString());
 
-        QStandardItemModel *modesModel = qobject_cast<QStandardItemModel *>(m_ui.otherModesList->model());
+        auto* modesModel = static_cast<QStandardItemModel *>(m_ui.otherModesList->model());
         for (int i = 0; i < modesModel->rowCount(); ++i)
         {
             modesModel->item(i, 0)->setCheckState(Qt::Unchecked);
@@ -343,8 +354,7 @@ namespace Konversation
 
         char mode;
 
-        foreach (const QString &currentMode, modes)
-        {
+        for (const QString &currentMode : modes) {
             mode = currentMode[0].toLatin1();
             switch(mode)
             {
@@ -356,7 +366,7 @@ namespace Konversation
                     break;
                 case 'l':
                     m_ui.userLimitChBox->setChecked(true);
-                    m_ui.userLimitEdit->setValue(currentMode.mid(1).toInt());
+                    m_ui.userLimitEdit->setValue(currentMode.midRef(1).toInt());
                     break;
                 case 'i':
                     m_ui.inviteModeChBox->setChecked(true);
@@ -375,7 +385,7 @@ namespace Konversation
                 {
                     bool found = false;
                     QString modeString;
-                    modeString = mode;
+                    modeString = QLatin1Char(mode);
 
                     for (int i = 0; !found && i < modesModel->rowCount(); ++i)
                     {
@@ -396,47 +406,49 @@ namespace Konversation
         refreshEnableModes(true);
     }
 
-    QStringList ChannelOptionsDialog::modes()
+    QStringList ChannelOptionsDialog::modes() const
     {
         QStringList modes;
         QString mode;
 
-        mode = (m_ui.topicModeChBox->isChecked() ? "+" : "-");
-        mode += 't';
+        const QString plus = QStringLiteral("+");
+        const QString minus = QStringLiteral("-");
+        mode = (m_ui.topicModeChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('t');
         modes.append(mode);
-        mode = (m_ui.messageModeChBox->isChecked() ? "+" : "-");
-        mode += 'n';
+        mode = (m_ui.messageModeChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('n');
         modes.append(mode);
-        mode = (m_ui.userLimitChBox->isChecked() ? "+" : "-");
-        mode += 'l' + QString::number( m_ui.userLimitEdit->value() );
+        mode = (m_ui.userLimitChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('l') + QString::number( m_ui.userLimitEdit->value() );
         modes.append(mode);
-        mode = (m_ui.inviteModeChBox->isChecked() ? "+" : "-");
-        mode += 'i';
+        mode = (m_ui.inviteModeChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('i');
         modes.append(mode);
-        mode = (m_ui.moderatedModeChBox->isChecked() ? "+" : "-");
-        mode += 'm';
+        mode = (m_ui.moderatedModeChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('m');
         modes.append(mode);
-        mode = (m_ui.secretModeChBox->isChecked() ? "+" : "-");
-        mode += 's';
+        mode = (m_ui.secretModeChBox->isChecked() ? plus : minus);
+        mode += QLatin1Char('s');
         modes.append(mode);
 
         if (m_ui.keyModeChBox->isChecked() && !m_ui.keyModeEdit->text().isEmpty())
         {
-            mode = '+';
-            mode += 'k' + m_ui.keyModeEdit->text();
+            mode = plus;
+            mode += QLatin1Char('k') + m_ui.keyModeEdit->text();
             modes.append(mode);
         }
         else if (!m_ui.keyModeChBox->isChecked())
         {
-            mode = '-';
-            mode += 'k' + m_ui.keyModeEdit->text();
+            mode = minus;
+            mode += QLatin1Char('k') + m_ui.keyModeEdit->text();
             modes.append(mode);
         }
 
-        QStandardItemModel *modesModel = qobject_cast<QStandardItemModel *>(m_ui.otherModesList->model());
+        auto* modesModel = static_cast<QStandardItemModel *>(m_ui.otherModesList->model());
         for (int i = 0; i < modesModel->rowCount(); ++i)
         {
-            mode = (modesModel->item(i, 0)->checkState() == Qt::Checked ? "+" : "-");
+            mode = (modesModel->item(i, 0)->checkState() == Qt::Checked) ? plus : minus;
             mode += modesModel->item(i, 0)->data().toString() + modesModel->item(i, 1)->text();
             modes.append(mode);
         }
@@ -457,7 +469,7 @@ namespace Konversation
 
     void ChannelOptionsDialog::addBan(const QString& newban)
     {
-        BanListViewItem *item = new BanListViewItem(m_ui.banList, newban.section(' ', 0, 0), newban.section(' ', 1, 1).section('!', 0, 0), newban.section(' ', 2 ,2).toUInt());
+        BanListViewItem *item = new BanListViewItem(m_ui.banList, newban.section(QLatin1Char(' '), 0, 0), newban.section(QLatin1Char(' '), 1, 1).section(QLatin1Char('!'), 0, 0), newban.section(QLatin1Char(' '), 2 ,2).toUInt());
         // set item as current item
         m_ui.banList->setCurrentItem(item);
         // update button states
@@ -467,7 +479,7 @@ namespace Konversation
     void ChannelOptionsDialog::removeBan(const QString& ban)
     {
         QList<QTreeWidgetItem *> items = m_ui.banList->findItems(ban, Qt::MatchCaseSensitive | Qt::MatchExactly, 0);
-        if (items.count() > 0)
+        if (!items.isEmpty())
           delete items.at(0);
     }
 
@@ -524,13 +536,12 @@ namespace Konversation
     /// Enables/disables addBan and updateBan buttons depending on the value of @p text
     void ChannelOptionsDialog::hostmaskChanged(const QString& text)
     {
-      if (text.trimmed().length() != 0)
-      {
+      if (!text.trimmed().isEmpty()) {
         if (m_isAnyTypeOfOp)
         {
           QList<QTreeWidgetItem*> items = m_ui.banList->findItems(text, Qt::MatchExactly | Qt::MatchCaseSensitive, 0);
-          m_ui.addBan->setEnabled(items.count() == 0);
-          m_ui.updateBan->setEnabled(items.count() == 0 && m_ui.banList->currentItem());
+          m_ui.addBan->setEnabled(items.isEmpty());
+          m_ui.updateBan->setEnabled(items.isEmpty() && m_ui.banList->currentItem());
         }
       }
       else
@@ -539,6 +550,24 @@ namespace Konversation
         m_ui.updateBan->setEnabled(false);
       }
     }
+
+    void ChannelOptionsDialog::startHistorySearchTimer(const QString &filter)
+    {
+        Q_UNUSED(filter)
+        m_historySearchTimer->start(300);
+    }
+
+    void ChannelOptionsDialog::updateHistoryFilter()
+    {
+        QSortFilterProxyModel* proxy = qobject_cast<QSortFilterProxyModel*>(m_ui.topicHistoryView->model());
+
+        if(!proxy)
+            return;
+
+        proxy->setFilterFixedString(m_ui.topicHistorySearchLine->text());
+    }
+
+
     // This is our implementation of BanListViewItem
 
     BanListViewItem::BanListViewItem(QTreeWidget *parent)
@@ -552,7 +581,7 @@ namespace Konversation
     {
         setText(0, label1);
         setText(1, label2);
-        m_timestamp.setTime_t(timestamp);
+        m_timestamp.setMSecsSinceEpoch(static_cast<qint64>(timestamp) * 1000);
         setText(2, QLocale().toString(m_timestamp, QLocale::ShortFormat));
         setData(2, Qt::UserRole, m_timestamp);
         parent->addTopLevelItem(this);
@@ -593,7 +622,7 @@ QString Konversation::ChannelOptionsDialog::whatsThisForMode(char mode)
     case 'L':
         return i18n("<qt><p>These control the <em>mode</em> of the channel.  Only an operator can change these.</p><p>A channel that has a user <b>L</b>imit means that only that many users can be in the channel at any one time.  Some channels have a bot that sits in the channel and changes this automatically depending on how busy the channel is.</p></qt>");
     default:
-        qWarning() << "called for unknown mode" << mode;
+        qCWarning(KONVERSATION_LOG) << "called for unknown mode" << mode;
         return QString();
     }
 }
