@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef CHATWINDOW_H
@@ -72,8 +67,8 @@ class ChatWindow : public QWidget
         void setTextView(IRCView* newView);
         IRCView* getTextView() const;
         void setInputBar(IRCInput* newInputBar) { m_inputBar = newInputBar; }
-        IRCInput* getInputBar() { return m_inputBar; }
-        virtual bool log();
+        IRCInput* getInputBar() const { return m_inputBar; }
+        virtual bool log() const;
 
         QString getName() const;
         QString getTitle() const;
@@ -97,24 +92,24 @@ class ChatWindow : public QWidget
 
         void clear();
 
-        virtual QString getTextInLine();
+        virtual QString getTextInLine() const;
         /** Reimplement this to return true in all classes that /can/ become front view.
          */
-        virtual bool canBeFrontView();
+        virtual bool canBeFrontView() const;
 
         /** Reimplement this to return true in all classes that you can search in - i.e. use "Edit->Find Text" in.
          */
-        virtual bool searchView();
+        virtual bool searchView() const;
 
-        virtual bool notificationsEnabled() { return m_notificationsEnabled; }
+        bool notificationsEnabled() const { return m_notificationsEnabled; }
 
         bool eventFilter(QObject* watched, QEvent* e) override;
 
-        QString logFileName() { return logfile.fileName(); }
+        QString logFileName() const { return logfile.fileName(); }
 
         virtual void setChannelEncoding(const QString& /* encoding */) {}
-        virtual QString getChannelEncoding() { return QString(); }
-        virtual QString getChannelEncodingDefaultDesc() { return QString(); }
+        virtual QString getChannelEncoding() const { return QString(); }
+        virtual QString getChannelEncodingDefaultDesc() const { return QString(); }
         bool isChannelEncodingSupported() const;
 
         /** Force updateInfo(info) to be emitted.
@@ -125,20 +120,21 @@ class ChatWindow : public QWidget
         /** child classes have to override this and return true if they want the
          *  "insert character" item on the menu to be enabled.
          */
-        virtual bool isInsertSupported() { return m_inputBar != 0; }
+        virtual bool isInsertSupported() const { return m_inputBar != nullptr; }
 
         /** child classes have to override this and return true if they want the
          *  "irc color" item on the menu to be enabled.
          */
-        virtual bool areIRCColorsSupported() {return false; }
+        virtual bool areIRCColorsSupported() const {return false; }
 
         Konversation::TabNotifyType currentTabNotification() const { return m_currentTabNotify; }
         QColor highlightColor();
 
         void msgHelper(const QString& recipient, const QString& message);
 
-        void setMargin(int margin) { layout()->setMargin(margin); }
+        void setMargin(int margin) { layout()->setContentsMargins(margin, margin, margin, margin); }
         void setSpacing(int spacing) { layout()->setSpacing(spacing); }
+        void activateView();
 
     Q_SIGNALS:
         void nameChanged(ChatWindow* view, const QString& newName);
@@ -153,9 +149,10 @@ class ChatWindow : public QWidget
         void clearStatusBarTempText();
 
         void closing(ChatWindow* myself);
+        void showView(ChatWindow* myself);
 
     public Q_SLOTS:
-        void updateAppearance();
+        virtual void updateAppearance();
 
         void logText(const QString& text);
 
@@ -199,6 +196,7 @@ class ChatWindow : public QWidget
         int spacing();
         int margin();
 
+    protected:
         bool firstLog;
         QString name;
         QString logName;
@@ -225,5 +223,8 @@ class ChatWindow : public QWidget
         Konversation::TabNotifyType m_currentTabNotify;
 
         bool m_recreationScheduled;
+
+        Q_DISABLE_COPY(ChatWindow)
 };
+
 #endif
