@@ -1,14 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Wed Sep 1 2004
-  copyright: (C) 2004 by Gary Cramblitt
-  email:     garycramblitt@comcast.net
+    SPDX-FileCopyrightText: 2004 Gary Cramblitt <garycramblitt@comcast.net>
 */
 
 #include "editnotifydialog.h"
@@ -20,10 +13,8 @@
 
 #include <KLineEdit>
 #include <KComboBox>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <KGuiItem>
 #include <QVBoxLayout>
 
 
@@ -72,10 +63,8 @@ const QString& nickname):
 
     // Add network names to network combobox and select the one corresponding to argument.
     m_networkNameCombo->addItem(i18n("All Networks"), -1);
-    QList<Server *> serverList = Application::instance()->getConnectionManager()->getServerList();
-    for (int i = 0; i < serverList.count(); ++i)
-    {
-      Server *server = serverList.at(i);
+    const QList<Server*> serverList = Application::instance()->getConnectionManager()->getServerList();
+    for (Server *server : serverList) {
       if (server->getServerGroup())
         m_networkNameCombo->addItem(server->getServerGroup()->name(), server->getServerGroup()->id());
     }
@@ -86,8 +75,8 @@ const QString& nickname):
     layout->addWidget(m_nicknameInput, 1, 1);
 
 
-    KGuiItem::assign(okButton, KGuiItem(i18n("&OK"),"dialog-ok",i18n("Change notify information")));
-    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KGuiItem(i18n("&Cancel"),"dialog-cancel",i18n("Discards all changes made")));
+    okButton->setToolTip(i18n("Change notify information"));
+    buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Discards all changes made"));
 
     m_nicknameInput->setFocus();
 }
