@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005-2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005-2006 Eike Hein <hein@kde.org>
 */
 
 #include "images.h"
@@ -19,7 +14,6 @@
 #include <QPainter>
 
 #include <QStandardPaths>
-#include <QDebug>
 
 
 using namespace Konversation;
@@ -32,6 +26,7 @@ class LedIconEngine : public QIconEngine
             : QIconEngine(), m_color(color), m_state(state)
         {
         }
+        ~LedIconEngine() override = default;
 
         // QIconEngine
         void paint(QPainter *painter, const QRect &rect, QIcon::Mode mode, QIcon::State state) override;
@@ -41,18 +36,21 @@ class LedIconEngine : public QIconEngine
     private:
         const QColor m_color;
         const bool m_state;
+
+        Q_DISABLE_COPY(LedIconEngine)
 };
 
 void LedIconEngine::paint(QPainter *painter, const QRect &rect, QIcon::Mode mode, QIcon::State state)
 {
-    Q_UNUSED(mode);
-    Q_UNUSED(state);
+    Q_UNUSED(mode)
+    Q_UNUSED(state)
+
     QColor color;
     QBrush brush;
     QPen pen;
 
     if (!m_state)
-        color = m_color.dark(180);
+        color = m_color.darker(180);
     else
         color = m_color;
 
@@ -84,7 +82,7 @@ void LedIconEngine::paint(QPainter *painter, const QRect &rect, QIcon::Mode mode
     // Draw the bright spot on the LED
     while (light_width)
     {
-        color = color.light( light_quote ); // make color lighter
+        color = color.lighter( light_quote ); // make color lighter
         pen.setColor( color );              // set color as pen color
         painter->setPen( pen );                // select the pen for drawing
         painter->drawEllipse( pos, pos, light_width, light_width ); // draw the ellipse (circle)
@@ -183,11 +181,10 @@ void Images::initializeLeds()
 void Images::initializeNickIcons()
 {
     QString iconTheme = Preferences::self()->iconTheme();
-    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konversation/themes/"+iconTheme, QStandardPaths::LocateDirectory);
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("konversation/themes/") + iconTheme, QStandardPaths::LocateDirectory);
     const bool isDefaultTheme = (iconTheme == QLatin1String("default"));
 
-    foreach(const QString& dir, dirs)
-    {
+    for (const QString& dir : qAsConst(dirs)) {
         if (nickIconSet->load(dir)) {
             break;
         }
@@ -197,8 +194,7 @@ void Images::initializeNickIcons()
     if (nickIconSet->isNull() && !isDefaultTheme) {
         dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konversation/themes/default"), QStandardPaths::LocateDirectory);
 
-        foreach(const QString& dir, dirs)
-        {
+        for (const QString& dir : qAsConst(dirs)) {
             if (nickIconSet->load(dir)) {
                 break;
             }
@@ -206,7 +202,7 @@ void Images::initializeNickIcons()
     }
 }
 
-QIcon Images::getLed(const QColor& col,bool state)
+QIcon Images::getLed(const QColor& col,bool state) const
 {
     Q_UNUSED(col)
     Q_UNUSED(state)
@@ -214,7 +210,7 @@ QIcon Images::getLed(const QColor& col,bool state)
     return QIcon(new LedIconEngine(col, state));
 }
 
-QIcon Images::getServerLed(bool state)
+QIcon Images::getServerLed(bool state) const
 {
     if (state)
         return m_serverLedOn;
@@ -222,7 +218,7 @@ QIcon Images::getServerLed(bool state)
         return m_serverLedOff;
 }
 
-QIcon Images::getSystemLed(bool state)
+QIcon Images::getSystemLed(bool state) const
 {
     if (Preferences::self()->tabNotificationsSystemColor()!=m_systemColor)
     {
@@ -240,7 +236,7 @@ QIcon Images::getSystemLed(bool state)
     }
 }
 
-QIcon Images::getMsgsLed(bool state)
+QIcon Images::getMsgsLed(bool state) const
 {
     if (Preferences::self()->tabNotificationsMsgsColor()!=m_msgsColor)
     {
@@ -258,7 +254,7 @@ QIcon Images::getMsgsLed(bool state)
     }
 }
 
-QIcon Images::getPrivateLed(bool state)
+QIcon Images::getPrivateLed(bool state) const
 {
     if (Preferences::self()->tabNotificationsPrivateColor()!=m_privateColor)
     {
@@ -276,7 +272,7 @@ QIcon Images::getPrivateLed(bool state)
     }
 }
 
-QIcon Images::getEventsLed()
+QIcon Images::getEventsLed() const
 {
     if (Preferences::self()->tabNotificationsEventsColor()!=m_eventsColor)
         return getLed(Preferences::self()->tabNotificationsEventsColor(),true);
@@ -284,7 +280,7 @@ QIcon Images::getEventsLed()
         return m_eventsLedOn;
 }
 
-QIcon Images::getNickLed()
+QIcon Images::getNickLed() const
 {
     if (Preferences::self()->tabNotificationsNickColor()!=m_nickColor)
         return getLed(Preferences::self()->tabNotificationsNickColor(),true);
@@ -292,7 +288,7 @@ QIcon Images::getNickLed()
         return m_nickLedOn;
 }
 
-QIcon Images::getHighlightsLed()
+QIcon Images::getHighlightsLed() const
 {
     if (Preferences::self()->tabNotificationsHighlightsColor()!=m_highlightsColor)
         return getLed(Preferences::self()->tabNotificationsHighlightsColor(),true);
