@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2010 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2010 Eike Hein <hein@kde.org>
 */
 
 #include "irccontextmenus.h"
@@ -34,15 +18,16 @@
 #include <KBookmarkManager>
 #include <QFileDialog>
 #include <KIO/CopyJob>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
 #include <QMenu>
 #include <KMessageBox>
-#include <KRun>
 #include <KStandardAction>
 #include <KStringHandler>
 #include <KToggleAction>
 
 // For the Web Shortcuts context menu sub-menu.
-#include <KToolInvocation>
+#include <KIO/CommandLauncherJob>
 #include <KUriFilter>
 
 
@@ -103,7 +88,7 @@ void IrcContextMenus::setupQuickButtonMenu()
     //NOTE: if we depend on m_nickMenu we get an we an cyclic initialising
     m_quickButtonMenu = new QMenu();
     m_quickButtonMenu->setTitle(i18n("Quick Buttons"));
-    connect(Application::instance(), SIGNAL(appearanceChanged()), this, SLOT(updateQuickButtonMenu()));
+    connect(Application::instance(), &Application::appearanceChanged, this, &IrcContextMenus::updateQuickButtonMenu);
 }
 
 bool IrcContextMenus::shouldShowQuickButtonMenu()
@@ -118,25 +103,25 @@ void IrcContextMenus::updateQuickButtonMenu()
     QAction * action;
     QString pattern;
 
-    foreach(const QString& button, Preferences::quickButtonList())
-    {
-        pattern = button.section(',', 1);
+    const auto buttons = Preferences::quickButtonList();
+    for (const QString& button : buttons) {
+        pattern = button.section(QLatin1Char(','), 1);
 
-        if (pattern.contains("%u"))
+        if (pattern.contains(QLatin1String("%u")))
         {
-            action = new QAction(button.section(',', 0, 0), m_quickButtonMenu);
+            action = new QAction(button.section(QLatin1Char(','), 0, 0), m_quickButtonMenu);
             action->setData(pattern);
             m_quickButtonMenu->addAction(action);
         }
     }
 }
 
-void IrcContextMenus::processQuickButtonAction(QAction* action, Server* server, const QString& context, const QStringList nicks)
+void IrcContextMenus::processQuickButtonAction(QAction* action, Server* server, const QString& context, const QStringList &nicks)
 {
     ChatWindow* chatWindow = server->getChannelOrQueryByName(context);
     QString line = server->parseWildcards(action->data().toString(), chatWindow, nicks);
 
-    if (line.contains('\n'))
+    if (line.contains(QLatin1Char('\n')))
         chatWindow->sendText(line);
     else
     {
@@ -151,33 +136,33 @@ void IrcContextMenus::setupTextMenu()
 
     m_textMenu->addSeparator();
 
-    m_linkActions << createAction(m_textMenu, LinkCopy, QIcon::fromTheme("edit-copy"), i18n("Copy Link Address"));
+    m_linkActions << createAction(m_textMenu, LinkCopy, QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Link Address"));
     // Not using KStandardAction is intentional here since the Ctrl+B
     // shortcut it would show in the menu is already used by our IRC-
     // wide bookmarking feature.
-    m_linkActions << createAction(m_textMenu, LinkBookmark, QIcon::fromTheme("bookmark-new"), i18n("Add to Bookmarks"));
+    m_linkActions << createAction(m_textMenu, LinkBookmark, QIcon::fromTheme(QStringLiteral("bookmark-new")), i18n("Add to Bookmarks"));
     m_linkActions << createAction(m_textMenu, LinkOpenWith, i18n("Open With..."));
-    m_linkActions << createAction(m_textMenu, LinkSaveAs, QIcon::fromTheme("document-save"), i18n("Save Link As..."));
+    m_linkActions << createAction(m_textMenu, LinkSaveAs, QIcon::fromTheme(QStringLiteral("document-save")), i18n("Save Link As..."));
 
     m_textMenu->addSeparator();
 
-    m_textCopyAction = KStandardAction::copy(0, 0, this);
+    m_textCopyAction = KStandardAction::copy(nullptr, nullptr, this);
     m_textCopyAction->setData(TextCopy);
     m_textMenu->addAction(m_textCopyAction);
     m_textCopyAction->setEnabled(false);
 
-    QAction* action = KStandardAction::selectAll(0, 0, this);
+    QAction* action = KStandardAction::selectAll(nullptr, nullptr, this);
     action->setData(TextSelectAll);
     m_textMenu->addAction(action);
 
     m_webShortcutsMenu = new QMenu();
-    m_webShortcutsMenu->menuAction()->setIcon(QIcon::fromTheme("preferences-web-browser-shortcuts"));
+    m_webShortcutsMenu->menuAction()->setIcon(QIcon::fromTheme(QStringLiteral("preferences-web-browser-shortcuts")));
     m_webShortcutsMenu->menuAction()->setVisible(false);
     m_textMenu->addMenu(m_webShortcutsMenu);
 
     m_textActionsSeparator = m_textMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedBasicNickActions)
+    for (QAction* action : qAsConst(m_sharedBasicNickActions))
         m_textMenu->addAction(action);
 
     m_textMenu->addSeparator();
@@ -186,12 +171,12 @@ void IrcContextMenus::setupTextMenu()
 
     m_textMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedNickSettingsActions)
+    for (QAction* action : qAsConst(m_sharedNickSettingsActions))
         m_textMenu->addAction(action);
 
     m_textMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedDccActions)
+    for (QAction* action : qAsConst(m_sharedDccActions))
         m_textMenu->addAction(action);
 
     m_textMenu->addSeparator();
@@ -204,14 +189,14 @@ int IrcContextMenus::textMenu(const QPoint& pos, MenuOptions options, Server* se
 
     KActionCollection* actionCollection = Application::instance()->getMainWindow()->actionCollection();
 
-    KToggleAction* toggleMenuBarAction = static_cast<KToggleAction*>(actionCollection->action("options_show_menubar"));
+    KToggleAction* toggleMenuBarAction = qobject_cast<KToggleAction*>(actionCollection->action(QStringLiteral("options_show_menubar")));
 
     if (toggleMenuBarAction && !toggleMenuBarAction->isChecked())
         textMenu->insertAction(textMenu->actions().first(), toggleMenuBarAction);
 
     bool showLinkActions = options.testFlag(ShowLinkActions);
 
-    foreach(QAction* action, self()->m_linkActions)
+    for (QAction* action : qAsConst(self()->m_linkActions))
         action->setVisible(showLinkActions);
 
     self()->m_textCopyAction->setEnabled(!selectedText.isEmpty());
@@ -220,7 +205,7 @@ int IrcContextMenus::textMenu(const QPoint& pos, MenuOptions options, Server* se
 
     bool showNickActions = options.testFlag(ShowNickActions);
 
-    foreach(QAction* action, self()->m_sharedBasicNickActions)
+    for (QAction* action : qAsConst(self()->m_sharedBasicNickActions))
         action->setVisible(showNickActions);
 
     self()->m_quickButtonMenu->menuAction()->setVisible(showNickActions && self()->shouldShowQuickButtonMenu());
@@ -229,31 +214,31 @@ int IrcContextMenus::textMenu(const QPoint& pos, MenuOptions options, Server* se
     {
         bool connected = server->isConnected();
 
-        foreach(QAction* action, self()->m_sharedBasicNickActions)
+        for (QAction* action : qAsConst(self()->m_sharedBasicNickActions))
             action->setEnabled(connected);
 
-        updateSharedNickSettingsActions(server, QStringList() << nick);
+        updateSharedNickSettingsActions(server, QStringList { nick });
 
-        foreach(QAction* action, self()->m_sharedDccActions)
+        for (QAction* action : qAsConst(self()->m_sharedDccActions))
             action->setEnabled(connected);
     }
     else
     {
-        foreach(QAction* action, self()->m_sharedNickSettingsActions)
+        for (QAction* action : qAsConst(self()->m_sharedNickSettingsActions))
             action->setVisible(false);
     }
 
-    foreach(QAction* action, self()->m_sharedDccActions)
+    for (QAction* action : qAsConst(self()->m_sharedDccActions))
         action->setVisible(showNickActions);
 
     if (options.testFlag(ShowFindAction))
-        textMenu->insertAction(self()->m_textActionsSeparator, actionCollection->action(KStandardAction::name(KStandardAction::Find)));
+        textMenu->insertAction(self()->m_textActionsSeparator, actionCollection->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Find))));
 
     if (options.testFlag(ShowLogAction))
-        textMenu->addAction(actionCollection->action("open_logfile"));
+        textMenu->addAction(actionCollection->action(QStringLiteral("open_logfile")));
 
     if (options.testFlag(ShowChannelActions))
-        textMenu->addAction(actionCollection->action("channel_settings"));
+        textMenu->addAction(actionCollection->action(QStringLiteral("channel_settings")));
 
     QAction* action = textMenu->exec(pos);
 
@@ -263,12 +248,12 @@ int IrcContextMenus::textMenu(const QPoint& pos, MenuOptions options, Server* se
         processLinkAction(actionId, link);
 
     if (self()->m_quickButtonMenu->actions().contains(action))
-        processQuickButtonAction(action, server, nick, QStringList() << nick);
+        processQuickButtonAction(action, server, nick, QStringList { nick });
 
     textMenu->removeAction(toggleMenuBarAction);
-    textMenu->removeAction(actionCollection->action(KStandardAction::name(KStandardAction::Find)));
-    textMenu->removeAction(actionCollection->action("open_logfile"));
-    textMenu->removeAction(actionCollection->action("channel_settings"));
+    textMenu->removeAction(actionCollection->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Find))));
+    textMenu->removeAction(actionCollection->action(QStringLiteral("open_logfile")));
+    textMenu->removeAction(actionCollection->action(QStringLiteral("channel_settings")));
 
     return actionId;
 }
@@ -282,7 +267,7 @@ void IrcContextMenus::updateWebShortcutsMenu(const QString& selectedText)
         return;
 
     QString searchText = selectedText;
-    searchText = searchText.replace('\n', ' ').replace('\r', ' ').simplified();
+    searchText = searchText.replace(QLatin1Char('\n'), QLatin1Char(' ')).replace(QLatin1Char('\r'), QLatin1Char(' ')).simplified();
 
     if (searchText.isEmpty())
         return;
@@ -299,10 +284,9 @@ void IrcContextMenus::updateWebShortcutsMenu(const QString& selectedText)
         {
             m_webShortcutsMenu->setTitle(i18n("Search for '%1' with",  KStringHandler::rsqueeze(searchText, 21)));
 
-            QAction * action = 0;
+            QAction * action = nullptr;
 
-            foreach(const QString& searchProvider, searchProviders)
-            {
+            for (const QString& searchProvider : searchProviders) {
                 action = new QAction(searchProvider, m_webShortcutsMenu);
                 action->setIcon(QIcon::fromTheme(filterData.iconNameForPreferredSearchProvider(searchProvider)));
                 action->setData(filterData.queryForPreferredSearchProvider(searchProvider));
@@ -313,7 +297,7 @@ void IrcContextMenus::updateWebShortcutsMenu(const QString& selectedText)
             m_webShortcutsMenu->addSeparator();
 
             action = new QAction(i18n("Configure Web Shortcuts..."), m_webShortcutsMenu);
-            action->setIcon(QIcon::fromTheme("configure"));
+            action->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
             connect(action, &QAction::triggered, this, &IrcContextMenus::configureWebShortcuts);
             m_webShortcutsMenu->addAction(action);
 
@@ -331,20 +315,21 @@ void IrcContextMenus::processWebShortcutAction()
         KUriFilterData filterData(action->data().toString());
 
         if (KUriFilter::self()->filterSearchUri(filterData, KUriFilter::WebShortcutFilter))
-            Application::instance()->openUrl(filterData.uri().url());
+            Application::openUrl(filterData.uri().url());
     }
 }
 
 void IrcContextMenus::configureWebShortcuts()
 {
-    KToolInvocation::kdeinitExec("kcmshell5", QStringList() << "webshortcuts");
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("webshortcuts")});
+    job->start();
 }
 
 void IrcContextMenus::setupChannelMenu()
 {
     m_channelMenu = new QMenu();
 
-    QAction* defaultAction = createAction(m_channelMenu, Join, QIcon::fromTheme("irc-join-channel"), i18n("&Join Channel..."));
+    QAction* defaultAction = createAction(m_channelMenu, Join, QIcon::fromTheme(QStringLiteral("irc-join-channel")), i18n("&Join Channel..."));
     m_channelMenu->setDefaultAction(defaultAction);
 
     createAction(m_channelMenu, Topic, i18n("Get &topic"));
@@ -362,7 +347,8 @@ void IrcContextMenus::channelMenu(const QPoint& pos, Server* server, const QStri
 
     bool connected = server->isConnected();
 
-    foreach(QAction* action, channelMenu->actions())
+    const auto channelMenuActions = channelMenu->actions();
+    for (QAction* action : channelMenuActions)
         action->setEnabled(connected);
 
     QAction* action = channelMenu->exec(pos);
@@ -372,13 +358,13 @@ void IrcContextMenus::channelMenu(const QPoint& pos, Server* server, const QStri
     switch (extractActionId(action))
     {
         case Join:
-            commandToServer(server, "join " + channel);
+            commandToServer(server, QLatin1String("join ") + channel);
             break;
         case Topic:
             server->requestTopic(channel);
             break;
         case Names:
-            commandToServer(server, "names " + channel);
+            commandToServer(server, QLatin1String("names ") + channel);
             break;
         case TextCopy:
             qApp->clipboard()->setText(channel, QClipboard::Clipboard);
@@ -397,7 +383,7 @@ void IrcContextMenus::setupNickMenu()
 
     m_nickMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedBasicNickActions)
+    for (QAction* action : qAsConst(m_sharedBasicNickActions))
         m_nickMenu->addAction(action);
 
     m_nickMenu->addSeparator();
@@ -405,12 +391,12 @@ void IrcContextMenus::setupNickMenu()
     m_modesMenu = new QMenu();
     m_nickMenu->addMenu(m_modesMenu);
     m_modesMenu->setTitle(i18n("Modes"));
-    createAction(m_modesMenu, GiveOp, QIcon::fromTheme("irc-operator"), i18n("Give Op"));
-    createAction(m_modesMenu, TakeOp, QIcon::fromTheme("irc-remove-operator"), i18n("Take Op"));
+    createAction(m_modesMenu, GiveOp, QIcon::fromTheme(QStringLiteral("irc-operator")), i18n("Give Op"));
+    createAction(m_modesMenu, TakeOp, QIcon::fromTheme(QStringLiteral("irc-remove-operator")), i18n("Take Op"));
     createAction(m_modesMenu, GiveHalfOp, i18n("Give HalfOp"));
     createAction(m_modesMenu, TakeHalfOp, i18n("Take HalfOp"));
-    createAction(m_modesMenu, GiveVoice, QIcon::fromTheme("irc-voice"), i18n("Give Voice"));
-    createAction(m_modesMenu, TakeVoice, QIcon::fromTheme("irc-unvoice"), i18n("Take Voice"));
+    createAction(m_modesMenu, GiveVoice, QIcon::fromTheme(QStringLiteral("irc-voice")), i18n("Give Voice"));
+    createAction(m_modesMenu, TakeVoice, QIcon::fromTheme(QStringLiteral("irc-unvoice")), i18n("Take Voice"));
 
     m_kickBanMenu = new QMenu();
     m_nickMenu->addMenu(m_kickBanMenu);
@@ -433,12 +419,12 @@ void IrcContextMenus::setupNickMenu()
 
     m_nickMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedNickSettingsActions)
+    for (QAction* action : qAsConst(m_sharedNickSettingsActions))
         m_nickMenu->addAction(action);
 
     m_nickMenu->addSeparator();
 
-    foreach(QAction* action, m_sharedDccActions)
+    for (QAction* action : qAsConst(m_sharedDccActions))
         m_nickMenu->addAction(action);
 }
 
@@ -456,16 +442,16 @@ void IrcContextMenus::createSharedNickSettingsActions()
     m_unignoreAction = createAction(UnignoreNick, i18n("Unignore"));
     m_sharedNickSettingsActions << m_unignoreAction;
 
-    m_addNotifyAction = createAction(AddNotify, QIcon::fromTheme("list-add-user"), i18n("Add to Watched Nicks"));
+    m_addNotifyAction = createAction(AddNotify, QIcon::fromTheme(QStringLiteral("list-add-user")), i18n("Add to Watched Nicks"));
     m_sharedNickSettingsActions << m_addNotifyAction;
-    m_removeNotifyAction = createAction(RemoveNotify, QIcon::fromTheme("list-remove-user"), i18n("Remove From Watched Nicks"));
+    m_removeNotifyAction = createAction(RemoveNotify, QIcon::fromTheme(QStringLiteral("list-remove-user")), i18n("Remove From Watched Nicks"));
     m_sharedNickSettingsActions << m_removeNotifyAction;
 }
 
 void IrcContextMenus::createSharedDccActions()
 {
-    if (KAuthorized::authorizeAction("allow_downloading"))
-        m_sharedDccActions << createAction(DccSend, QIcon::fromTheme("arrow-right-double"), i18n("Send &File..."));
+    if (KAuthorized::authorizeAction(QStringLiteral("allow_downloading")))
+        m_sharedDccActions << createAction(DccSend, QIcon::fromTheme(QStringLiteral("arrow-right-double")), i18n("Send &File..."));
 
     m_sharedDccActions << createAction(StartDccChat, i18n("Open DCC Chat"));
     m_sharedDccActions << createAction(StartDccWhiteboard, i18n("Open DCC Whiteboard"));
@@ -479,7 +465,8 @@ void IrcContextMenus::nickMenu(const QPoint& pos, MenuOptions options, Server* s
     if (options.testFlag(ShowTitle) && nicks.count() == 1)
         nickMenu->setTitle(KStringHandler::rsqueeze(nicks.first(), 15));
 
-    foreach(QAction* action, nickMenu->actions())
+    const auto nickMenuActions = nickMenu->actions();
+    for (QAction* action : nickMenuActions)
         action->setVisible(true);
 
     self()->m_modesMenu->menuAction()->setVisible(options.testFlag(ShowChannelActions));
@@ -488,10 +475,10 @@ void IrcContextMenus::nickMenu(const QPoint& pos, MenuOptions options, Server* s
 
     bool connected = server->isConnected();
 
-    foreach(QAction* action, self()->m_sharedBasicNickActions)
+    for (QAction* action : qAsConst(self()->m_sharedBasicNickActions))
         action->setEnabled(connected);
 
-    foreach(QAction* action, self()->m_sharedDccActions)
+    for (QAction* action : qAsConst(self()->m_sharedDccActions))
         action->setEnabled(connected);
 
     self()->m_modesMenu->menuAction()->setEnabled(connected);
@@ -516,84 +503,84 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
         channel = context;
 
     QString pattern;
-    QString mode;
+    QChar mode;
 
     switch (actionId)
     {
         case OpenQuery:
-            commandToServer(server, "query %1", nicks);
+            commandToServer(server, QStringLiteral("query %1"), nicks);
             break;
         case Whois:
-            commandToServer(server, "whois %1 %1", nicks);
+            commandToServer(server, QStringLiteral("whois %1 %1"), nicks);
             break;
         case Version:
-            commandToServer(server, "ctcp %1 VERSION", nicks);
+            commandToServer(server, QStringLiteral("ctcp %1 VERSION"), nicks);
             break;
         case Ping:
-            commandToServer(server, "ctcp %1 PING", nicks);
+            commandToServer(server, QStringLiteral("ctcp %1 PING"), nicks);
             break;
         case GiveOp:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c +%m %l";
-            mode = 'o';
+            pattern = QStringLiteral("MODE %c +%m %l");
+            mode = QLatin1Char('o');
             break;
         case TakeOp:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c -%m %l";
-            mode = 'o';
+            pattern = QStringLiteral("MODE %c -%m %l");
+            mode = QLatin1Char('o');
             break;
         case GiveHalfOp:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c +%m %l";
-            mode = 'h';
+            pattern = QStringLiteral("MODE %c +%m %l");
+            mode = QLatin1Char('h');
             break;
         case TakeHalfOp:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c -%m %l";
-            mode = 'h';
+            pattern = QStringLiteral("MODE %c -%m %l");
+            mode = QLatin1Char('h');
             break;
         case GiveVoice:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c +%m %l";
-            mode = 'v';
+            pattern = QStringLiteral("MODE %c +%m %l");
+            mode = QLatin1Char('v');
             break;
         case TakeVoice:
             if (channel.isEmpty()) break;
-            pattern = "MODE %c -%m %l";
-            mode = 'v';
+            pattern = QStringLiteral("MODE %c -%m %l");
+            mode = QLatin1Char('v');
             break;
         case Kick:
-            commandToServer(server, "kick %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kick %1"), nicks, channel);
             break;
         case KickBan:
-            commandToServer(server, "kickban %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kickban %1"), nicks, channel);
             break;
         case BanNick:
-            commandToServer(server, "ban %1", nicks, channel);
+            commandToServer(server, QStringLiteral("ban %1"), nicks, channel);
             break;
         case BanHost:
-            commandToServer(server, "ban -HOST %1", nicks, channel);
+            commandToServer(server, QStringLiteral("ban -HOST %1"), nicks, channel);
             break;
         case BanDomain:
-            commandToServer(server, "ban -DOMAIN %1", nicks, channel);
+            commandToServer(server, QStringLiteral("ban -DOMAIN %1"), nicks, channel);
             break;
         case BanUserHost:
-            commandToServer(server, "ban -USERHOST %1", nicks, channel);
+            commandToServer(server, QStringLiteral("ban -USERHOST %1"), nicks, channel);
             break;
         case BanUserDomain:
-            commandToServer(server, "ban -USERDOMAIN %1", nicks, channel);
+            commandToServer(server, QStringLiteral("ban -USERDOMAIN %1"), nicks, channel);
             break;
         case KickBanHost:
-            commandToServer(server, "kickban -HOST %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kickban -HOST %1"), nicks, channel);
             break;
         case KickBanDomain:
-            commandToServer(server, "kickban -DOMAIN %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kickban -DOMAIN %1"), nicks, channel);
             break;
         case KickBanUserHost:
-            commandToServer(server, "kickban -USERHOST %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kickban -USERHOST %1"), nicks, channel);
             break;
         case KickBanUserDomain:
-            commandToServer(server, "kickban -USERDOMAIN %1", nicks, channel);
+            commandToServer(server, QStringLiteral("kickban -USERDOMAIN %1"), nicks, channel);
             break;
         case IgnoreNick:
         {
@@ -610,11 +597,11 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
                 i18n("Ignore"),
                 KGuiItem(i18n("Ignore")),
                 KStandardGuiItem::cancel(),
-                "IgnoreNick"
+                QStringLiteral("IgnoreNick")
                 ) ==
                 KMessageBox::Continue)
             {
-                commandToServer(server, "ignore -ALL " + nicks.join(" "));
+                commandToServer(server, QLatin1String("ignore -ALL ") + nicks.join(QLatin1Char(' ')));
             }
 
             break;
@@ -624,8 +611,7 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
             QString question;
             QStringList selectedIgnoredNicks;
 
-            foreach(const QString& nick, nicks)
-            {
+            for (const QString& nick : nicks) {
                 if (Preferences::isIgnored(nick))
                     selectedIgnoredNicks << nick;
             }
@@ -641,10 +627,10 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
                 i18n("Unignore"),
                 KGuiItem(i18n("Unignore")),
                 KStandardGuiItem::cancel(),
-                "UnignoreNick") ==
+                QStringLiteral("UnignoreNick")) ==
                 KMessageBox::Continue)
             {
-                commandToServer(server, "unignore " + selectedIgnoredNicks.join(" "));
+                commandToServer(server, QLatin1String("unignore ") + selectedIgnoredNicks.join(QLatin1Char(' ')));
             }
 
             break;
@@ -653,7 +639,7 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
         {
             if (!server->getServerGroup()) break;
 
-            foreach(const QString& nick, nicks)
+            for(const QString& nick : nicks)
                 Preferences::addNotify(server->getServerGroup()->id(), nick);
 
             break;
@@ -662,19 +648,19 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
         {
             if (!server->getServerGroup()) break;
 
-            foreach(const QString& nick, nicks)
+            for(const QString& nick : nicks)
                 Preferences::removeNotify(server->getServerGroup()->id(), nick);
 
             break;
         }
         case DccSend:
-            commandToServer(server, "dcc send %1", nicks);
+            commandToServer(server, QStringLiteral("dcc send %1"), nicks);
             break;
         case StartDccChat:
-            commandToServer(server, "dcc chat %1", nicks);
+            commandToServer(server, QStringLiteral("dcc chat %1"), nicks);
             break;
         case StartDccWhiteboard:
-            commandToServer(server, "dcc whiteboard %1", nicks);
+            commandToServer(server, QStringLiteral("dcc whiteboard %1"), nicks);
             break;
         default:
             break;
@@ -682,7 +668,7 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
 
     if (!pattern.isEmpty())
     {
-        pattern.replace("%c", channel);
+        pattern.replace(QLatin1String("%c"), channel);
 
         QString command;
         QStringList partialList;
@@ -692,10 +678,10 @@ void IrcContextMenus::processNickAction(int actionId, Server* server, const QStr
         {
             command = pattern;
             partialList = nicks.mid(index, modesCount);
-            command = command.replace("%l", partialList.join(" "));
-            const QString repeatedMode = mode.repeated(partialList.count());
+            command.replace(QLatin1String("%l"), partialList.join(QLatin1Char(' ')));
+            const QString repeatedMode = QString(partialList.count(), mode);
 
-            command = command.replace("%m", repeatedMode);
+            command.replace(QLatin1String("%m"), repeatedMode);
 
             server->queue(command);
         }
@@ -714,8 +700,7 @@ void IrcContextMenus::updateSharedNickSettingsActions(Server* server, const QStr
     if (server->getServerGroup())
         serverGroupId = server->getServerGroup()->id();
 
-    foreach(const QString& nick, nicks)
-    {
+    for (const QString& nick : nicks) {
         if (Preferences::isIgnored(nick))
             ++unignoreCounter;
         else
@@ -766,7 +751,11 @@ void IrcContextMenus::processLinkAction(int  actionId, const QString& link)
         }
         case LinkOpenWith:
         {
-            KRun::displayOpenWithDialog(QList<QUrl>() << QUrl(link), Application::instance()->getMainWindow());
+            // ApplicationLauncherJob ctor without args will invoke the open-with dialog
+            auto *job = new KIO::ApplicationLauncherJob();
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
+            job->setUrls({ QUrl(link) });
+            job->start();
 
             break;
         }
@@ -811,7 +800,7 @@ void IrcContextMenus::topicHistoryMenu(const QPoint& pos, Server* server, const
             qApp->clipboard()->setText(text, QClipboard::Clipboard);
             break;
         case OpenQuery:
-            commandToServer(server, QString("query %1").arg(author));
+            commandToServer(server, QStringLiteral("query %1").arg(author));
             break;
         default:
             break;
@@ -883,7 +872,7 @@ int IrcContextMenus::extractActionId(QAction* action)
 
 void IrcContextMenus::commandToServer(Server* server, const QString& command, const QString& destination)
 {
-    Konversation::OutputFilterResult result = server->getOutputFilter()->parse(QString(), Preferences::self()->commandChar() + command, destination);
+    const Konversation::OutputFilterResult result = server->getOutputFilter()->parse(QString(), Preferences::self()->commandChar() + command, destination);
 
     server->queue(result.toServer);
 
@@ -891,7 +880,7 @@ void IrcContextMenus::commandToServer(Server* server, const QString& command, co
         server->appendMessageToFrontmost(result.typeString, result.output);
     else if (!result.outputList.isEmpty())
     {
-        foreach(const QString& output, result.outputList)
+        for (const QString& output : result.outputList)
             server->appendMessageToFrontmost(result.typeString, output);
     }
 }
@@ -899,6 +888,6 @@ void IrcContextMenus::commandToServer(Server* server, const QString& command, co
 void IrcContextMenus::commandToServer(Server* server, const QString& command,
     const QStringList& arguments, const QString& destination)
 {
-    foreach(const QString& argument, arguments)
+    for (const QString& argument : arguments)
         commandToServer(server, command.arg(argument), destination);
 }
