@@ -1,31 +1,24 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  The line input widget with chat enhanced functions
-  begin:     Tue Mar 5 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "ircinput.h"
 #include "application.h"
 #include "pasteeditor.h"
+#include "ircview.h"
+#include "topiclabel.h"
 
 #include <QClipboard>
 #include <QKeyEvent>
-#include <QMenu>
 #include <QMimeData>
 
 #include <KMessageBox>
 #include <KCompletionBox>
 #include <KActionCollection>
 
-#define MAXHISTORY 100
+constexpr int MAXHISTORY = 100;
 
 IRCInput::IRCInput(QWidget* parent) : KTextEdit(parent)
 {
@@ -35,7 +28,8 @@ IRCInput::IRCInput(QWidget* parent) : KTextEdit(parent)
     //nor in compensating for it if my guess is incorrect. so, cache it.
     m_qtBoxPadding = document()->size().toSize().height() - fontMetrics().lineSpacing();
 
-    connect(qApp, SIGNAL(appearanceChanged()), this, SLOT(updateAppearance()));
+    connect(Application::instance(), &Application::appearanceChanged,
+            this, &IRCInput::updateAppearance);
     m_multiRow = Preferences::self()->useMultiRowInputBox();
 
     // add one empty line to the history (will be overwritten with newest entry)
@@ -78,8 +72,6 @@ void IRCInput::createHighlighter()
 
 QSize IRCInput::sizeHint() const
 {
-    QFontMetrics fm(font());
-
     int h = document()->size().toSize().height();
 
     QStyleOptionFrame opt;
@@ -89,7 +81,7 @@ QSize IRCInput::sizeHint() const
     opt.midLineWidth = 0;
     opt.state |= QStyle::State_Sunken;
 
-    QSize s = style()->sizeFromContents(QStyle::CT_LineEdit, &opt, QSize(100, h).expandedTo(QApplication::globalStrut()), this);
+    QSize s = style()->sizeFromContents(QStyle::CT_LineEdit, &opt, QSize(100, h), this);
 
     return s;
 }
@@ -128,7 +120,7 @@ void IRCInput::hideEvent(QHideEvent* /* event */)
     //TODO FIXME when we get to require 4.2 the above is possible with
     //KTextEditSpellInterface and is actually quite easy to do.
 
-    disconnect(SIGNAL(checkSpellingChanged(bool)));
+    disconnect(this, &IRCInput::checkSpellingChanged, nullptr, nullptr);
     m_disableSpellCheckTimer->setSingleShot(true);
     m_disableSpellCheckTimer->start(5000);
 }
@@ -192,11 +184,10 @@ void IRCInput::setText(const QString& text, bool preserveContents)
 //take text events from IRCView and TopicLabel
 bool IRCInput::eventFilter(QObject *object,QEvent *event)
 {
-    if (object->metaObject()->className() == QString("IRCView") || object->metaObject()->className() == QString("Konversation::TopicLabel"))
-    {
+    if (qobject_cast<IRCView*>(object) || qobject_cast<Konversation::TopicLabel*>(object)) {
         if (event->type() == QEvent::KeyPress)
         {
-            QKeyEvent* ke = static_cast<QKeyEvent*>(event);
+            auto* ke = static_cast<QKeyEvent*>(event);
 
             // Allow tab to be handled naturally by the widget.
             // Once it runs out of links it goes to the next control.
@@ -285,7 +276,7 @@ void IRCInput::keyPressEvent(QKeyEvent* e)
 
             // support ASCII BEL
             if(e->text().unicode()->toLatin1() == 7)
-                insertPlainText("%G");
+                insertPlainText(QStringLiteral("%G"));
             // support ^U (delete text in input box)
             else if(e->text().unicode()->toLatin1() == 21)
                 setText(QString());
@@ -299,11 +290,11 @@ bool IRCInput::event(QEvent* e)
     if (e->type() == QEvent::ShortcutOverride)
     {
         // Make sure KTextEdit doesn't eat actionCollection shortcuts
-        QKeyEvent* event = static_cast<QKeyEvent*>(e);
+        auto* event = static_cast<QKeyEvent*>(e);
         const int key = event->key() | event->modifiers();
 
-        foreach(QAction* action, Application::instance()->getMainWindow()->actionCollection()->actions())
-        {
+        const auto actions = Application::instance()->getMainWindow()->actionCollection()->actions();
+        for (QAction* action : actions) {
             if (action->shortcuts().contains(QKeySequence(key)))
             {
                 event->ignore();
@@ -318,9 +309,9 @@ bool IRCInput::event(QEvent* e)
 
 void IRCInput::wheelEvent(QWheelEvent* e)
 {
-    if (e->delta() > 0)
+    if (e->angleDelta().y() > 0)
         getHistory(true);
-    else if (e->delta() < 0)
+    else if (e->angleDelta().y() < 0)
         getHistory(false);
 
     KTextEdit::wheelEvent(e);
@@ -404,25 +395,24 @@ void IRCInput::insertFromMimeData(const QMimeData * source)
         Konversation::sterilizeUnicode(pasteText);
 
         // replace \r with \n to make xterm pastes happy
-        pasteText.replace('\r','\n');
+        pasteText.replace(QLatin1Char('\r'), QLatin1Char('\n'));
         // remove blank lines
-        while(pasteText.contains("\n\n"))
-            pasteText.replace("\n\n","\n");
+        while(pasteText.contains(QLatin1String("\n\n")))
+            pasteText.replace(QLatin1String("\n\n"),QLatin1String("\n"));
 
-        QRegExp reTopSpace("^ *\n");
+        QRegExp reTopSpace(QStringLiteral("^ *\n"));
         while(pasteText.contains(reTopSpace))
             pasteText.remove(reTopSpace);
 
-        QRegExp reBottomSpace("\n *$");
+        QRegExp reBottomSpace(QStringLiteral("\n *$"));
         while(pasteText.contains(reBottomSpace))
             pasteText.remove(reBottomSpace);
 
         // does the text contain at least one newline character?
-        if(pasteText.contains('\n'))
-        {
+        if( pasteText.contains(QLatin1Char('\n'))) {
             // make comparisons easier (avoid signed / unsigned warnings)
-            int pos=pasteText.indexOf('\n');
-            int rpos=pasteText.lastIndexOf('\n');
+            const int pos = pasteText.indexOf(QLatin1Char('\n'));
+            const int rpos = pasteText.lastIndexOf(QLatin1Char('\n'));
 
             // emit the signal if there's a line break in the middle of the text
             if(pos>0 && pos!=(pasteText.length()-1))
@@ -433,7 +423,7 @@ void IRCInput::insertFromMimeData(const QMimeData * source)
 
             // Remove the \n from end of the line if there's only one \n
             if(!signal)
-                pasteText.remove('\n');
+                pasteText.remove(QLatin1Char('\n'));
         }
         else
         {
@@ -449,7 +439,7 @@ void IRCInput::insertFromMimeData(const QMimeData * source)
             if(!toPlainText().isEmpty())
             {
               // prepend text to the paste
-              pasteText=toPlainText()+'\n'+pasteText;
+              pasteText = toPlainText() + QLatin1Char('\n') + pasteText;
             }
             // ask the user on long pastes
             if(checkPaste(pasteText))
@@ -475,7 +465,7 @@ bool IRCInput::checkPaste(QString& text)
     int doPaste=KMessageBox::Yes;
 
     //text is now preconditioned when you get here
-    int lines=text.count('\n');
+    const int lines = text.count(QLatin1Char('\n'));
 
     if(text.length()>256 || lines)
     {
@@ -493,7 +483,7 @@ bool IRCInput::checkPaste(QString& text)
             KGuiItem(i18n("Paste")),
             KGuiItem(i18n("&Edit...")),
             KStandardGuiItem::cancel(),
-            QString("LargePaste"),
+            QStringLiteral("LargePaste"),
             KMessageBox::Dangerous);
     }
 
@@ -525,7 +515,7 @@ void IRCInput::insertCompletion(const QString& nick)
 
     QString line = toPlainText();
 
-    while(pos && line[pos-1] != ' ') pos--;
+    while(pos && line[pos-1] != QLatin1Char(' ')) pos--;
 
     line.remove(pos, oldPos - pos);
 
@@ -562,8 +552,8 @@ void IRCInput::doInlineAutoreplace()
 // Accessor methods
 
 void IRCInput::setCompletionMode(char mode) { completionMode=mode; }
-char IRCInput::getCompletionMode() { return completionMode; }
+char IRCInput::getCompletionMode() const { return completionMode; }
 void IRCInput::setOldCursorPosition(int pos) { oldPos=pos; }
-int IRCInput::getOldCursorPosition() { return oldPos; }
+int IRCInput::getOldCursorPosition() const { return oldPos; }
 
 
