@@ -1,14 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005-2016 Peter Simonsson <peter.simonsson@gmail.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005-2016 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef IRCVIEW_H
@@ -22,6 +17,7 @@
 
 #include <QTextBrowser>
 #include <QUrl>
+#include <QDateTime>
 
 
 class Server;
@@ -35,9 +31,12 @@ class IrcViewMarkerLine: public QObject, public QTextObjectInterface
 
     public:
         IrcViewMarkerLine(QObject *p) : QObject(p), QTextObjectInterface() {}
-        ~IrcViewMarkerLine() override {}
+        ~IrcViewMarkerLine() {}
         void drawObject(QPainter *painter, const QRectF &rect, QTextDocument *doc, int posInDocument, const QTextFormat &format) override;
         QSizeF intrinsicSize(QTextDocument *doc, int posInDocument, const QTextFormat &format) override;
+
+    private:
+        Q_DISABLE_COPY(IrcViewMarkerLine)
 };
 
 /// Helper struct which remembers the openHtmlTags, the fore and
@@ -94,6 +93,19 @@ class IRCView : public QTextBrowser
         void setStatusBarTempText(const QString&); //! these two look like mixins to me
         void clearStatusBarTempText();//! these two look like mixins to me
 
+    protected:
+        QMimeData* createMimeDataFromSelection() const override;
+        void dragEnterEvent(QDragEnterEvent* e) override;
+        void dragMoveEvent(QDragMoveEvent* e) override;
+        void dropEvent(QDropEvent* e) override;
+
+        void resizeEvent(QResizeEvent *event) override;
+        void mouseReleaseEvent(QMouseEvent* ev) override;
+        void mousePressEvent(QMouseEvent* ev) override;
+        void mouseMoveEvent(QMouseEvent* ev) override;
+        void keyPressEvent(QKeyEvent* ev) override;
+        void contextMenuEvent(QContextMenuEvent* ev) override;
+        void wheelEvent(QWheelEvent* ev) override;
 
     //// Marker lines
     public:
@@ -102,10 +114,10 @@ class IRCView : public QTextBrowser
         bool hasLines();
 
         /// QTextBlockFormat states for setUserState.
-        enum BlockStates { None = -1, BlockIsMarker = 1, BlockIsRemember = 2 };
+        enum BlockStates { None = -1, BlockIsMarker = 1, BlockIsRemember = 2, BlockIsDateMarker = 3 };
 
         /// QTextCharFormat object types.
-        enum ObjectFormats { MarkerLine = QTextFormat::UserObject, RememberLine};
+        enum ObjectFormats { MarkerLine = QTextFormat::UserObject, RememberLine, DateLine };
 
     public Q_SLOTS:
         /// Inserts a marker line.
@@ -124,12 +136,6 @@ class IRCView : public QTextBrowser
         /// Does not effect m_rememberLineDirtyBit.
         void clearLines();
 
-    protected:
-        QMimeData* createMimeDataFromSelection() const override;
-        void dragEnterEvent(QDragEnterEvent* e) override;
-        void dragMoveEvent(QDragMoveEvent* e) override;
-        void dropEvent(QDropEvent* e) override;
-
     private:
         /// The internal mechanics of inserting a line.
         /// Clears m_rememberLineDirtyBit.
@@ -147,10 +153,12 @@ class IRCView : public QTextBrowser
         bool lastBlockIsLine(int select=-1);
 
         /// Causes a block to stop being a marker.
-        void voidLineBlock(QTextBlock rem);
+        void voidLineBlock(const QTextBlock &rem);
 
         /// Shortcut to get an object format of the desired type
-        QTextCharFormat getFormat(ObjectFormats);
+        static QTextCharFormat getFormat(ObjectFormats);
+
+        BlockStates objectFormatToBlockState(ObjectFormats format);
 
     public Q_SLOTS:
         // Doesn't have to be a slot, but what the hay.
@@ -180,21 +188,18 @@ class IRCView : public QTextBrowser
 
         void appendQuery(const QString& nick, const QString& message, const QHash<QString, QString> &messageTags, bool inChannel = false);
         void appendQueryAction(const QString& nick, const QString& message, const QHash<QString, QString> &messageTags);
-    protected:
-        //! FIXME why is this protected, and all alone down there?
-        void appendAction(const QString& nick, const QString& message, const QHash<QString, QString> &messageTags);
 
-        /// Appends a new line without any scrollback or notification checks
-        void doRawAppend(const QString& newLine, bool rtl);
-
-    public Q_SLOTS:
         void appendChannelAction(const QString& nick, const QString& message, const QHash<QString, QString> &messageTags);
 
         void appendServerMessage(const QString& type, const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool parseURL = true);
         void appendCommandMessage(const QString& command, const QString& message, const QHash<QString, QString> &messageTags, bool parseURL=true, bool self=false);
         void appendBacklogMessage(const QString& firstColumn, const QString& message);
 
-    protected:
+    private:
+        void appendAction(const QString& nick, const QString& message, const QHash<QString, QString> &messageTags);
+
+        /// Appends a new line without any scrollback or notification checks
+        void doRawAppend(const QString& newLine, bool rtl);
         void doAppend(const QString& line, bool rtl, bool self=false);
 
     public Q_SLOTS:
@@ -209,22 +214,20 @@ class IRCView : public QTextBrowser
         void decreaseFontSize();
         void resetFontSize();
 
-    protected Q_SLOTS:
-        void highlightedSlot(const QString& link);
-        void anchorClicked(const QUrl& url);
+    private Q_SLOTS:
+        void highlightedSlot(const QUrl& link);
+        void handleAnchorClicked(const QUrl& url);
 
-    protected:
+    private:
         void openLink(const QUrl &url);
 
-        QString filter(const QString& line, const QString& defaultColor, const QString& who=QString(), bool doHighlight=true, bool parseURL=true, bool self=false, QChar::Direction* direction = 0);
+        QString filter(const QString& line, const QString& defaultColor, const QString& who=QString(), bool doHighlight=true, bool parseURL=true, bool self=false, QChar::Direction* direction = nullptr);
 
         void replaceDecoration(QString& line, char decoration, char replacement);
 
-    private:
-
         /// Returns a string where all irc-richtext chars are replaced with proper
         /// html tags and all urls are parsed if parseURL is true
-        inline QString ircTextToHtml(const QString& text, bool parseURL, const QString& defaultColor, const QString& whoSent, bool closeAllTags = true, QChar::Direction* direction = 0);
+        inline QString ircTextToHtml(const QString& text, bool parseURL, const QString& defaultColor, const QString& whoSent, bool closeAllTags = true, QChar::Direction* direction = nullptr);
 
         /// Returns a string that closes all open html tags to <parm>tag</parm>
         /// The closed tag is removed from opentagList in data
@@ -274,16 +277,7 @@ class IRCView : public QTextBrowser
         /// Parses the colors in <parm>text</parm> starting from <parm>start</parm>
         /// and returns them in the given fg and bg string, as well as information
         /// if the values are valid
-        inline QString getColors(const QString& text, int start, QString& _fgColor, QString& _bgColor, bool* invalidFgVal, bool* invalidBgValue);
-
-    protected:
-        void resizeEvent(QResizeEvent *event) override;
-        void mouseReleaseEvent(QMouseEvent* ev) override;
-        void mousePressEvent(QMouseEvent* ev) override;
-        void mouseMoveEvent(QMouseEvent* ev) override;
-        void keyPressEvent(QKeyEvent* ev) override;
-        void contextMenuEvent(QContextMenuEvent* ev) override;
-        void wheelEvent(QWheelEvent* ev) override;
+        static QString getColors(const QString& text, int start, QString& _fgColor, QString& _bgColor, bool* invalidFgVal, bool* invalidBgValue);
 
         QChar::Direction basicDirection(const QString &string);
 
@@ -291,9 +285,9 @@ class IRCView : public QTextBrowser
         bool dateRtlDirection();
 
         /// Format the line by adding needed bidi marks
-        QString formatFinalLine(bool rtl, QString lineColor, QString label, QString nickLine, QString nickStar, QString text);
+        QString formatFinalLine(bool rtl, const QString &lineColor, const QString &label, const QString &nickLine, const QString &nickStar, const QString &text);
 
-        /// Returns a formated timestamp if timestamps are enabled else it returns QString::null
+        /// Returns a formated timestamp if timestamps are enabled else it returns QString()
         QString timeStamp(QHash<QString, QString> messageTags, bool rtl);
 
         /// Returns a formated nick string
@@ -301,9 +295,9 @@ class IRCView : public QTextBrowser
         QString createNickLine(const QString& nick, const QString& defaultColor,
             bool encapsulateNick = true, bool privMsg = false);
 
+    private:
         //// Search
         QTextDocument::FindFlags m_searchFlags;
-        bool m_forward;
         QString m_pattern;
 
         //used in ::filter
@@ -344,5 +338,11 @@ class IRCView : public QTextBrowser
 
         ChatWindow* m_chatWin;
         friend class IRCStyleSheet;
+
+        QDateTime m_prevTimestamp;
+        bool m_showDate;
+
+        Q_DISABLE_COPY(IRCView)
 };
+
 #endif
