@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #include "topicedit.h"
@@ -33,18 +17,18 @@
 #include <QTextCodec>
 
 
-#define MARGIN 4
+constexpr int MARGIN = 4;
 
 
 TopicEdit::TopicEdit(QWidget* parent) : KTextEdit(parent)
 {
-    m_channel = 0;
+    m_channel = nullptr;
 
     m_maximumLength = -1;
     m_maxCursorPos = -1;
 
-    m_warning = 0;
-    m_warningUndercarriage = 0;
+    m_warning = nullptr;
+    m_warningUndercarriage = nullptr;
 
     viewport()->installEventFilter(this);
 
@@ -75,14 +59,14 @@ void TopicEdit::setMaximumLength(int length)
     m_maximumLength = length;
 
     if (m_maximumLength != -1)
-        connect(document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
+        connect(document(), &QTextDocument::contentsChange, this, &TopicEdit::contentsChanged);
     else
-        disconnect(document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
+        disconnect(document(), &QTextDocument::contentsChange, this, &TopicEdit::contentsChanged);
 }
 
 void TopicEdit::contentsChanged(int position, int charsRemoved, int charsAdded)
 {
-    Q_UNUSED(position);
+    Q_UNUSED(position)
 
     // If there are no undo steps, the change probably occurred via setText() rather
     // than user interaction.
@@ -294,13 +278,11 @@ QSize TopicEdit::minimumSizeHint() const
 
 bool TopicEdit::eventFilter(QObject* watched, QEvent* event)
 {
-    Q_UNUSED(watched);
-
     if ((event->type() == QEvent::Resize || event->type() == QEvent::Move)
         && m_warning && m_warning->isVisible())
         updateWarningGeometry();
 
-    return false;
+    return KTextEdit::eventFilter(watched, event);
 }
 
 void TopicEdit::moveEvent(QMoveEvent* event)
