@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #ifndef TOPICEDIT_H
@@ -38,8 +22,8 @@ class TopicEdit : public KTextEdit
     Q_OBJECT
 
     public:
-        explicit TopicEdit(QWidget* parent = 0);
-        ~TopicEdit() override;
+        explicit TopicEdit(QWidget* parent = nullptr);
+        ~TopicEdit();
 
         Channel* channel() const;
         void setChannel(Channel* channel);
@@ -69,6 +53,7 @@ class TopicEdit : public KTextEdit
         void hideWarning();
         void updateWarningGeometry();
 
+    private:
         int m_maximumLength;
         int m_maxCursorPos;
 
@@ -76,6 +61,8 @@ class TopicEdit : public KTextEdit
         QWidget* m_warningUndercarriage;
 
         Channel* m_channel;
+
+        Q_DISABLE_COPY(TopicEdit)
 };
 
 #endif
