@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #include "topichistoryview.h"
@@ -28,7 +12,7 @@
 #include <KCategoryDrawer>
 
 
-#define MARGIN 2
+constexpr int MARGIN = 2;
 
 
 TopicHistorySortfilterProxyModel::TopicHistorySortfilterProxyModel(QObject* parent) : KCategorizedSortFilterProxyModel(parent)
@@ -55,7 +39,7 @@ QVariant TopicHistorySortfilterProxyModel::data(const QModelIndex& index, int ro
     {
         const QModelIndex& sourceIndex = mapToSource(index);
 
-        return sourceModel()->data(sourceIndex.sibling(sourceIndex.row(), 2)).toDateTime().toTime_t();
+        return sourceModel()->data(sourceIndex.sibling(sourceIndex.row(), 2)).toDateTime().toSecsSinceEpoch();
     }
 
     return KCategorizedSortFilterProxyModel::data(index, role);
@@ -64,24 +48,24 @@ QVariant TopicHistorySortfilterProxyModel::data(const QModelIndex& index, int ro
 void TopicHistorySortfilterProxyModel::setSourceModel(QAbstractItemModel* model)
 {
     if (sourceModel())
-        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
+        disconnect(sourceModel(), &QAbstractItemModel::dataChanged, this, &TopicHistorySortfilterProxyModel::sourceDataChanged);
 
     KCategorizedSortFilterProxyModel::setSourceModel(model);
 
-    connect(model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
+    connect(model, &QAbstractItemModel::dataChanged, this, &TopicHistorySortfilterProxyModel::sourceDataChanged);
 }
 
 bool TopicHistorySortfilterProxyModel::filterAcceptsColumn(int source_column, const QModelIndex& source_parent) const
 {
-    Q_UNUSED(source_parent);
+    Q_UNUSED(source_parent)
 
     return (source_column == 0);
 }
 
 void TopicHistorySortfilterProxyModel::sourceDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
 {
-    Q_UNUSED(topLeft);
-    Q_UNUSED(bottomRight);
+    Q_UNUSED(topLeft)
+    Q_UNUSED(bottomRight)
 
     emit layoutAboutToBeChanged();
     emit layoutChanged();
@@ -134,8 +118,6 @@ TopicHistoryItemDelegate::~TopicHistoryItemDelegate()
 
 bool TopicHistoryItemDelegate::eventFilter(QObject* watched, QEvent* event)
 {
-    Q_UNUSED(watched);
-
     // NOTE: QTextEdit needs to have been shown at least once (and while its
     // parents are shown, too) before it starts to calculate the document sizes
     // we need in sizeHint().
@@ -146,7 +128,7 @@ bool TopicHistoryItemDelegate::eventFilter(QObject* watched, QEvent* event)
         m_hiddenLabel->hide();
     }
 
-    return false;
+    return KWidgetItemDelegate::eventFilter(watched, event);
 }
 
 QList<QWidget*> TopicHistoryItemDelegate::createItemWidgets(const QModelIndex& index) const
@@ -156,8 +138,8 @@ QList<QWidget*> TopicHistoryItemDelegate::createItemWidgets(const QModelIndex& i
     QList<QWidget*> widgets;
 
     TopicHistoryLabel* label = new TopicHistoryLabel();
-    connect(static_cast<TopicHistoryView*>(itemView()), SIGNAL(textSelectableChanged(bool)),
-        label, SLOT(setTextSelectable(bool)));
+    connect(qobject_cast<TopicHistoryView*>(itemView()), &TopicHistoryView::textSelectableChanged,
+        label, &TopicHistoryLabel::setTextSelectable);
     widgets << label;
 
     return widgets;
@@ -168,8 +150,8 @@ void TopicHistoryItemDelegate::updateItemWidgets(const QList<QWidget*> widgets,
 {
     if (widgets.isEmpty()) return;
 
-    TopicHistoryView* historyView = static_cast<TopicHistoryView*>(itemView());
-    TopicHistoryLabel* label = static_cast<TopicHistoryLabel*>(widgets[0]);
+    auto* historyView = static_cast<TopicHistoryView*>(itemView());
+    auto* label = static_cast<TopicHistoryLabel*>(widgets[0]);
 
     QPalette::ColorRole colorRole = !historyView->textSelectable() &&
         historyView->selectionModel()->isRowSelected(index.row(), index.parent())
@@ -186,21 +168,20 @@ void TopicHistoryItemDelegate::updateItemWidgets(const QList<QWidget*> widgets,
 
 void TopicHistoryItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
 
-    if (!static_cast<TopicHistoryView*>(itemView())->textSelectable())
-    {
+    if (!static_cast<TopicHistoryView*>(itemView())->textSelectable()) {
         QStyleOptionViewItem* hack = const_cast<QStyleOptionViewItem*>(&option);
 
         hack->rect.setHeight(hack->rect.height() - (2 * MARGIN) - 1);
 
-        itemView()->style()->drawPrimitive(QStyle::PE_PanelItemViewItem, hack, painter, 0);
+        itemView()->style()->drawPrimitive(QStyle::PE_PanelItemViewItem, hack, painter, nullptr);
     }
 }
 
 QSize TopicHistoryItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
-    Q_UNUSED(option);
+    Q_UNUSED(option)
 
     m_hiddenLabel->setPlainText(index.model()->data(index).toString());
     m_hiddenLabel->setFixedWidth(itemView()->viewport()->width()
@@ -267,23 +248,6 @@ void TopicHistoryView::setModel(QAbstractItemModel* model)
     KCategorizedView::setModel(m_proxyModel);
 }
 
-bool TopicHistoryView::eventFilter(QObject* watched, QEvent* event)
-{
-    Q_UNUSED(watched);
-
-    if (event->type() == QEvent::Show && !event->spontaneous())
-    {
-        selectionModel()->clearSelection();
-
-        const QModelIndex& currentTopic = model()->index(model()->rowCount() - 1, 0);
-
-        selectionModel()->select(currentTopic, QItemSelectionModel::Select);
-        scrollTo(currentTopic, QAbstractItemView::EnsureVisible);
-    }
-
-    return false;
-}
-
 void TopicHistoryView::resizeEvent(QResizeEvent* event)
 {
     KCategorizedView::resizeEvent(event);
@@ -317,7 +281,7 @@ void TopicHistoryView::updateSelectedItemWidgets()
     const QModelIndexList selectedIndexes = selectionModel()->selectedIndexes();
 
     if (!selectedIndexes.isEmpty())
-        m_proxyModel->dataChanged(selectedIndexes.first(), selectedIndexes.first());
+        emit m_proxyModel->dataChanged(selectedIndexes.first(), selectedIndexes.first());
 }
 
 void TopicHistoryView::updateGeometries()
