@@ -1,24 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2005-2007 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2005-2007 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #ifndef TOPICHISTORYVIEW_H
@@ -42,8 +26,8 @@ class TopicHistorySortfilterProxyModel : public KCategorizedSortFilterProxyModel
     friend class TopicHistoryView;
 
     public:
-        explicit TopicHistorySortfilterProxyModel(QObject* parent = 0);
-        ~TopicHistorySortfilterProxyModel() override;
+        explicit TopicHistorySortfilterProxyModel(QObject* parent = nullptr);
+        ~TopicHistorySortfilterProxyModel();
 
         QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
 
@@ -56,6 +40,9 @@ class TopicHistorySortfilterProxyModel : public KCategorizedSortFilterProxyModel
 
     private Q_SLOTS:
         void sourceDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight);
+
+    private:
+        Q_DISABLE_COPY(TopicHistorySortfilterProxyModel)
 };
 
 
@@ -64,12 +51,15 @@ class TopicHistoryLabel : public KTextEdit
     Q_OBJECT
 
     public:
-        explicit TopicHistoryLabel(QWidget* parent = 0);
-        ~TopicHistoryLabel() override;
+        explicit TopicHistoryLabel(QWidget* parent = nullptr);
+        ~TopicHistoryLabel();
 
 
     public Q_SLOTS:
         void setTextSelectable(bool selectable);
+
+    private:
+        Q_DISABLE_COPY(TopicHistoryLabel)
 };
 
 
@@ -78,8 +68,8 @@ class TopicHistoryItemDelegate : public KWidgetItemDelegate
     Q_OBJECT
 
     public:
-        explicit TopicHistoryItemDelegate(QAbstractItemView* itemView, QObject* parent = 0);
-        ~TopicHistoryItemDelegate() override;
+        explicit TopicHistoryItemDelegate(QAbstractItemView* itemView, QObject* parent = nullptr);
+        ~TopicHistoryItemDelegate();
 
         void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
         QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
@@ -96,6 +86,8 @@ class TopicHistoryItemDelegate : public KWidgetItemDelegate
     private:
         TopicHistoryLabel* m_hiddenLabel;
         bool m_shownBefore;
+
+        Q_DISABLE_COPY(TopicHistoryItemDelegate)
 };
 
 
@@ -104,8 +96,8 @@ class TopicHistoryView : public KCategorizedView
     Q_OBJECT
 
     public:
-        explicit TopicHistoryView(QWidget* parent = 0);
-        ~TopicHistoryView() override;
+        explicit TopicHistoryView(QWidget* parent = nullptr);
+        ~TopicHistoryView();
 
         void setServer(Server* server) { m_server = server; }
 
@@ -133,6 +125,8 @@ class TopicHistoryView : public KCategorizedView
         Server* m_server;
         TopicHistorySortfilterProxyModel* m_proxyModel;
         bool m_textSelectable;
+
+        Q_DISABLE_COPY(TopicHistoryView)
 };
 
 #endif
