@@ -1,8 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2003 Peter Simonsson <psn@linux.se>
 */
 
 #include "trayicon.h"
@@ -21,7 +20,7 @@ namespace Konversation
 
         updateAppearance();
 
-        setToolTip("konversation", i18n("Konversation"), i18n("Konversation - IRC Client"));
+        setToolTip(QStringLiteral("konversation"), i18n("Konversation"), i18n("Konversation - IRC Client"));
     }
 
     TrayIcon::~TrayIcon()
@@ -57,9 +56,9 @@ namespace Konversation
 
     void TrayIcon::updateAppearance()
     {
-        setIconByName("konversation");
-        setAttentionIconByName("konv_message");
-        setOverlayIconByName(m_away ? "user-away" : QString());
+        setIconByName(QStringLiteral("konversation"));
+        setAttentionIconByName(QStringLiteral("konv_message"));
+        setOverlayIconByName(m_away ? QStringLiteral("user-away") : QString());
     }
 }
 
