@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #include "viewspringloader.h"
@@ -48,9 +32,8 @@ bool ViewSpringLoader::eventFilter(QObject* watched, QEvent* event)
 {
     if (event->type() == QEvent::DragEnter)
     {
-        if (!static_cast<QDragEnterEvent*>(event)->mimeData()->hasFormat("application/x-konversation-chatwindow"))
-        {
-            m_hoveredWidget = static_cast<QWidget*>(watched);
+        if (!static_cast<QDragEnterEvent*>(event)->mimeData()->hasFormat(QStringLiteral("application/x-konversation-chatwindow"))) {
+            m_hoveredWidget = qobject_cast<QWidget*>(watched);
 
             event->accept();
 
@@ -59,9 +42,9 @@ bool ViewSpringLoader::eventFilter(QObject* watched, QEvent* event)
     }
     else if (event->type() == QEvent::DragMove)
     {
-        QDragMoveEvent* dragMoveEvent = static_cast<QDragMoveEvent*>(event);
+        auto* dragMoveEvent = static_cast<QDragMoveEvent*>(event);
 
-        if (!dragMoveEvent->mimeData()->hasFormat("application/x-konversation-chatwindow"))
+        if (!dragMoveEvent->mimeData()->hasFormat(QStringLiteral("application/x-konversation-chatwindow")))
         {
             ChatWindow* hoveredView = viewForPos(watched, dragMoveEvent->pos());
 
@@ -81,8 +64,8 @@ bool ViewSpringLoader::eventFilter(QObject* watched, QEvent* event)
     else if (event->type() == QEvent::Drop || event->type() == QEvent::DragLeave)
     {
         m_hoverTimer.stop();
-        m_hoveredWidget = 0;
-        m_hoveredView = 0;
+        m_hoveredWidget = nullptr;
+        m_hoveredView = nullptr;
     }
 
     return QObject::eventFilter(watched, event);
@@ -94,7 +77,7 @@ void ViewSpringLoader::springLoad()
         m_hoveredWidget->mapFromGlobal(QCursor::pos())))
     {
         m_viewContainer->showView(m_hoveredView);
-        m_hoveredView = 0;
+        m_hoveredView = nullptr;
     }
 }
 
@@ -120,5 +103,5 @@ ChatWindow* ViewSpringLoader::viewForPos(QObject* widget, const QPoint& pos)
         }
     }
 
-    return 0;
+    return nullptr;
 }
