@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006-2009 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006-2009 Eike Hein <hein@kde.org>
 */
 
 #include "viewtree.h"
@@ -25,15 +20,17 @@
 #include <QItemSelectionModel>
 #include <QStyleHints>
 #include <QToolTip>
+#include <QPainterPath>
 
 // FIXME KF5 Port: Not DPI-aware.
-#define LED_ICON_SIZE 14
-#define MARGIN 2
-#define RADIUS 4
+constexpr int LED_ICON_SIZE = 14;
+constexpr int MARGIN = 2;
+constexpr int RADIUS = 4;
 
-ViewTreeDelegate::ViewTreeDelegate(QObject* parent) : QStyledItemDelegate(parent)
+ViewTreeDelegate::ViewTreeDelegate(ViewTree* parent)
+    : QStyledItemDelegate(parent)
+    , m_view(parent)
 {
-    m_view = qobject_cast<ViewTree*>(parent);
 }
 
 ViewTreeDelegate::~ViewTreeDelegate()
@@ -103,7 +100,7 @@ void ViewTreeDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opti
         bottomWing.lineTo(bottomWing.currentPosition().x() - RADIUS, bottomWing.currentPosition().y());
         bottomWing.moveTo(startPos);
         bottomWing.lineTo(bottomWing.currentPosition().x(), bottomWing.currentPosition().y() + RADIUS);
-        bottomWing.quadTo(startPos, QPoint(bottomWing.currentPosition().x() - RADIUS,
+        bottomWing.quadTo(startPos, QPointF(bottomWing.currentPosition().x() - RADIUS,
             bottomWing.currentPosition().y() - RADIUS));
         painter->fillPath(bottomWing, selColor);
     }
@@ -117,7 +114,7 @@ void ViewTreeDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opti
         topWing.lineTo(topWing.currentPosition().x() - RADIUS, topWing.currentPosition().y());
         topWing.moveTo(startPos);
         topWing.lineTo(topWing.currentPosition().x(), topWing.currentPosition().y() - RADIUS);
-        topWing.quadTo(startPos, QPoint(topWing.currentPosition().x() - RADIUS,
+        topWing.quadTo(startPos, QPointF(topWing.currentPosition().x() - RADIUS,
             topWing.currentPosition().y() + RADIUS));
         painter->fillPath(topWing, selColor);
     }
@@ -219,18 +216,16 @@ bool ViewTree::event(QEvent* event)
     if (event->type() == QEvent::ToolTip) {
         event->accept();
 
-        const QHelpEvent* helpEvent = static_cast<QHelpEvent*>(event);
+        const auto* helpEvent = static_cast<QHelpEvent*>(event);
 
         const QModelIndex& idx = indexAt(helpEvent->pos());
 
         if (idx.isValid()) {
-            const QString &text = idx.model()->data(idx, Qt::DisplayRole).toString();
             const QSize& preferredSize = static_cast<ViewTreeDelegate*>(itemDelegate())->preferredSizeHint(idx);
             const QRect& itemRect = visualRect(idx);
 
             if (preferredSize.width() > itemRect.width()) {
-                event->accept();
-
+                const QString &text = idx.model()->data(idx, Qt::DisplayRole).toString();
                 QToolTip::showText(helpEvent->globalPos(), text, this);
 
                 return true;
@@ -262,7 +257,7 @@ void ViewTree::paintEvent(QPaintEvent* event)
     int count = model->rowCount(lastRow);
 
     if (count) {
-        lastRow = lastRow.child(count - 1, 0);
+        lastRow = model->index(count - 1, 0, lastRow);
     }
 
     if (lastRow.isValid() && lastRow == currentRow) {
@@ -279,7 +274,7 @@ void ViewTree::paintEvent(QPaintEvent* event)
         bottomWing.lineTo(bottomWing.currentPosition().x() - RADIUS, bottomWing.currentPosition().y());
         bottomWing.moveTo(startPos);
         bottomWing.lineTo(bottomWing.currentPosition().x(), bottomWing.currentPosition().y() + RADIUS);
-        bottomWing.quadTo(startPos, QPoint(bottomWing.currentPosition().x() - RADIUS,
+        bottomWing.quadTo(startPos, QPointF(bottomWing.currentPosition().x() - RADIUS,
             bottomWing.currentPosition().y() - RADIUS));
         painter.fillPath(bottomWing, painter.brush());
     }
@@ -331,14 +326,14 @@ void ViewTree::mouseReleaseEvent(QMouseEvent* event)
             const QModelIndex& idx = indexAt(event->pos());
 
             if (idx.isValid()) {
-                if (m_pressedView != 0 && m_pressedView == static_cast<ChatWindow*>(idx.internalPointer())) {
+                if (m_pressedView != nullptr && m_pressedView == static_cast<ChatWindow*>(idx.internalPointer())) {
                     emit closeView(m_pressedView.data());
                 }
             }
         }
     }
 
-    m_pressedView = 0;
+    m_pressedView = nullptr;
 
     QTreeView::mouseReleaseEvent(event);
 }
@@ -349,7 +344,7 @@ void ViewTree::mouseMoveEvent(QMouseEvent* event)
         selectionModel()->select(indexAt(event->pos()), QItemSelectionModel::ClearAndSelect);
         startDrag(Qt::MoveAction);
         m_pressPos = QPoint();
-        m_pressedView = 0;
+        m_pressedView = nullptr;
     }
 
     QTreeView::mouseMoveEvent(event);
@@ -437,7 +432,7 @@ void ViewTree::wheelEvent(QWheelEvent* event)
             int count = model->rowCount(idx);
 
             if (count) {
-                idx = idx.child(count - 1, 0);
+                idx = model->index(count - 1, 0, idx);
             }
         } else {
             idx = model->index(0, 0);
@@ -465,7 +460,7 @@ void ViewTree::keyPressEvent(QKeyEvent* event)
                     view->appendInputText(event->text(), true);
                 else if (view->getType() == ChatWindow::Konsole)
                 {
-                    KonsolePanel* panel = static_cast<KonsolePanel*>(view);
+                    auto* panel = static_cast<KonsolePanel*>(view);
                     QCoreApplication::sendEvent(panel->getWidget(), event);
                 }
 
@@ -491,7 +486,7 @@ void ViewTree::selectionChanged(const QItemSelection& selected, const QItemSelec
 
     const QModelIndexList& idxList = selected.indexes();
 
-    if (idxList.count()) {
+    if (!idxList.isEmpty()) {
         const QModelIndex& idx = idxList.at(0);
 
         ChatWindow* view = static_cast<ChatWindow*>(idx.internalPointer());
